<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
	<!-- VIRTUAL DISK TABLE HEADER -->
	<xsl:template name="VirtualDiskTableHeader">
		<xsl:param name="tasks"/>
		<!-- ignore on web is set to true since it's only needed for scripts using the cli -->
		<Data name="Id" editable="false" type="ustring" >
			<xsl:attribute name="display"><xsl:value-of select="$strID"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$strID"/></xsl:attribute>
		</Data>
		<Data name="Status" editable="false" type="ustring">
			<xsl:attribute name="display"><xsl:value-of select="$strStatus"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$strStatus"/></xsl:attribute>
		</Data>
		<Data name="Name" editable="false" type="ustring">
			<xsl:attribute name="display"><xsl:value-of select="$strName"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$strName"/></xsl:attribute>
		</Data>
		<Data name="State" editable="false" type="ustring">
			<xsl:attribute name="display"><xsl:value-of select="$strState"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$strState"/></xsl:attribute>
		</Data>
		<xsl:if test="$tasks='true'">
			<Data name="Delete" editable="false" type="ustring">
				<xsl:attribute name="display"><xsl:value-of select="$strTasks"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="$strTasks"/></xsl:attribute>
			</Data>
			<!-- The Rows have one extra row for the execute button.  Including a blank <Data> tag here keeps the line that underlines the headers continuous -->
			<Data name="exbut" editable="false" type="ustring" ignoreoncli="true">
				<xsl:attribute name="display">Execute</xsl:attribute>
				<xsl:attribute name="value"> </xsl:attribute>
			</Data>
		</xsl:if>
		<xsl:if test="//Progress or /OMA/@cli = 'true'">
			<!-- See if any VDisk has a progress.  If so, show the header for the table -->
			<Data name="Progress" editable="false" type="ustring">
				<xsl:attribute name="display"><xsl:value-of select="$strProgress"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="$strProgress"/></xsl:attribute>
			</Data>
		</xsl:if>
		<Data name="Layout" editable="false" type="ustring">
			<xsl:attribute name="display"><xsl:value-of select="$strLayout"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$strLayout"/></xsl:attribute>
		</Data>
		<Data name="Size" editable="false" type="ustring">
			<xsl:attribute name="display"><xsl:value-of select="$strSize"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$strSize"/></xsl:attribute>
		</Data>
		<Data name="DeviceName" editable="false" type="ustring">
			<xsl:attribute name="display"><xsl:value-of select="$strDeviceName"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$strDeviceName"/></xsl:attribute>
		</Data>
		<Data name="Read Cache" editable="false" type="ustring">
			<xsl:attribute name="display"><xsl:value-of select="$strReadCache"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$strReadCache"/></xsl:attribute>
		</Data>
		<Data name="Write Cache" editable="false" type="ustring">
			<xsl:attribute name="display"><xsl:value-of select="$strWriteCache"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$strWriteCache"/></xsl:attribute>
		</Data>
		<Data name="Cache Policy" editable="false" type="ustring">
			<xsl:attribute name="display"><xsl:value-of select="$strCachePolicy"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$strCachePolicy"/></xsl:attribute>
		</Data>
		<Data name="StripeSize" editable="false" type="ustring">
			<xsl:attribute name="display"><xsl:value-of select="$strStripeSize"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$strStripeSize"/></xsl:attribute>
		</Data>
	</xsl:template>
	<!-- VIRTUAL DISK TABLE ROWS -->
	<xsl:template name="VirtualDiskTableRows">
		<xsl:param name="ObjID">
			<xsl:call-template name="ModNexus">
				<xsl:with-param name="nexus">
					<xsl:value-of select="Nexus"/>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:param>
		<xsl:param name="tasks"/>
		<xsl:param name="caller"/>
		<!--<xsl:call-template name="scripts"/>-->
		<xsl:variable name="vdiskname">
			<xsl:value-of select="../@VirtualDiskName"/>
		</xsl:variable>
		<xsl:variable name="vdiskid">
			<xsl:value-of select="$ObjID"/>
		</xsl:variable>

		<xsl:variable name="blink">
			<xsl:if test="substring(DCStorageObject/CurrentMethodMask,24,1)!='0'">true</xsl:if>
		</xsl:variable>
		
		<xsl:variable name="isCluster">
			<xsl:choose>
				<xsl:when test="substring(/OMA/ArrayDisks/DCStorageObject/AttributesMask,32,1)!='0'">1</xsl:when>
			  <xsl:otherwise>0</xsl:otherwise>
		 </xsl:choose>
		</xsl:variable>
		
		<xsl:variable name="vdevname">
			<xsl:value-of select="../@VirtualDiskName"/>
		</xsl:variable>
		<xsl:variable name="numbootpart">
			<xsl:choose>
				<xsl:when test="NumOfPartition">
					<xsl:value-of select="NumOfPartition"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="0"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:if test="count(ParentVDID)= 0">
			<!-- Only display main virtual disks, not child VDisks -->
			<Row>
				<!-- ignore on web is set to true since it's only needed for scripts using the cli -->
				<Data name="Test" editable="false" type="ustring" display="Test" >
					<xsl:attribute name="value"><xsl:value-of select="TargetID"/></xsl:attribute>
				</Data>
				<Data type="status" align="center">
					<xsl:attribute name="value"><xsl:value-of select="ObjStatus"/></xsl:attribute>
				</Data>
				<Data link="true" editable="false" type="ustring" display="Test">
					<xsl:attribute name="name"><xsl:value-of select="$strName"/><xsl:value-of select="position()"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="../@VirtualDiskName"/></xsl:attribute>
				</Data>
				<Data editable="false" type="ustring" display="Test">
					<xsl:attribute name="name"><xsl:value-of select="$strState"/><xsl:value-of select="position()"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:call-template name="GetState"><xsl:with-param name="state"><xsl:value-of select="ObjState"/></xsl:with-param></xsl:call-template></xsl:attribute>
				</Data>
				<!-- isEmpty var used for tasks menu option -->
				<xsl:variable name="isEmpty">
					<xsl:call-template name="IsCurrentMethodMaskEmpty">
						<xsl:with-param name="Mask">
							<xsl:value-of select="CurrentMethodMask"/>
						</xsl:with-param>
					</xsl:call-template>
				</xsl:variable>
				<xsl:if test="$tasks='true'">
					<xsl:choose>
						<!--check to see if methods even exist -->
						<xsl:when test="$isEmpty='0'">
							<!-- currentmethod mask isn't empty -->
							<Data value="tasks" type="select" boxwidth="width:400px">
								<xsl:attribute name="display"><xsl:value-of select="$strVDTasks"/></xsl:attribute>
								<xsl:attribute name="name">VDtasks<xsl:value-of select="$vdiskid"/></xsl:attribute>
								<Choice returnvalue="-" default="true">
									<xsl:attribute name="value"><xsl:value-of select="$strSelectTask"/></xsl:attribute>
								</Choice>
								<xsl:call-template name="for-loop-list-box">
									<xsl:with-param name="Mask" select="CurrentMethodMask"/>
									<xsl:with-param name="templateName" select="9"/>
								</xsl:call-template>
							</Data>
							<!-- add execute link -->
							<Data type="ustring" link="true">
								<xsl:attribute name="value"><xsl:value-of select="$strExecute"/></xsl:attribute>
								<xsl:attribute name="name"><xsl:value-of select="$strExecute"/><xsl:value-of select="position()"/></xsl:attribute>
								<xsl:attribute name="href">javascript:onExecute("<xsl:value-of select="$vdiskname"/>","<xsl:value-of select="$vdiskid"/>","<xsl:value-of select="$blink"/>","<xsl:value-of select="$vdevname"/>","<xsl:value-of select="$numbootpart"/>")
									</xsl:attribute>
							</Data>
						</xsl:when>
						<xsl:otherwise>
							<!-- current methodmask is empty -->
							<Data value="tasks" type="select" boxwidth="width:400px">
								<xsl:attribute name="display"><xsl:value-of select="$strVDTasks"/></xsl:attribute>
								<xsl:attribute name="name">VDtasks<xsl:value-of select="$vdiskid"/></xsl:attribute>
								<Choice returnvalue="" default="true">
									<xsl:attribute name="value"><xsl:value-of select="$strNoTask"/></xsl:attribute>
								</Choice>
							</Data>
							<!-- add execute link that is disabled -->
							<Data type="ustring" link="false">
								<xsl:attribute name="value"><xsl:value-of select="$strExecute"/></xsl:attribute>
								<xsl:attribute name="name"><xsl:value-of select="$strExecute"/><xsl:value-of select="position()"/></xsl:attribute>
							</Data>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:if>
				<xsl:if test="//Progress or /OMA/@cli = 'true'">
					<xsl:choose>
						<xsl:when test="Progress">
							<Data type="ustring" align="center">
								<xsl:attribute name="value"><xsl:value-of select="Progress"/><xsl:value-of select="$strPercComp"/></xsl:attribute>
							</Data>
						</xsl:when>
						<xsl:when test="/OMA/@cli = 'true'">
							<Data type="ustring" align="center">
								<xsl:attribute name="value"><xsl:value-of select="$strNotApplicable"/></xsl:attribute>
							</Data>
						</xsl:when>
						<xsl:otherwise>
							<Data type="ustring" align="center">
								<xsl:attribute name="value"/>
							</Data>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:if>
				<Data editable="false" type="ustring" display="Test">
					<xsl:attribute name="name"><xsl:value-of select="$strLayout"/><xsl:value-of select="position()"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:call-template name="GetRaidLayout"><xsl:with-param name="RaidType"><xsl:value-of select="Layout"/></xsl:with-param></xsl:call-template></xsl:attribute>
				</Data>
				<xsl:choose>
					<xsl:when test="/OMA/@cli='true'">
						<!--CLI version of the capacty data (displays bytes as well as GB)-->
						<Data name="Test" editable="false" type="ustring" display="Test" >
							<xsl:attribute name="value"><xsl:call-template name="DecimalSep"><xsl:with-param name="Size"><xsl:value-of select="Length"/></xsl:with-param></xsl:call-template> GB (<xsl:value-of select="Length"/> bytes)</xsl:attribute>
						</Data>
					</xsl:when>
					<xsl:otherwise>
						<!-- Web Version of the length data (ONLY displays GB) -->
						<Data editable="false" type="ustring" display="Test" >
							<xsl:attribute name="name"><xsl:value-of select="$strSize"/><xsl:value-of select="position()"/></xsl:attribute>
							<xsl:attribute name="value"><xsl:call-template name="DecimalSep"><xsl:with-param name="Size"><xsl:value-of select="Length"/></xsl:with-param></xsl:call-template> <xsl:value-of select="$strGB"/></xsl:attribute>
						</Data>
					</xsl:otherwise>
				</xsl:choose>
				<Data editable="false" type="ustring" display="Test">
					<xsl:attribute name="name"><xsl:value-of select="$strDeviceName"/><xsl:value-of select="position()"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="ProductID"/></xsl:attribute>
				</Data>
				<Data editable="false" type="ustring" display="Test">
					<xsl:attribute name="name"><xsl:value-of select="$strReadCache"/><xsl:value-of select="position()"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:call-template name="GetReadPolicy"><xsl:with-param name="readpolicy"><xsl:value-of select="ReadPolicy"/></xsl:with-param></xsl:call-template></xsl:attribute>
				</Data>
				<Data editable="false" type="ustring" display="Test">
					<xsl:attribute name="name"><xsl:value-of select="$strWriteCache"/><xsl:value-of select="position()"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:call-template name="GetWritePolicy"><xsl:with-param name="writepolicy"><xsl:value-of select="WritePolicy"/></xsl:with-param></xsl:call-template></xsl:attribute>
				</Data>
				<Data editable="false" type="ustring" display="Test">
					<xsl:attribute name="name"><xsl:value-of select="$strCachePolicy"/><xsl:value-of select="position()"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:call-template name="GetCachePolicy"><xsl:with-param name="cachepolicy"><xsl:value-of select="CachePolicy"/></xsl:with-param></xsl:call-template></xsl:attribute>
				</Data>
				<Data editable="false" type="ustring" display="Test">
					<xsl:attribute name="name"><xsl:value-of select="$strStripeSize"/><xsl:value-of select="position()"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:call-template name="GetStripeSize"><xsl:with-param name="stripesize"><xsl:value-of select="StripeSize"/></xsl:with-param></xsl:call-template></xsl:attribute>
				</Data>
			</Row>
		</xsl:if>
		<!-- End if (VDLevel = 0) -->
	</xsl:template>
</xsl:stylesheet>
