<!---<?xml version="1.0" encoding="UTF-8"?> -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
   <xsl:output method="xml" />
   <xsl:strip-space elements="*" />
   

   <xsl:template match="SMBIOS">
   <OMA>
       <xsl:attribute name="cli">true</xsl:attribute>
        <ChassisList>
           <Chassis>
           <xsl:attribute name="index"><xsl:value-of select="count(System_Information) - 1" /></xsl:attribute> 
           <xsl:attribute name="count"><xsl:value-of select="count(Base_Board_Information)"/></xsl:attribute>
           <xsl:attribute name="display">Main System Chassis</xsl:attribute>
             <ChassisInfo>
		       <xsl:apply-templates select="System_Information" />
	 		   <xsl:apply-templates select="System_Enclosure_or_Chassis"/>     
			 <BaseBoardList>
				 <xsl:attribute name="count"><xsl:value-of select="count(//Base_Board_Information)"/></xsl:attribute>
			       <xsl:apply-templates select="Base_Board_Information" />
			 </BaseBoardList>
			 </ChassisInfo>
			</Chassis>
		 </ChassisList>
		 <ObjStatus>1</ObjStatus>
        <SMStatus>0</SMStatus>
    </OMA>
   </xsl:template>

   <xsl:template match="Base_Board_Information">
   <BaseBoard>
	      <xsl:attribute name="index"><xsl:value-of select="position()-1"/></xsl:attribute>
         <BaseBoardType>
			 <xsl:if test="position() = 1"><xsl:value-of select="13"/> </xsl:if>
			 <xsl:if test="position() > 1"><xsl:value-of select="3"/></xsl:if>
         </BaseBoardType>
         <Manufacturer>
			 <xsl:value-of select="Manufacturer"/>
           </Manufacturer>
         <ProductName>
			 <xsl:value-of select="Product"/>
         </ProductName>
         <Version>
			 <xsl:value-of select="Version"/>
         </Version>
         <ServiceTag>
			 <xsl:value-of select="substring(Serial_Number,2,7)"/>
         </ServiceTag>
         <xsl:if test="position() = 1">
	 	<PiecePartID>
			 <xsl:value-of select="substring(Serial_Number,10)"/>
		 </PiecePartID>
	 </xsl:if>
	 <AssetTag>
		 <xsl:value-of select="Asset_Tag"/>
	 </AssetTag>
	 <BoardLocation>
		 <xsl:value-of select="Location_in_Chassis"/>
	 </BoardLocation>
	 <BaseBoardTypeStr>
		 <xsl:if test="position() > 1">Server Blade </xsl:if>
		 <xsl:if test="position() = 1">Interconnect Board</xsl:if>
	 </BaseBoardTypeStr>
	 </BaseBoard>
   </xsl:template>

   <xsl:template match="System_Information">
       <!--Yes there are 2 levels of OMA -->
               <ChassisProps1>
                <ChassType>
                    <xsl:choose>
			<xsl:when test="//System_Enclosure_or_Chassis/Enclosure_Type/Item = 'Multi-system Chassis' "><xsl:value-of select="25"/>
			</xsl:when>
			<xsl:otherwise><xsl:value-of select="6"/>
			</xsl:otherwise>
		   </xsl:choose>
		</ChassType>
                <ChassClass>
                    <xsl:choose>
			<xsl:when test="//System_Enclosure_or_Chassis/Enclosure_Type/Item = 'Multi-system Chassis' "><xsl:value-of select="4"/>
			</xsl:when>
			<xsl:otherwise><xsl:value-of select="4"/>
			</xsl:otherwise>
		   </xsl:choose>
		</ChassClass>
                 <ChassModel>
		        	<xsl:choose>
		        	<xsl:when test="substring(Product_Name,15,1) ='/' " >
						  <xsl:value-of select="substring(Product_Name,1,14)" />
		        	</xsl:when>
		        	<xsl:otherwise>
						  <xsl:value-of select="Product_Name" />
		        	</xsl:otherwise>
		        	</xsl:choose>
		        </ChassModel>
		        <ChassManufacturer>
					  <xsl:value-of select="Manufacturer" />
		        </ChassManufacturer>
		        <ChassLockPresent>
		        	<xsl:choose>
		        		<xsl:when test="//Enclosure_Type/Item='Chassis lock'">
		        			true
		        		</xsl:when>
		        		<xsl:when test="//System_Enclosure_or_Chassis/Security_Status/Item!='None'">
		        			true
		        		</xsl:when>
		        		<xsl:otherwise>
		        			false
		        		</xsl:otherwise>
		        	</xsl:choose>
		        </ChassLockPresent>
             </ChassisProps1>
   </xsl:template>

   <xsl:template match="System_Enclosure_or_Chassis">
           <ChassisProps2>
<!--
			  <FanControl>0</FanControl> 
			  <FaultLEDControl>0</FaultLEDControl> 
			  <FaultLEDState>0</FaultLEDState> 
			  <ConnectStatus>2</ConnectStatus> 
			  <PowerButtonControl>0</PowerButtonControl> 
			  <NMIButtonControl>0</NMIButtonControl> 
			  <ChassIdentifyState>0</ChassIdentifyState> 
			  <ChassIdentifyTimeout>
			    <xsl:attribute name="unit">seconds</xsl:attribute>0</ChassIdentifyTimeout> 
			  <HdLedSupport>false</HdLedSupport> 
			  <IdentifySupport>false</IdentifySupport> 
-->
             <ServiceTag>
	            <xsl:choose>
					<xsl:when test="count(//Base_Board_Information) > 1">
						<xsl:value-of select="//System_Information/Serial_Number"/>
					</xsl:when>
	            	<xsl:when test="normalize-space(Serial_Number) != ''">
	            		<xsl:value-of select="Serial_Number" />
	           		</xsl:when>
	           		<xsl:when test="normalize-space(Version) != ''" >
	            		<xsl:value-of select="Version" />
	           		</xsl:when>
	           		<xsl:otherwise>
	            		<xsl:value-of select="Asset_Tag_Number" />
		           	</xsl:otherwise>
	           	</xsl:choose>
             </ServiceTag>
             <AssetTag>
		<xsl:attribute name="editable"><xsl:value-of select="true"/></xsl:attribute>
		 <xsl:choose>	
			<xsl:when test="normalize-space(//System_Enclosure_or_Chassis/Enclosure_Type/Item) = 'Multi-system Chassis' ">
				<xsl:value-of select="//Base_Board_Information/Asset_Tag"/>
		  	</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="Asset_Tag_Number"/>
                        </xsl:otherwise>
		</xsl:choose>
	     </AssetTag>

           </ChassisProps2>
   </xsl:template>

<!--	Here is where we begin the supporting functions templates
-->


   <xsl:template match="*" />
</xsl:stylesheet>

