<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:output method="xml"/>
	<xsl:strip-space elements="*"/>
	<xsl:template match="SMBIOS">
		<OMA>
			<xsl:attribute name="cli">true</xsl:attribute>
			<!--     <OMA>
		   <System>
			   <xsl:apply-templates select="System_Header"/>
		   </System>

       </OMA>
-->
			<OMA>
				<ChassisList>
					<xsl:attribute name="index"><xsl:value-of select="count(System_Information) - 1"/></xsl:attribute>
					<xsl:attribute name="count"><xsl:value-of select="count(System_Enclosure_or_Chassis)"/></xsl:attribute>
					<Chassis>
						<xsl:attribute name="display"><xsl:value-of select="//System_Enclosure_or_Chassis/Enclosure_Type/Item"/></xsl:attribute>
						<xsl:attribute name="index"><xsl:value-of select="count(System_Information) - 1"/></xsl:attribute>
						<ChassisInfo>
							<xsl:apply-templates select="System_Information"/>
							<xsl:apply-templates select="System_Enclosure_or_Chassis"/>
						</ChassisInfo>
						<Hardware>
							<ProcessorList>
								<xsl:attribute name="count"><xsl:value-of select="count(Processor_Information)"/></xsl:attribute>
								<xsl:apply-templates select="Processor_Information"/>
							</ProcessorList>
							<!--
							<xsl:variable name="cntmem">
								<xsl:value-of select="count(//Memory_Array_Mapped_Address)"/>
							</xsl:variable>
							-->
							<xsl:variable name="MaxMem">
								<xsl:variable name="Temp_sum">
									<xsl:call-template name="Sum_Mem">
										<xsl:with-param name="MemSlots" select="count(//Memory_Device)"/>
									</xsl:call-template>
								</xsl:variable>
								<xsl:value-of select="number($Temp_sum)"/>
							</xsl:variable>
							<MemoryInfo>
								<TotalPhysMemorySize>
									<xsl:attribute name="unit"> KB</xsl:attribute>
									<xsl:value-of select="number($MaxMem)* 1024"/>
								</TotalPhysMemorySize>
								<TotalPhysMemorySizeMB>
									<xsl:attribute name="unit"> MB</xsl:attribute>
									<xsl:value-of select="number($MaxMem)"/>
								</TotalPhysMemorySizeMB>
							</MemoryInfo>
							<xsl:call-template name="MemArrays">
								<xsl:with-param name="MaxPhysical" select="$MaxMem"/>
							</xsl:call-template>
							<MaxInstalledSizeMBCumulative>
								<xsl:attribute name="unit"> MB</xsl:attribute>
								<xsl:value-of select="number($MaxMem)"/>
							</MaxInstalledSizeMBCumulative>
							<MaxSizeMBCumulative>
								<xsl:attribute name="unit"> MB</xsl:attribute>
								<xsl:variable name="MSMB_res">
									<xsl:call-template name="hexToDec">
										<xsl:with-param name="hexVal" select="substring-after(Physical_Memory_Array/Maximum_Capacity,'x')"/>
										<xsl:with-param name="decVal" select="0"/>
									</xsl:call-template>
								</xsl:variable>
								<xsl:value-of select="($MSMB_res) div 1024"/>
							</MaxSizeMBCumulative>
							<SlotsList>
								<xsl:apply-templates select="System_Slots"/>
								<xsl:call-template name="SlotZero"/>
							</SlotsList>
							<SystemBIOS>
								<SMBIOSPresent>true</SMBIOSPresent>
								<Manufacturer>
									<xsl:value-of select="BIOS_Information/Vendor"/>
								</Manufacturer>
								<Version>
									<xsl:value-of select="BIOS_Information/BIOS_Version"/>
								</Version>
								<ReleaseDate>
									<xsl:value-of select="BIOS_Information/BIOS_Release_Date"/>
								</ReleaseDate>
							</SystemBIOS>
						</Hardware>
					</Chassis>
				</ChassisList>
				<BaseBoardList>
					<xsl:attribute name="count"><xsl:value-of select="count(//Base_Board_Information)"/></xsl:attribute>
					<xsl:apply-templates select="Base_Board_Information"/>
				</BaseBoardList>
				<SMStatus>0</SMStatus>
			</OMA>
		</OMA>
	</xsl:template>
	<xsl:template match="Base_Board_Information">
		<BaseBoard>
			<xsl:attribute name="index"><xsl:value-of select="position()-1"/></xsl:attribute>
			<BaseBoardType>
				<xsl:if test="position() = 1">
					<xsl:value-of select="13"/>
				</xsl:if>
				<xsl:if test="position() &gt; 1">
					<xsl:value-of select="3"/>
				</xsl:if>
			</BaseBoardType>
			<Manufacturer>
				<xsl:value-of select="Manufacturer"/>
			</Manufacturer>
			<ProductName>
				<xsl:value-of select="Product"/>
			</ProductName>
			<Version>
				<xsl:value-of select="Version"/>
			</Version>
			<ServiceTag>
				<xsl:value-of select="substring(Serial_Number,2,7)"/>
			</ServiceTag>
			<xsl:if test="position() = 1">
				<PiecePartID>
					<xsl:value-of select="substring(Serial_Number,10)"/>
				</PiecePartID>
			</xsl:if>
			<AssetTag>
				<xsl:value-of select="Asset_Tag"/>
			</AssetTag>
			<BoardLocation>
				<xsl:value-of select="Location_in_Chassis"/>
			</BoardLocation>
			<BaseBoardTypeStr>
				<xsl:if test="position() &gt; 1">Server Blade </xsl:if>
				<xsl:if test="position() = 1">Interconnect Board</xsl:if>
			</BaseBoardTypeStr>
		</BaseBoard>
	</xsl:template>
	<xsl:template match="System_Information">
		<!--Yes there are 2 levels of OMA -->
		<ChassisProps1>
			<ChassType>
				<xsl:choose>
					<xsl:when test="//System_Enclosure_or_Chassis/Enclosure_Type/Item = 'Multi-system Chassis' ">
						<xsl:value-of select="25"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="6"/>
					</xsl:otherwise>
				</xsl:choose>
			</ChassType>
			<ChassClass>
				<xsl:choose>
					<xsl:when test="//System_Enclosure_or_Chassis/Enclosure_Type/Item = 'Multi-system Chassis' ">
						<xsl:value-of select="4"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="4"/>
					</xsl:otherwise>
				</xsl:choose>
			</ChassClass>
			<ChassModel>
				<xsl:choose>
					<xsl:when test="substring(Product_Name,15,1) ='/' ">
						<xsl:value-of select="substring(Product_Name,1,14)"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="Product_Name"/>
					</xsl:otherwise>
				</xsl:choose>
			</ChassModel>
			<ChassManufacturer>
				<xsl:value-of select="Manufacturer"/>
			</ChassManufacturer>
			<ChassLockPresent>
				<xsl:choose>
					<xsl:when test="//Enclosure_Type/Item='Chassis lock'">
						<xsl:value-of select="true"/>
					</xsl:when>
					<xsl:when test="//System_Enclosure_or_Chassis/Security_Status/Item!='None'">
						<xsl:value-of select="true"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="false"/>
					</xsl:otherwise>
				</xsl:choose>
			</ChassLockPresent>
		</ChassisProps1>
	</xsl:template>
	<xsl:template match="System_Enclosure_or_Chassis">
		<ChassisProps2>
			<ServiceTag>
				<xsl:choose>
					<xsl:when test="normalize-space(Serial_Number) != ''">
						<xsl:value-of select="Serial_Number"/>
					</xsl:when>
					<xsl:when test="count(//Base_Board_Information) &gt; 1">
						<xsl:value-of select="//System_Information/Serial_Number"/>
					</xsl:when>
					<xsl:when test="normalize-space(Version) != ''">
						<xsl:value-of select="Version"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="Asset_Tag_Number"/>
					</xsl:otherwise>
				</xsl:choose>
			</ServiceTag>
			<AssetTag>
				<xsl:attribute name="editable"><xsl:value-of select="true"/></xsl:attribute>
				<xsl:choose>
					<xsl:when test="normalize-space(//System_Enclosure_or_Chassis/Enclosure_Type/Item) = 'Multi-system Chassis' ">
						<xsl:value-of select="//Base_Board_Information/Asset_Tag"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="Asset_Tag_Number"/>
					</xsl:otherwise>
				</xsl:choose>
			</AssetTag>
		</ChassisProps2>
	</xsl:template>
	<xsl:template match="Processor_Information">
		<!--Yes there are 2 levels of OMA -->
		<DevProcessor>
			<ExtName>
				<xsl:value-of select="Socket_Designation"/>
			</ExtName>
			<Family>
				<xsl:choose>
					<xsl:when test="normalize-space(//Processor_Family/Item)='Intel Xeon Processor MP' ">
						<xsl:value-of select="181"/>
					</xsl:when>
					<xsl:when test="normalize-space(//Processor_Family/Item)='Pentium processor Family' ">
						<xsl:value-of select="11"/>
					</xsl:when>
					<xsl:when test="normalize-space(//Processor_Family/Item)='Pentium Pro processor' ">
						<xsl:value-of select="12"/>
					</xsl:when>
					<xsl:when test="normalize-space(//Processor_Family/Item)='Pentium II processor' ">
						<xsl:value-of select="13"/>
					</xsl:when>
					<xsl:when test="normalize-space(//Processor_Family/Item)='Pentium processor with MMX technology' ">
						<xsl:value-of select="14"/>
					</xsl:when>
					<xsl:when test="normalize-space(//Processor_Family/Item)='Celeron processor' ">
						<xsl:value-of select="15"/>
					</xsl:when>
					<xsl:when test="normalize-space(//Processor_Family/Item)='Pentium II Xeon processor' ">
						<xsl:value-of select="16"/>
					</xsl:when>
					<xsl:when test="normalize-space(//Processor_Family/Item)='Pentium III processor' ">
						<xsl:value-of select="17"/>
					</xsl:when>
					<xsl:when test="normalize-space(//Processor_Family/Item)='Pentium II Xeon processor' ">
						<xsl:value-of select="176"/>
					</xsl:when>
					<xsl:when test="normalize-space(//Processor_Family/Item)='Pentium 4 Processor' ">
						<xsl:value-of select="178"/>
					</xsl:when>
					<xsl:when test="normalize-space(//Processor_Family/Item)='Intel Xeon' ">
						<xsl:value-of select="179"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="2"/>
					</xsl:otherwise>
				</xsl:choose>
			</Family>
			<ProcessorStatus>
				<xsl:choose>
					<xsl:when test="normalize-space(Status/Item)='CPU Enabled' ">
						<xsl:value-of select="1"/>
					</xsl:when>
					<xsl:when test="normalize-space(Status/Item)='CPU Disabled by User via BIOS Setup' ">
						<xsl:value-of select="2"/>
					</xsl:when>
					<xsl:when test="normalize-space(Status/Item)='CPU Disabled by BIOS (POST Error)' ">
						<xsl:value-of select="3"/>
					</xsl:when>
					<xsl:when test="normalize-space(Status/Item)='CPU is Idle, waiting to be enabled' ">
						<xsl:value-of select="4"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="0"/>
					</xsl:otherwise>
				</xsl:choose>
			</ProcessorStatus>
			<Manufacturer>
				<xsl:value-of select="normalize-space(Processor_Manufacturer)"/>
			</Manufacturer>
			<!--<Family>178</Family> -->
			<MaxSpeed>
				<xsl:attribute name="unit"> MHz</xsl:attribute>
				<xsl:variable name="MS_res">
					<xsl:call-template name="hexToDec">
						<xsl:with-param name="hexVal" select="normalize-space(Max_Speed)"/>
						<xsl:with-param name="decVal" select="0"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:value-of select="$MS_res"/>
			</MaxSpeed>
			<CurSpeed>
				<xsl:attribute name="unit"> MHz</xsl:attribute>
				<xsl:variable name="CS_res">
					<xsl:call-template name="hexToDec">
						<xsl:with-param name="hexVal" select="normalize-space(Current_Speed)"/>
						<xsl:with-param name="decVal" select="0"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:value-of select="$CS_res"/>
			</CurSpeed>
			<ExtClockSpeed>
				<xsl:attribute name="unit"> MHz</xsl:attribute>
				<xsl:variable name="ECS_res">
					<xsl:call-template name="hexToDec">
						<xsl:with-param name="hexVal" select="normalize-space(External_Clock)"/>
						<xsl:with-param name="decVal" select="0"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:value-of select="$ECS_res"/>
			</ExtClockSpeed>
			<Voltage>
				<xsl:attribute name="unit"> v</xsl:attribute>
				<xsl:choose>
					<xsl:when test="count(Voltage/Item) = 1">
						<xsl:if test="Voltage/Item = 'Legacy' ">
							<!--XLATE-->5<!--XLATE -->
						</xsl:if>
					</xsl:when>
					<xsl:when test="count(Voltage/Item) > 1">
						<!--XLATE-->3.3<!--XLATE -->
					</xsl:when>
				</xsl:choose>
			</Voltage>
			<Upgrade>
				<xsl:value-of select="normalize-space(Processor_Upgrade)"/>
			</Upgrade>
			<Version>
				<xsl:value-of select="normalize-space(Processor_Version) "/>
			</Version>
		</DevProcessor>
	</xsl:template>
	<xsl:template match="Memory_Device">
		<PortGeneric>
			<ConnectorType>
				<xsl:value-of select="Form_Factor/Item"/>
			</ConnectorType>
			<MemoryDevice>
				<Size>
					<xsl:attribute name="unit"> KB</xsl:attribute>
					<xsl:variable name="MSKB_res">
						<xsl:call-template name="hexToDec">
							<xsl:with-param name="hexVal" select="substring-after(Size,'x')"/>
							<xsl:with-param name="decVal" select="0"/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:value-of select="$MSKB_res * 1024"/>
				</Size>
				<SizeMB>
					<xsl:attribute name="unit"> MB</xsl:attribute>
					<xsl:variable name="MSMB_res">
						<xsl:call-template name="hexToDec">
							<xsl:with-param name="hexVal" select="substring-after(Size,'x')"/>
							<xsl:with-param name="decVal" select="0"/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:value-of select="$MSMB_res"/>
				</SizeMB>
				<MemDevType>
					<xsl:choose>
						<xsl:when test="substring(Memory_Type/Item,1,7) = 'UNKNOWN'">
							<xsl:value-of select="substring(Memory_Type/Item,27,4)"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="Memory_Type/Item"/>
						</xsl:otherwise>
					</xsl:choose>
				</MemDevType>
				<TypeDetail>
					<xsl:value-of select="Type_Detail/Item"/>
				</TypeDetail>
			</MemoryDevice>
		</PortGeneric>
	</xsl:template>
	<xsl:template name="MemArrays" match="Physical_Memory_Array">
		<xsl:param name="MaxPhysical"/>
		<MemoryArrayList>
			<xsl:attribute name="count"><xsl:value-of select="count(//Physical_Memory_Array)"/></xsl:attribute>
			<MemoryArray>
				<Location>
					<xsl:choose>
						<xsl:when test="Physical_Memory_Array/Location/Item='Other'">
							<xsl:value-of select="1"/>
						</xsl:when>
						<xsl:when test="Physical_Memory_Array/Location/Item='System Board or Motherboard'">
							<xsl:value-of select="3"/>
						</xsl:when>
						<xsl:when test="Physical_Memory_Array/Location/Item='ISA Add-on Card'">
							<xsl:value-of select="4"/>
						</xsl:when>
						<xsl:when test="Physical_Memory_Array/Location/Item='EISA Add-on Card'">
							<xsl:value-of select="5"/>
						</xsl:when>
						<xsl:when test="Physical_Memory_Array/Location/Item='PCI Add-on Card'">
							<xsl:value-of select="6"/>
						</xsl:when>
						<xsl:when test="Physical_Memory_Array/Location/Item='MCA Add-on Card'">
							<xsl:value-of select="7"/>
						</xsl:when>
						<xsl:when test="Physical_Memory_Array/Location/Item='PCMCIA Add-on Card'">
							<xsl:value-of select="8"/>
						</xsl:when>
						<xsl:when test="Physical_Memory_Array/Location/Item ='Proprietary add-on card'">
							<xsl:value-of select="9"/>
						</xsl:when>
						<xsl:when test="Physical_Memory_Array/Location/Item='NuBus'">
							<xsl:value-of select="16"/>
						</xsl:when>
						<xsl:when test="Physical_Memory_Array/Location/Item='PC-98/C20 Add-on Card'">
							<xsl:value-of select="160"/>
						</xsl:when>
						<xsl:when test="Physical_Memory_Array/Location/Item='PC-98/C24 Add-on Card'">
							<xsl:value-of select="161"/>
						</xsl:when>
						<xsl:when test="Physical_Memory_Array/Location/Item='PC-98/E Add-on Card'">
							<xsl:value-of select="162"/>
						</xsl:when>
						<xsl:when test="Physical_Memory_Array/Location/Item='PC-98/Local Bus Add-on Card'">
							<xsl:value-of select="163"/>
						</xsl:when>
						<xsl:when test="Physical_Memory_Array/Location/Item='PC-98/Card Slot Add-on Card'">
							<xsl:value-of select="164"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="3"/>
						</xsl:otherwise>
					</xsl:choose>
				</Location>
				<Use>
					<xsl:choose>
						<xsl:when test="Physical_Memory_Array/Use/Item='System memory'">
							<xsl:value-of select="3"/>
						</xsl:when>
						<xsl:when test="Physical_Memory_Array/Use/Item='Video memory'">
							<xsl:value-of select="4"/>
						</xsl:when>
						<xsl:when test="Physical_Memory_Array/Use/Item='Flash memory'">
							<xsl:value-of select="5"/>
						</xsl:when>
						<xsl:when test="Physical_Memory_Array/Use/Item='Non-Volatile RAM'">
							<xsl:value-of select="6"/>
						</xsl:when>
						<xsl:when test="Physical_Memory_Array/Use/Item='Cache memory'">
							<xsl:value-of select="7"/>
						</xsl:when>
					</xsl:choose>
				</Use>
				<ErrCorrType>
					<xsl:choose>
						<xsl:when test="Physical_Memory_Array/Memory_Error_Correction/Item ='Multi-bit ECC'">
							<xsl:value-of select="6"/>
						</xsl:when>
						<xsl:when test="Physical_Memory_Array/Memory_Error_Correction/Item ='Single-bit ECC'">
							<xsl:value-of select="5"/>
						</xsl:when>
						<xsl:when test="Physical_Memory_Array/Memory_Error_Correction/Item ='Parity'">
							<xsl:value-of select="4"/>
						</xsl:when>
						<xsl:when test="Physical_Memory_Array/Memory_Error_Correction/Item ='CRC'">
							<xsl:value-of select="7"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="1"/>
						</xsl:otherwise>
					</xsl:choose>
				</ErrCorrType>
				<NumSocketsTotal>
					<xsl:variable name="Scnt_res">
						<xsl:call-template name="hexToDec">
							<xsl:with-param name="hexVal" select="substring-after(Physical_Memory_Array/Number_of_Memory_Devices,'x')"/>
							<xsl:with-param name="decVal" select="0"/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:value-of select="$Scnt_res"/>
				</NumSocketsTotal>
				<!-- This gets messy. on 4G boxes there can be multiple Memory Arrays some 2 some 4
			      All others use just one logical array-->
				<NumSocketsInUse>
					<xsl:variable name="Scnt_res">
						<xsl:call-template name="hexToDec">
							<xsl:with-param name="hexVal" select="substring-after(Physical_Memory_Array/Number_of_Memory_Devices,'x')"/>
							<xsl:with-param name="decVal" select="0"/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:call-template name="Cnt_Mem">
						<xsl:with-param name="MemSlots" select="number($Scnt_res)"/>
					</xsl:call-template>
					<!--				<xsl:choose>
				   <xsl:when test="count(Memory_Array_Mapped_Address) = 2" >
		    			<xsl:value-of select="count(Memory_Device/Size = '0x0')"/>
				   </xsl:when>	
				   <xsl:when test="count(Memory_Array_Mapped_Address) = 3" >
		    			<xsl:value-of select="count(Memory_Device_Mapped_Address)-8"/>
				   </xsl:when>	
				   <xsl:otherwise>
		    			<xsl:value-of select="count(Memory_Device[string-length(normalize-space(Size))> 3])"/>
                                   </xsl:otherwise>
                                </xsl:choose>	
-->
				</NumSocketsInUse>
				<MaxSize>
					<xsl:attribute name="unit"> KB</xsl:attribute>
					<xsl:variable name="MSKB_res">
						<xsl:call-template name="hexToDec">
							<xsl:with-param name="hexVal" select="substring-after(Physical_Memory_Array/Maximum_Capacity,'x')"/>
							<xsl:with-param name="decVal" select="0"/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:value-of select="$MSKB_res "/>
				</MaxSize>
				<MaxSizeMB>
					<xsl:attribute name="unit"> MB</xsl:attribute>
					<xsl:variable name="MSMB_res">
						<xsl:call-template name="hexToDec">
							<xsl:with-param name="hexVal" select="substring-after(Physical_Memory_Array/Maximum_Capacity,'x')"/>
							<xsl:with-param name="decVal" select="0"/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:value-of select="round($MSMB_res div 1024)"/>
				</MaxSizeMB>
				<MemPortConnList>
					<xsl:attribute name="count"><xsl:variable name="Mcnt_res"><xsl:call-template name="hexToDec"><xsl:with-param name="hexVal" select="substring-after(Physical_Memory_Array/Number_of_Memory_Devices,'x')"/><xsl:with-param name="decVal" select="0"/></xsl:call-template></xsl:variable><xsl:value-of select="$Mcnt_res"/></xsl:attribute>
					<xsl:apply-templates select="Memory_Device"/>
				</MemPortConnList>
				<InstalledSizeMBCumulative>
					<xsl:attribute name="unit"> MB</xsl:attribute>
<!--					<xsl:variable name="tmem_res">
						<xsl:call-template name="hexToDec">
							<xsl:with-param name="hexVal" select="substring-after($MaxPhysical,'x')"/>
							<xsl:with-param name="decVal" select="0"/>
						</xsl:call-template>
					</xsl:variable>
-->
          <xsl:variable name="Temp_sum">
            <xsl:call-template name="Sum_Mem">
              <xsl:with-param name="MemSlots" select="count(//Memory_Device)"/>
            </xsl:call-template>
          </xsl:variable>
          <xsl:value-of select="number($Temp_sum)"/>
        </InstalledSizeMBCumulative>
			</MemoryArray>
		</MemoryArrayList>
	</xsl:template>
	<xsl:template name="SlotInfo">
		<xsl:param name="SlotID"/>
		<xsl:for-each select="//PCISlot[number(@slotnum) = number($SlotID)]">
			<xsl:choose>
				<xsl:when test="count(DeviceName) > 0">
					<xsl:value-of select="DeviceName"/>
				</xsl:when>
			</xsl:choose>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="SlotDev">
		<xsl:param name="SlotID"/>
		<xsl:param name="DevType"/>
		<xsl:for-each select="//PCISlot[number(@slotnum) = number($SlotID)]">
			<xsl:choose>
				<xsl:when test="count(DeviceName/Device_Type_Instance) > 0">
					<xsl:for-each select="DeviceName">
						<xsl:if test="./Device_Type_Instance=$DevType">
							<xsl:value-of select="."/>
						</xsl:if>
					</xsl:for-each>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="."/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="SlotZero">
		<xsl:for-each select="//PCISlot[number(@slotnum) = 0]">
			<xsl:for-each select="DeviceName">
				<Slot index="0" status="4" oid="wmi01001">
					<Type>1</Type>
					<Length>0</Length>
					<IsVolt5> </IsVolt5>
					<IsVolt33> </IsVolt33>
					<IsPMECapable>
						<xsl:value-of select="PowerManagmentEnabled"/>
					</IsPMECapable>
					<HotPlugSystemSlot>
						<DataBusWidth>0</DataBusWidth>
						<SlotSpeed>0</SlotSpeed>
					</HotPlugSystemSlot>
					<SlotDevice>
						<DeviceDesc>Embedded</DeviceDesc>
					</SlotDevice>
					<SlotID>0x0<!-- hard code to zero-->
					</SlotID>
					<ExtName>
						<xsl:value-of select="."/>
					</ExtName>
				</Slot>
			</xsl:for-each>
		</xsl:for-each>
		<xsl:for-each select="//OnBoard_Device_Extended_Information">
			<Slot index="0" status="4" oid="4101001">
				<Type>1</Type>
				<Length>0</Length>
				<IsVolt5> </IsVolt5>
				<IsVolt33> </IsVolt33>
				<IsPMECapable>
					<xsl:value-of select="PowerManagmentEnabled"/>
				</IsPMECapable>
				<HotPlugSystemSlot>
					<DataBusWidth>0</DataBusWidth>
					<SlotSpeed>0</SlotSpeed>
				</HotPlugSystemSlot>
				<SlotDevice>
					<DeviceDesc>Embedded</DeviceDesc>
				</SlotDevice>
				<SlotID>0x0<!-- hard code to zero-->
				</SlotID>
				<ExtName>
					<xsl:call-template name="SlotDev">
						<xsl:with-param name="SlotID" select="substring-after(normalize-space(Bus_Number),'x')"/>
						<xsl:with-param name="DevType">
							<xsl:choose>
								<xsl:when test="substring-after(normalize-space(Device_Type_Instance),'x') = '1' ">
									<!-- XLATESTART-->e<!-- XLATEEND-->
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="substring-after(normalize-space(Device_Type_Instance),'x')"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:with-param>
					</xsl:call-template>
				</ExtName>
			</Slot>
		</xsl:for-each>
	</xsl:template>
	<xsl:template match="System_Slots">
		<Slot>
			<xsl:variable name="SlotOID">
				<xsl:value-of select="substring-after( Type,'x') "/>
				<xsl:value-of select="substring-after( Length,'x') "/>
				<xsl:value-of select="substring-before(substring-after( Handle,'x'),'&#xA;') "/>
			</xsl:variable>
			<xsl:attribute name="index"><!--				<xsl:variable name="ndx_res">
  				<xsl:call-template name="hexToDec">
    				<xsl:with-param name="hexVal" select="Slot_ID"/>
    				<xsl:with-param name="decVal" select="0"/>
  				</xsl:call-template>
				</xsl:variable>
			<xsl:value-of select="$ndx_res"/>--><xsl:value-of select="substring-after(normalize-space(Slot_ID),'x')"/></xsl:attribute>
			<!--   			Not needed for temp -->
			<xsl:attribute name="status"><xsl:choose><xsl:when test="Current_Usage/Item='Unavailable'"><xsl:value-of select="1"/></xsl:when><xsl:when test="Current_Usage/Item='Available'"><xsl:value-of select="3"/></xsl:when><xsl:when test="Current_Usage/Item='In use'"><xsl:value-of select="4"/></xsl:when><xsl:otherwise><xsl:value-of select="0"/></xsl:otherwise></xsl:choose></xsl:attribute>
			<xsl:attribute name="oid"><xsl:value-of select="$SlotOID"/></xsl:attribute>
			<Type>
				<xsl:choose>
					<xsl:when test="substring(Slot_Type/Item,1,7)='UNKNOWN'">
						<xsl:variable name="ttype">
							<xsl:call-template name="hexToDec">
								<xsl:with-param name="hexVal" select="substring-after(Slot_Type/Item,'value:')"/>
								<xsl:with-param name="decVal" select="0"/>
							</xsl:call-template>
							<!--	<xsl:value-of select="substring(Slot_Data_Bus_Width/Item,27,4)" /> -->
						</xsl:variable>
						<xsl:value-of select="$ttype"/>
					</xsl:when>
					<xsl:when test="Slot_Type/Item='PCI'">
						<xsl:value-of select="6"/>
					</xsl:when>
					<xsl:when test="Slot_Type/Item='PCI-X'">
						<xsl:value-of select="18"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="1"/>
					</xsl:otherwise>
				</xsl:choose>
			</Type>
			<Length>
				<xsl:choose>
					<xsl:when test="Slot_Length='Other'">
						<xsl:value-of select="1"/>
					</xsl:when>
					<xsl:when test="Slot_Length='Short Length'">
						<xsl:value-of select="3"/>
					</xsl:when>
					<xsl:when test="Slot_Length='Long Length'">
						<xsl:value-of select="4"/>
					</xsl:when>
					<xsl:when test="Slot_Length='Long Length'">
						<xsl:value-of select="4"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="4"/>
					</xsl:otherwise>
				</xsl:choose>
			</Length>
			<SlotID>
				<!--
				<xsl:variable name="id_res">
  				<xsl:call-template name="hexToDec">
    				<xsl:with-param name="hexVal" select="//Slot_ID"/>
    				<xsl:with-param name="decVal" select="0"/>
  				</xsl:call-template>
				</xsl:variable>
			<xsl:value-of select="$id_res"/> -->
				<xsl:value-of select="normalize-space(Slot_ID)"/>
			</SlotID>
			<xsl:choose>
				<xsl:when test="Slot_Characteristics_1/Item='Provides 3.3 volts'">
					<IsVolt5>false</IsVolt5>
					<IsVolt33>true</IsVolt33>
				</xsl:when>
				<xsl:otherwise>
					<IsVolt5>true</IsVolt5>
					<IsVolt33>false</IsVolt33>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:choose>
				<xsl:when test="Slot_Characteristics_2/Item='PCI slot supports Power Management Enable (PME) signal'">
					<IsPMECapable>true</IsPMECapable>
				</xsl:when>
				<xsl:otherwise>
					<IsPMECapable>false</IsPMECapable>
				</xsl:otherwise>
			</xsl:choose>
			<HotPlugSystemSlot>
				<DataBusWidth>
					<xsl:choose>
						<xsl:when test="Slot_Data_Bus_Width/Item ='32x or x32' ">
							<xsl:value-of select="14"/>
						</xsl:when>
						<xsl:when test="Slot_Data_Bus_Width/Item ='16x or x16' ">
							<xsl:value-of select="13"/>
						</xsl:when>
						<xsl:when test="Slot_Data_Bus_Width/Item ='12x or x12' ">
							<xsl:value-of select="12"/>
						</xsl:when>
						<xsl:when test="Slot_Data_Bus_Width/Item ='8x or x8' ">
							<xsl:value-of select="11"/>
						</xsl:when>
						<xsl:when test="Slot_Data_Bus_Width/Item ='4x or x4' ">
							<xsl:value-of select="10"/>
						</xsl:when>
						<xsl:when test="Slot_Data_Bus_Width/Item ='2x or x2' ">
							<xsl:value-of select="9"/>
						</xsl:when>
						<xsl:when test="Slot_Data_Bus_Width/Item ='1x or x1' ">
							<xsl:value-of select="8"/>
						</xsl:when>
						<xsl:when test="Slot_Data_Bus_Width/Item ='128 bit'">
							<xsl:value-of select="7"/>
						</xsl:when>
						<xsl:when test="Slot_Data_Bus_Width/Item ='64 bit'">
							<xsl:value-of select="6"/>
						</xsl:when>
						<xsl:when test="Slot_Data_Bus_Width/Item ='32 bit'">
							<xsl:value-of select="5"/>
						</xsl:when>
						<xsl:when test="Slot_Data_Bus_Width/Item ='16 bit'">
							<xsl:value-of select="4"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="1"/>
						</xsl:otherwise>
					</xsl:choose>
				</DataBusWidth>
				<SlotSpeed>0</SlotSpeed>
			</HotPlugSystemSlot>
			<SlotDevice>
				<xsl:choose>
					<xsl:when test="Current_Usage">
						<DeviceDesc>
							<xsl:value-of select="Current_Usage/Item"/>
						</DeviceDesc>
					</xsl:when>
				</xsl:choose>
			</SlotDevice>
			<ExtName>
				<xsl:choose>
					<xsl:when test="number(substring-after(normalize-space(Slot_ID),'x')) >0">
						<xsl:call-template name="SlotInfo">
							<xsl:with-param name="SlotID" select="substring-after(normalize-space(Slot_ID),'x')"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="ExtName"/>
					</xsl:otherwise>
				</xsl:choose>
			</ExtName>
		</Slot>
	</xsl:template>
	<!--	Here is where we begin the supporting functions templates-->
	<!-- This function is recursive-->
	<xsl:template name="Sum_Mem">
		<xsl:param name="MemSlots"/>
		<xsl:param name="TOT">0</xsl:param>
		<xsl:if test="$MemSlots = 0">
			<xsl:value-of select="$TOT"/>
		</xsl:if>
		<xsl:if test="$MemSlots &gt; 0">
			<xsl:variable name="Tempval">
				<xsl:call-template name="hexToDec">
					<xsl:with-param name="hexVal" select="substring-after(Memory_Device[$MemSlots]/Size,'x')"/>
					<xsl:with-param name="decVal" select="0"/>
				</xsl:call-template>
			</xsl:variable>
			<xsl:choose>
				<xsl:when test="$Tempval &gt; 0">
					<xsl:call-template name="Sum_Mem">
						<xsl:with-param name="MemSlots" select="number($MemSlots) - 1"/>
						<!-- Now pass in the value from current  DIMM to add to total-->
						<xsl:with-param name="TOT" select="number($TOT) + number($Tempval)"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="Sum_Mem">
						<xsl:with-param name="MemSlots" select="number($MemSlots) - 1"/>
						<xsl:with-param name="TOT" select="number($TOT)"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
	</xsl:template>
	<xsl:template name="Cnt_Mem">
		<xsl:param name="MemSlots"/>
		<xsl:param name="CNT">0</xsl:param>
		<xsl:if test="$MemSlots = 0">
			<xsl:value-of select="$CNT"/>
		</xsl:if>
		<xsl:if test="$MemSlots &gt; 0">
			<xsl:variable name="Tempval">
				<xsl:call-template name="hexToDec">
					<xsl:with-param name="hexVal" select="substring-after(Memory_Device[$MemSlots]/Size,'x')"/>
					<xsl:with-param name="decVal" select="0"/>
				</xsl:call-template>
			</xsl:variable>
			<xsl:choose>
				<xsl:when test="$Tempval &gt; 0">
					<xsl:call-template name="Cnt_Mem">
						<xsl:with-param name="MemSlots" select="number($MemSlots) - 1"/>
						<xsl:with-param name="CNT" select="number($CNT) + 1"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="Cnt_Mem">
						<xsl:with-param name="MemSlots" select="number($MemSlots) - 1"/>
						<xsl:with-param name="CNT" select="number($CNT)"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
	</xsl:template>
	<xsl:template name="Cnt_Slots">
		<xsl:param name="CNT"/>
		<xsl:for-each select="Memory_Device">
			<xsl:choose>
				<xsl:when test="Size = '0x0'"/>
				<xsl:otherwise>
					<xsl:value-of select="$CNT + 1"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>
		<xsl:value-of select="$CNT"/>
	</xsl:template>
	<xsl:template name="singleHexToDec">
		<xsl:param name="hex"/>
		<xsl:variable name="table" select="'0123456789abcdef'"/>
		<xsl:value-of select="string-length(substring-before($table,$hex))"/>
	</xsl:template>
	<xsl:template name="hexToDec">
		<xsl:param name="hexVal"/>
		<xsl:param name="decVal"/>
		<xsl:variable name="hexLength" select="string-length(normalize-space($hexVal))"/>
		<xsl:choose>
			<xsl:when test="$hexLength &gt; 0">
				<xsl:variable name="hexPos">
					<xsl:call-template name="singleHexToDec">
						<xsl:with-param name="hex" select="substring($hexVal,1,1)"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:variable name="powerof">
					<xsl:if test="$hexLength = 9">
						<xsl:value-of select="4294967296"/>
					</xsl:if>
					<xsl:if test="$hexLength = 8">
						<xsl:value-of select="268435456"/>
					</xsl:if>
					<xsl:if test="$hexLength = 7">
						<xsl:value-of select="16777216"/>
					</xsl:if>
					<xsl:if test="$hexLength = 6">
						<xsl:value-of select="1048576"/>
					</xsl:if>
					<xsl:if test="$hexLength = 5">
						<xsl:value-of select="65536"/>
					</xsl:if>
					<xsl:if test="$hexLength = 4">
						<xsl:value-of select="4096"/>
					</xsl:if>
					<xsl:if test="$hexLength = 3">
						<xsl:value-of select="256"/>
					</xsl:if>
					<xsl:if test="$hexLength = 2">
						<xsl:value-of select="16"/>
					</xsl:if>
					<xsl:if test="$hexLength = 1">
						<xsl:value-of select="1"/>
					</xsl:if>
					<xsl:if test="$hexLength = 0">
						<xsl:value-of select="0"/>
					</xsl:if>
				</xsl:variable>
				<xsl:variable name="addToDec">
					<xsl:value-of select="(number($hexPos) * number($powerof))"/>
					<!--			  <xsl:call-template name="raiseToPower">
				<xsl:with-param name="number" select="(number($hexPos) * number($powerof))"/> 
				<xsl:with-param name="number" select="number($hexPos) * 16"/>
				<xsl:with-param name="power" select="$hexLength"/> 
			  </xsl:call-template>
-->
				</xsl:variable>
				<xsl:call-template name="hexToDec">
					<xsl:with-param name="hexVal" select="substring($hexVal,2)"/>
					<xsl:with-param name="decVal" select="(number($decVal) + number($addToDec))"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$decVal"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="raiseToPower">
		<xsl:param name="number"/>
		<xsl:param name="power"/>
		<xsl:choose>
			<xsl:when test="$number &gt; 0">
				<xsl:call-template name="raiseToPowerIter">
					<xsl:with-param name="multiplier" select="$number"/>
					<xsl:with-param name="accumulator" select="$power"/>
					<xsl:with-param name="reps" select="1"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="0"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="raiseToPowerIter">
		<xsl:param name="multiplier"/>
		<xsl:param name="accumulator"/>
		<xsl:param name="reps"/>
		<xsl:choose>
			<xsl:when test="$reps &gt; 0">
				<xsl:call-template name="raiseToPowerIter">
					<xsl:with-param name="multiplier" select="$multiplier"/>
					<xsl:with-param name="accumulator" select="$accumulator * $multiplier"/>
					<xsl:with-param name="reps" select="$reps - 1"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$accumulator"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="*"/>
</xsl:stylesheet>
