<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
	<xsl:strip-space elements="*"/>
	<xsl:output method="xml" indent="no"/>
	
	<xsl:template match="OMA">
	<OMA skin="modern">
		<DataArea>
			<xsl:choose>
				<xsl:when test="DRAC/@drac2='true'" >
					<PageTitle>
						<xsl:attribute name="display">DRAC II Information</xsl:attribute>
					</PageTitle>
					<xsl:for-each select="DRAC">
						<xsl:call-template name="DRAC2"/>
					</xsl:for-each>
				</xsl:when>
				<xsl:otherwise>
					<PageTitle>
						<xsl:attribute name="display">DRAC Information</xsl:attribute>
					</PageTitle>
					<xsl:call-template name="RAC"/>
				</xsl:otherwise>
			</xsl:choose>
		</DataArea>
		</OMA>
	</xsl:template>
	
	<xsl:template name="RAC">
			<xsl:for-each select="DRAC/RAC_Info">
				<ListData type="custom">
					<Data>
						<xsl:attribute name="display">RAC Datetime</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="RAC_Datetime"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">FW Version</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="FW_Version"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">FW Updated</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="FW_Updated"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">HW Version</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="HW_Version"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">Current IP</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="Cur_IP"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">Current IP Gateway</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="Cur_IP_Gate"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">Current IP Netmask</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="CUR_IP_Net"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">DHCP Enabled</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="DHCP_Enabled"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">MAC Address</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="MAC_Addr"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">Current DNS Server 1</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="Cur_DNS_1"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">Current DNS Server 2</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="Cur_DNS_2"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">DNS Server From DHCP</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="DNS_FM_DHCP"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">Registered DNS RAC Name</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="Reg_DNS_RAC_Name"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">DNS Server RAC Name</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="DNS_RAC_Name"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">Current DNS Domain</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="Cur_DNS_Domain"/></xsl:attribute>
					</Data>
				</ListData>
			</xsl:for-each>
			
			<xsl:for-each select="DRAC/Watchdog_Info">
				<TableData>
					<Header>
						<Data name="">
							<xsl:attribute name="value">Recovery Action</xsl:attribute>
						</Data>
						<Data name="">
							<xsl:attribute name="value">Countdown Value</xsl:attribute>
						</Data>
						<Data name="">
							<xsl:attribute name="value">Initial Countdown Value</xsl:attribute>
						</Data>
					</Header>
					<Row>
						<Data>
							<xsl:attribute name="value"><xsl:value-of select="Recovery_Action"/></xsl:attribute>
						</Data>
						<Data>
							<xsl:attribute name="value"><xsl:value-of select="Countdown_Value"/></xsl:attribute>
						
						</Data>
						<Data>
							<xsl:attribute name="value"><xsl:value-of select="Init_Countdown_Value"/></xsl:attribute>
						
						</Data>
					</Row>
				</TableData>
			</xsl:for-each>
			
			<xsl:for-each select="DRAC/RAC_FWStatus">
				<TableData>
					<Header>
						<Data>
							<xsl:attribute name="value">Global Reset Pending</xsl:attribute>
						</Data>
					</Header>
					<Row>
						<Data>
							<xsl:attribute name="value"><xsl:value-of select="Global_Reset_Pending"/></xsl:attribute>
						</Data>
					</Row>
				</TableData>
			</xsl:for-each>
			
			<xsl:for-each select="DRAC/Session_Summary">
				<TableData>
					<Header>
						<Data>
							<xsl:attribute name="value">Active Sessions</xsl:attribute>
						</Data>
						<Data>
							<xsl:attribute name="value">Available Sessions</xsl:attribute>
						</Data>
					</Header>
					<Row>
						<Data>
							<xsl:attribute name="value"><xsl:value-of select="Active"/></xsl:attribute>
						</Data>
						<Data>
							<xsl:attribute name="value"><xsl:value-of select="Available"/></xsl:attribute>
						</Data>
					</Row>
				</TableData>
			</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="DRAC2" match="DRAC">
				<ListData type="custom">
					<Data>
						<xsl:attribute name="display">Firmware Version</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="FW_Version"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">Firmware Build Date</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="FW_Updated"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">Processor</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="Proc_Version"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">Processor Speed</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="Proc_Speed"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">Memory Size</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="Memory_Size"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">ROM Size</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="ROM_Size"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">NVRAM Size</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="NVRAM_Size"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">Modem Type</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="Modem_Type"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">Host Bridge</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="Host_Bridge"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">Network Controller</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="Network_Controller"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">NIC Address</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="NIC_Addr"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">IP Address</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="IP_Address"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">Subnet Mask</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="Subnet_Mask"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">PCMCIA Controller</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="PCMCIA_Controller"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">PC Card Manufacturer</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="PC_Card_Man"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">PC Card Product Name</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="PC_Card_Product"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">Utility Build Date</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="Util_Bld_Date"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">Utility Build Time</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="Util_Bld_Time"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">Utility Version</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="Util_Version"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">Auto Recovery Method</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="Auto_Recovery_Method"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">Auto Recovery Timeout</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="Auto_Recovery_Timeout"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">HeartBeat Timeout</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="HeartBeat_Timeout"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">Server ID</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="Server_ID"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">Battery Type</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="Battery_Type"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">Battery Status</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="Battery_Status"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">Battery Charge State</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="Battery_Charge_State"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">Fast Charge Count</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="Fast_Charge_Count"/></xsl:attribute>
					</Data>
				</ListData>
	</xsl:template>
	
	<xsl:template name="smstatus">
		<xsl:param name="status"/>
		<xsl:param name="mssg"/>
		<xsl:choose>
			<xsl:when test="$status = '-1'">Command Unsuccessfull</xsl:when>
			<xsl:otherwise>SMStatus: <xsl:value-of select="$status"/></xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="*"/>
</xsl:stylesheet>
