<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:fo="http://www.w3.org/1999/XSL/Format">
  <xsl:variable name="currentObjs"><xsl:value-of select="/OMA/CurrentProbeList/CurrentProbe"/></xsl:variable>
  <xsl:variable name="currentpoid"><xsl:value-of select="/OMA/CurrentProbeList/@poid"/></xsl:variable>
  <xsl:variable name="varUnit">
    <xsl:choose>
      <xsl:when test="/OMA/@cli = 'true'"><xsl:value-of select="/OMA/UnitType"/></xsl:when>
      <xsl:otherwise>all</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>    

  <!-- This constant is needed for date functions -->
  <!-- This is the value for  Julian Date 01-01-1970 -->
  <xsl:variable name="jd19700101" select="2440588"/>

  <xsl:template match="OMA">
    <OMA skin="modern"> 
    <DataArea>
    <xsl:choose>
      <!-- Power Monitoring not available -->
      <xsl:when test="count(/OMA/PowerConsumptionDataObj) &lt; 1">
      <xsl:choose>
          <xsl:when test="count(/OMA/PowerProfilesObject) &lt; 1">
              <PromptText><xsl:value-of select="$strPowerProfilesNAMessage"/></PromptText>     
          </xsl:when>
          <xsl:otherwise>
              <xsl:apply-templates select="PowerProfilesObject"/>
          </xsl:otherwise>
        </xsl:choose>
          <PromptText><xsl:value-of select="$strPowerMonitoringNAMessage"/></PromptText>
      </xsl:when>
      <xsl:otherwise>
        <PageTitle>
          <xsl:attribute name="display"><xsl:value-of select="$strPowerConsumptionInfo"/></xsl:attribute>
          <xsl:choose>
            <xsl:when test="/OMA/@cli = 'true'">	</xsl:when>
            <xsl:otherwise>
              <xsl:attribute name="status"><xsl:value-of select="/OMA/ObjStatus"/></xsl:attribute>
            </xsl:otherwise>
          </xsl:choose>
        </PageTitle>
		<CustomButton>
			<Data link="true" name="Return">
				<xsl:attribute name="display"><xsl:value-of select=					"$strRetSystemSummary"/></xsl:attribute>
				<xsl:attribute name="href">syssum.xml</xsl:attribute>
			</Data>
		</CustomButton>
        <xsl:choose>
          <!-- Power Monitoring available, but error condition -->
          <xsl:when test="SMStatus != '0'">
              <TableData>
                <Header>
                  <Data>
                    <xsl:attribute name="display"><xsl:value-of select="$gstrError"/></xsl:attribute>
                    <xsl:attribute name="value"><xsl:value-of select="$gstrError"/></xsl:attribute>
                  </Data>
                </Header>
                <Row>
                  <Data>
                    <xsl:attribute name="display"><xsl:value-of select="$str"/></xsl:attribute>
                    <xsl:attribute name="value">
                      <xsl:call-template name="smstatus">
                        <xsl:with-param name="status"><xsl:value-of select="SMStatus"/></xsl:with-param>
                      </xsl:call-template>
                    </xsl:attribute>
                  </Data>
                </Row>
              </TableData>
          </xsl:when>
          <!-- Power Monitoring available and success condition -->
          <xsl:otherwise>
              <xsl:call-template name="CurrentSensorsData"/>
              <xsl:apply-templates select="PowerConsumptionDataObj"/>
              <xsl:apply-templates select="PowerProfilesObject"/>
              <!--xsl:apply-templates select="PowerKnobFanObject"/>
              <xsl:apply-templates select="PowerKnobMemoryObject"/>
              <xsl:apply-templates select="PowerKnobPstateObject "/-->
          </xsl:otherwise>
        </xsl:choose>
      </xsl:otherwise>
    </xsl:choose>
  </DataArea>

  </OMA>
  </xsl:template>

  <xsl:template name="CurrentSensorsData">
    <xsl:if test="count(/OMA/CurrentProbeList/CurrentProbe[SubType = '26']) &gt; 0">
      <xsl:call-template name="PowerConsumptionTable"/>
    </xsl:if>
    <xsl:if test="count(/OMA/CurrentProbeList/CurrentProbe[SubType = '23']) &gt; 0">
      <xsl:call-template name="AmperageInformationTable"/>
    </xsl:if>
  </xsl:template>

  <xsl:template name="AmperageInformationTable">
    <TableData name="ampinfo" columnspacing="false">
      <xsl:attribute name="display"><xsl:value-of select="$strAmperage"/></xsl:attribute>
      <SubHeader>
        <xsl:attribute name="display"><xsl:value-of select="$strAmperage"/></xsl:attribute>
      </SubHeader>
      <Header>
        <Data>
          <xsl:attribute name="display"><xsl:value-of select="$strLocation"/></xsl:attribute>
          <xsl:attribute name="value"><xsl:value-of select="$strLocation"/></xsl:attribute>
        </Data>
        <Data>
          <xsl:attribute name="display"><xsl:value-of select="$strReading"/></xsl:attribute>
          <xsl:attribute name="value"><xsl:value-of select="$strReading"/></xsl:attribute>
        </Data>
      </Header>
      <xsl:for-each select="/OMA/CurrentProbeList/CurrentProbe[SubType = '23']">
        <Row>
          <Data>
            <xsl:attribute name="value"><xsl:value-of select="ProbeLocation"/></xsl:attribute>
          </Data>
          <Data>
            <xsl:attribute name="value">
            <xsl:call-template name="formatDeciAmpsValue">
              <xsl:with-param name="value"><xsl:value-of select="ProbeReading"/></xsl:with-param>
            </xsl:call-template>
            </xsl:attribute>
          </Data>
        </Row>
      </xsl:for-each>
    </TableData>
  </xsl:template>

  <!--Power Headroom Table-->
   <xsl:template name="PowerHeadroomInformationTable">
   <xsl:if test="instHeadRoom!='65535'">
    <TableData name="pwrheadroominfo" columnspacing="false">
        <xsl:attribute name="display"><xsl:value-of select="$strPowerHeadroom"/></xsl:attribute>
      <SubHeader>
        <xsl:attribute name="display"><xsl:value-of select="$strPowerHeadroom"/></xsl:attribute>
      </SubHeader>
      <Header>
        <Data>
          <xsl:attribute name="display"><xsl:value-of select="$gstrAttribute"/></xsl:attribute>
          <xsl:attribute name="value"><xsl:value-of select="$gstrAttribute"/></xsl:attribute>
        </Data>
        <Data>
          <xsl:attribute name="display"><xsl:value-of select="$gstrValue"/></xsl:attribute>
          <xsl:attribute name="value"><xsl:value-of select="$gstrValue"/></xsl:attribute>
        </Data>
      </Header>
        <Row>
          <Data width="42%">
            <xsl:attribute name="display">
              <xsl:value-of select="$strSystemInstantaneousHeadroom"/>
            </xsl:attribute>
            <xsl:attribute name="value">
              <xsl:value-of select="$strSystemInstantaneousHeadroom"/>
            </xsl:attribute>
          </Data>
          <Data>
			<xsl:attribute name="display">
              <xsl:value-of select="$strSystemInstantaneousHeadroom"/>
            </xsl:attribute>
            <xsl:attribute name="value">
              <xsl:call-template name="formatWattValue">
                <xsl:with-param name="value"><xsl:value-of select="instHeadRoom"/></xsl:with-param>
                <xsl:with-param name="unit"><xsl:value-of select="$varUnit"/></xsl:with-param>
              </xsl:call-template>
            </xsl:attribute>
          </Data>
        </Row>
        <Row>
          <Data width="42%">
	        <xsl:attribute name="display"><xsl:value-of select="$strSystemPeakHeadroom"/></xsl:attribute>
            <xsl:attribute name="value"><xsl:value-of select="$strSystemPeakHeadroom"/></xsl:attribute>
          </Data>
         <Data>
            <xsl:attribute name="value">
              <xsl:call-template name="formatWattValue">
                <xsl:with-param name="value"><xsl:value-of select="peakHeadRoom"/></xsl:with-param>
                <xsl:with-param name="unit"><xsl:value-of select="$varUnit"/></xsl:with-param>
              </xsl:call-template>
            </xsl:attribute>
           </Data>
        </Row>	
    </TableData>
    </xsl:if>
  </xsl:template>

  <xsl:template name="PowerConsumptionTable">
    <TableData columnspacing="true" name="powerconinfo">
      <xsl:attribute name="display"><xsl:value-of select="$strPowerConsumption"/></xsl:attribute>
      <xsl:attribute name="status"><xsl:value-of select="ObjStatus"/></xsl:attribute>
      <SubHeader>
        <xsl:attribute name="display"><xsl:value-of select="$strPowerConsumption"/></xsl:attribute>
      </SubHeader>
      <xsl:if test="(/OMA/OMAUserRights = '7') or (/OMA/OMAUserRights = '3')">
        <!--<PromptText><xsl:value-of select="$strClickTheProbe"/></PromptText>-->
      </xsl:if>
      <Header>
        <Data ignoreonweb="true">
          <xsl:attribute name="display"><xsl:value-of select="$strIndex"/></xsl:attribute>
          <xsl:attribute name="value"><xsl:value-of select="$strIndex"/></xsl:attribute>
        </Data>
        <Data align="center">
          <xsl:attribute name="display"><xsl:value-of select="$strStatus"/></xsl:attribute>
          <xsl:attribute name="value"><xsl:value-of select="$strStatus"/></xsl:attribute>
        </Data>
        <Data>
          <xsl:attribute name="display"><xsl:value-of select="$strProbeName"/></xsl:attribute>
          <xsl:attribute name="value"><xsl:value-of select="$strProbeName"/></xsl:attribute>
        </Data>
        <Data align="center">
          <xsl:attribute name="display"><xsl:value-of select="$strReading"/></xsl:attribute>
          <xsl:attribute name="value"><xsl:value-of select="$strReading"/></xsl:attribute>
        </Data>
        <Data align="center">
          <xsl:attribute name="display"><xsl:value-of select="$strWarningThreshold"/></xsl:attribute>
          <xsl:attribute name="value"><xsl:value-of select="$strWarningThreshold"/></xsl:attribute>
        </Data>
        <Data align="center">
          <xsl:attribute name="display"><xsl:value-of select="$strFailureThreshold"/></xsl:attribute>
          <xsl:attribute name="value"><xsl:value-of select="$strFailureThreshold"/></xsl:attribute>
        </Data>
      </Header>
      <xsl:for-each select="/OMA/CurrentProbeList/CurrentProbe[SubType = '26']">
        <Row>
          <Data ignoreonweb="true">
            <xsl:attribute name="value"><xsl:value-of select="@index"/></xsl:attribute>
          </Data>
          <Data type="status">
            <xsl:attribute name="value"><xsl:value-of select="@status"/></xsl:attribute>
            <xsl:attribute name="align">center</xsl:attribute>
          </Data>
          <Data>
            <xsl:attribute name="value" ><xsl:value-of select="ProbeLocation"/></xsl:attribute>
          </Data>
          <Data>
            <xsl:attribute name="value">
              <xsl:call-template name="formatWattValue">
                <xsl:with-param name="value"><xsl:value-of select="ProbeReading"/></xsl:with-param>
                <xsl:with-param name="unit"><xsl:value-of select="$varUnit"/></xsl:with-param>
              </xsl:call-template>
            </xsl:attribute>
            <xsl:attribute name="align">center</xsl:attribute>
          </Data>
          <Data>
            <xsl:attribute name="value">
              <xsl:call-template name="formatWattValue">
                <xsl:with-param name="value"><xsl:value-of select="ProbeThresholds/UNCThreshold"/></xsl:with-param>
                <xsl:with-param name="unit"><xsl:value-of select="$varUnit"/></xsl:with-param>
              </xsl:call-template>
            </xsl:attribute>
            <xsl:attribute name="align">center</xsl:attribute>
          </Data>
          <Data>
            <xsl:attribute name="value">
              <xsl:call-template name="formatWattValue">
                <xsl:with-param name="value"><xsl:value-of select="ProbeThresholds/UCThreshold"/></xsl:with-param>
                <xsl:with-param name="unit"><xsl:value-of select="$varUnit"/></xsl:with-param>
              </xsl:call-template>
            </xsl:attribute>
            <xsl:attribute name="align">center</xsl:attribute>
          </Data>
        </Row>
      </xsl:for-each>
    </TableData>
  </xsl:template>

  <xsl:template match="PowerConsumptionDataObj">
	<xsl:if test="not(/OMA/EMPObj/type) or (/OMA/EMPObj/type != '17'  and /OMA/EMPObj/type != '33')">
		<xsl:call-template name="PowerHeadroomInformationTable"/>
	</xsl:if>
	<!-- in GUI, this is moved under Power Statistics tab whereas in CLI, need to retain-->
    <xsl:if test="/OMA/@cli = 'true'">
		<xsl:call-template name="CumulativePower"/>
		<xsl:call-template name="PeakPower"/>
		<xsl:call-template name="PowerInventory"/>
		<xsl:call-template name="PowerBudget"/>
	</xsl:if>
  </xsl:template>
  
	<xsl:template match="PowerProfilesObject">   
		<xsl:call-template name="prof_web"/>  
	</xsl:template>
  
  <!--xsl:template match="PowerKnobFanObject">
    <xsl:call-template name="Prof_Fan"/>
  </xsl:template>
  <xsl:template match="PowerKnobMemoryObject">
    <xsl:call-template name="Prof_Mem"/>
  </xsl:template>
  <xsl:template match="PowerKnobPstateObject">
    <xsl:call-template name="Prof_Knob"/>
  </xsl:template-->


  <xsl:template name="CumulativePower">
    <TableData columnspacing="true" name="cumlpower" >
      <xsl:attribute name="display"><xsl:value-of select="$strPowerTrackStats"/></xsl:attribute>
      <SubHeader>
        <xsl:attribute name="display"><xsl:value-of select="$strPowerTrackStats"/></xsl:attribute>
      </SubHeader>
      <Header>
        <Data>
          <xsl:attribute name="display"><xsl:value-of select="$strStatistic"/></xsl:attribute>
          <xsl:attribute name="value"><xsl:value-of select="$strStatistic"/></xsl:attribute>
        </Data>
        <Data>
          <xsl:attribute name="display"><xsl:value-of select="$strMeasureStartTime"/></xsl:attribute>
          <xsl:attribute name="value"><xsl:value-of select="$strMeasureStartTime"/></xsl:attribute>
        </Data>
        <Data>
          <xsl:attribute name="display"><xsl:value-of select="$strMeasureFinishTime"/></xsl:attribute>
          <xsl:attribute name="value"><xsl:value-of select="$strMeasureFinishTime"/></xsl:attribute>
        </Data>
        <Data align="center">
          <xsl:attribute name="display"><xsl:value-of select="$strReading"/></xsl:attribute>
          <xsl:attribute name="value"><xsl:value-of select="$strReading"/></xsl:attribute>
        </Data>
        <!-- DF361376: Special characters in Power Monitoring tab of T310_W2k8x64DC
        <xsl:if test="(/OMA/OMAUserRights = '7')">
          <Data align="center">
            <xsl:attribute name="display"><xsl:value-of select="$strResetReading"/></xsl:attribute>
            <xsl:attribute name="value"><xsl:value-of select="$strResetReading"/></xsl:attribute>
          </Data>
        </xsl:if>
        -->
      </Header>
      <Row>
        <Data>
          <xsl:attribute name="value"><xsl:value-of select="$strEnergyConsumption"/></xsl:attribute>
        </Data>
        <Data>
          <xsl:attribute name="value">
			<xsl:choose>
				<xsl:when test="/OMA/cwStartTimeDisplay">
					<xsl:value-of select="/OMA/cwStartTimeDisplay"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$strNA"/>
				</xsl:otherwise>
			</xsl:choose>
			<!--<xsl:variable name="varcwStartTime" select="cwStartTime"/>
			<xsl:choose>
				<xsl:when test="number($varcwStartTime)">
				
					<xsl:call-template name="float-to-date-time">
						<xsl:with-param name="value" select="$jd19700101 + (cwStartTime div	(24 * 60 * 60))"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise><xsl:value-of select="$strNA"/></xsl:otherwise>
			</xsl:choose>-->
		 </xsl:attribute>
         <xsl:attribute name="align">left</xsl:attribute>
        </Data>
        <Data>
          <xsl:attribute name="value">
			<xsl:choose>
				<xsl:when test="/OMA/cwFinishTimeDisplay">
					<xsl:value-of select="/OMA/cwFinishTimeDisplay"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$strNA"/>
				</xsl:otherwise>
			</xsl:choose>
			<!-- <xsl:value-of select="/OMA/cwFinishTimeDisplay"/> -->
			<!--<xsl:variable name="varpwStartTime" select="pwStartTime"/>
			<xsl:choose>
				<xsl:when test="number($varpwStartTime)">
					<xsl:call-template name="float-to-date-time">
						<xsl:with-param name="value" select="$jd19700101 + (pwStartTime div	(24 * 60 * 60))"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise><xsl:value-of select="$strNA"/></xsl:otherwise>
			</xsl:choose>-->
          </xsl:attribute>
          <xsl:attribute name="align">left</xsl:attribute>
        </Data>
        <Data>
          <xsl:attribute name="value">
            <xsl:call-template name="formatKiloWattValue">
              <xsl:with-param name="value"><xsl:value-of select="cumulativeWatts"/></xsl:with-param>
            </xsl:call-template>
          </xsl:attribute>
          <xsl:attribute name="align">center</xsl:attribute>
        </Data>
        <!-- DF361376: Special characters in Power Monitoring tab of T310_W2k8x64DC
        <xsl:if test="(/OMA/OMAUserRights = '7')">
          <Data id="resetreadid" type="button">
            <xsl:attribute name="value"><xsl:value-of select="$strReset"/></xsl:attribute>
            <xsl:attribute name="tablebutton">true</xsl:attribute>
            <xsl:attribute name="href">javascript:resetreadings(1)</xsl:attribute>
            <xsl:attribute name="formSubmit">true</xsl:attribute>
            <xsl:attribute name="align">center</xsl:attribute>
          </Data>
        </xsl:if>
        -->
      </Row>
    </TableData>
  </xsl:template>
  
  <xsl:template name="PeakPower">
    <TableData columnspacing="true" name="peakpower">
      <Header>
        <Data>
          <xsl:attribute name="display"><xsl:value-of select="$strStatistic"/></xsl:attribute>
          <xsl:attribute name="value"><xsl:value-of select="$strStatistic"/></xsl:attribute>
        </Data>
        <Data>
          <xsl:attribute name="display"><xsl:value-of select="$strMeasureStartTime"/></xsl:attribute>
          <xsl:attribute name="value"><xsl:value-of select="$strMeasureStartTime"/></xsl:attribute>
        </Data>
        <Data>
          <xsl:attribute name="display"><xsl:value-of select="$strPeakTime"/></xsl:attribute>
          <xsl:attribute name="value"><xsl:value-of select="$strPeakTime"/></xsl:attribute>
        </Data>
        <Data align="center">
          <xsl:attribute name="display"><xsl:value-of select="$strPeakReading"/></xsl:attribute>
          <xsl:attribute name="value"><xsl:value-of select="$strPeakReading"/></xsl:attribute>
        </Data>
        <!-- DF361376 : Special characters in Power Monitoring tab of T310_W2k8x64DC
        <xsl:if test="(/OMA/OMAUserRights = '7')">
          <Data align="center">
            <xsl:attribute name="display"><xsl:value-of select="$strResetReading"/></xsl:attribute>
            <xsl:attribute name="value"><xsl:value-of select="$strResetReading"/></xsl:attribute>
          </Data>
        </xsl:if>
        -->
      </Header>
      <Row>
        <Data>
          <xsl:attribute name="value"><xsl:value-of select="$strSystemPeakPower"/></xsl:attribute>
        </Data>
        <Data>
          <xsl:attribute name="value">
			<xsl:choose>
				<xsl:when test="/OMA/pwStartTimeDisplay">
					<xsl:value-of select="/OMA/pwStartTimeDisplay"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$strNA"/>
				</xsl:otherwise>
			</xsl:choose>
		  <!-- <xsl:value-of select="/OMA/pwStartTimeDisplay"/> -->
		  <!--<xsl:variable name="varpwStartTime" select="pwStartTime"/>
			<xsl:choose>
			<xsl:when test="number($varpwStartTime)">
			 <xsl:call-template name="float-to-date-time">
				<xsl:with-param name="value" select="$jd19700101 + (pwStartTime div	(24 * 60 * 60))"/>
			</xsl:call-template>
			</xsl:when>
			<xsl:otherwise><xsl:value-of select="$strNA"/></xsl:otherwise>
			</xsl:choose>-->
         
          </xsl:attribute>
          <xsl:attribute name="align">left</xsl:attribute>
        </Data>
        <Data>
          <xsl:attribute name="value">
			<xsl:choose>
				<xsl:when test="/OMA/pwReadingTimeDisplay">
					<xsl:value-of select="/OMA/pwReadingTimeDisplay"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$strNA"/>
				</xsl:otherwise>
			</xsl:choose>
			<!--<xsl:value-of select="/OMA/pwReadingTimeDisplay"/> -->
		  <!--<xsl:variable name="varpwReadingTime" select="pwReadingTime"/>
			<xsl:choose>
			<xsl:when test="number($varpwReadingTime)">
			 <xsl:call-template name="float-to-date-time">
				<xsl:with-param name="value" select="$jd19700101 + (pwReadingTime div	(24 * 60 * 60))"/>
			</xsl:call-template>
			</xsl:when>
			<xsl:otherwise><xsl:value-of select="$strNA"/></xsl:otherwise>
			</xsl:choose>-->
          
          </xsl:attribute>
          <xsl:attribute name="align">left</xsl:attribute>
        </Data>
        <Data>
          <xsl:attribute name="value">
            <xsl:call-template name="formatWattValue">
                <xsl:with-param name="value"><xsl:value-of select="peakWatts"/></xsl:with-param>
            </xsl:call-template>
          </xsl:attribute>
          <xsl:attribute name="align">center</xsl:attribute>
        </Data>
        <!-- DF361376 : Special characters in Power Monitoring tab of T310_W2k8x64DC
        <xsl:if test="(/OMA/OMAUserRights = '7')">
          <Data id="resetreadid" rowspan="2" type="button">
            <xsl:attribute name="value"><xsl:value-of select="$strReset"/></xsl:attribute>
            <xsl:attribute name="tablebutton">true</xsl:attribute>
            <xsl:attribute name="href">javascript:resetreadings(2)</xsl:attribute>
            <xsl:attribute name="formSubmit">true</xsl:attribute>
            <xsl:attribute name="align">center</xsl:attribute>
          </Data>
        </xsl:if>
        -->
      </Row>
      <xsl:variable name="peakamp"><xsl:value-of select="peakAmps"/></xsl:variable>
      <xsl:if test="$peakamp != ''">
      <Row>
        <Data>
          <xsl:attribute name="value" ><xsl:value-of select="$strSystemPeakAmperage"/></xsl:attribute>
        </Data>
        <Data> 
          <xsl:attribute name="value">
			<xsl:choose>
				<xsl:when test="/OMA/paStartTimeDisplay">
					<xsl:value-of select="/OMA/paStartTimeDisplay"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$strNA"/>
				</xsl:otherwise>
			</xsl:choose>
		  <!-- <xsl:value-of select="/OMA/paStartTimeDisplay"/> -->
			<!--<xsl:variable name="varpaStartTime" select="paStartTime"/>
			<xsl:choose>
			<xsl:when test="number($varpaStartTime)">
				<xsl:call-template name="float-to-date-time">
					<xsl:with-param name="value" select="$jd19700101 + (paStartTime div	(24 * 60 * 60))"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise><xsl:value-of select="$strNA"/></xsl:otherwise>
			</xsl:choose>-->
          
          </xsl:attribute>
          <xsl:attribute name="align">left</xsl:attribute>
        </Data>
        <Data>
          <xsl:attribute name="value">
		  <xsl:choose>
				<xsl:when test="/OMA/paReadingTimeDisplay">
					<xsl:value-of select="/OMA/paReadingTimeDisplay"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$strNA"/>
				</xsl:otherwise>
			</xsl:choose>
		  <!--  <xsl:value-of select="/OMA/paReadingTimeDisplay"/> -->
		  <!--<xsl:variable name="varpaReadingTime" select="paReadingTime"/>
			<xsl:choose>
			<xsl:when test="number($varpaReadingTime)">
			 <xsl:call-template name="float-to-date-time">
				<xsl:with-param name="value" select="$jd19700101 + (paReadingTime div	(24 * 60 * 60))"/>
			</xsl:call-template>
			</xsl:when>
			<xsl:otherwise><xsl:value-of select="$strNA"/></xsl:otherwise>
			</xsl:choose>-->
        
          </xsl:attribute>
          <xsl:attribute name="align">left</xsl:attribute>
        </Data>
        <Data>
          <xsl:attribute name="value">
            <xsl:call-template name="formatDeciAmpsValue">
              <xsl:with-param name="value"><xsl:value-of select="peakAmps"/></xsl:with-param>
            </xsl:call-template>
          </xsl:attribute>
          <xsl:attribute name="align">center</xsl:attribute>
        </Data>
      </Row>
      </xsl:if>
    </TableData>
  </xsl:template>

  <xsl:template name="formatWattValue">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value = '-2147483648'"><xsl:value-of select="$strNA"/></xsl:when>
	  <xsl:when test="$value = '65535'"><xsl:value-of select="$strNA"/></xsl:when>
      <xsl:when test="$value = ''"><xsl:value-of select="$strNA"/></xsl:when>
      <xsl:otherwise><xsl:value-of select="$value"/><xsl:value-of select="$strWattUnit"/></xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="formatKiloWattValue">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value = '-2147483648'"><xsl:value-of select="$strNA"/></xsl:when>
	  <xsl:when test="$value = '65535'"><xsl:value-of select="$strNA"/></xsl:when>
      <xsl:when test="$value = ''"><xsl:value-of select="$strNA"/></xsl:when>
      <xsl:otherwise>
        <xsl:variable name="formatval"><xsl:value-of select="format-number($value div 1000,'##0.0')"/></xsl:variable>
					<xsl:variable name="univdecsep">
						<xsl:choose>
							<xsl:when test="substring(format-number(1.1,'##0.0'), 2, 1) = '.'">.</xsl:when>
							<xsl:when test="substring(format-number(1.1,'##0.0'), 2, 1) = ','">,</xsl:when>
						</xsl:choose>
					</xsl:variable>
					<xsl:variable name="localdecsep"><xsl:value-of select="$strDecimalFractionSeperator"/></xsl:variable>
					<xsl:value-of select="translate($formatval, $univdecsep,$localdecsep)"/><xsl:value-of select="$strKiloWattHrUnit"/>        
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="formatDeciAmpsValue">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value = '-2147483648'"><xsl:value-of select="$strNA"/></xsl:when>
	  <xsl:when test="$value = '65535'"><xsl:value-of select="$strNA"/></xsl:when>
      <xsl:when test="$value = ''"><xsl:value-of select="$strNA"/></xsl:when>
      <xsl:otherwise>
        <xsl:variable name="formatval"><xsl:value-of select="format-number($value div 10,'##0.0')"/></xsl:variable>
					<xsl:variable name="univdecsep">
						<xsl:choose>
							<xsl:when test="substring(format-number(1.1,'##0.0'), 2, 1) = '.'">.</xsl:when>
							<xsl:when test="substring(format-number(1.1,'##0.0'), 2, 1) = ','">,</xsl:when>
						</xsl:choose>
					</xsl:variable>
					<xsl:variable name="localdecsep"><xsl:value-of select="$strDecimalFractionSeperator"/></xsl:variable>
					<xsl:value-of select="translate($formatval, $univdecsep,$localdecsep)"/><xsl:value-of select="$strAmperageUnit"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  <xsl:template name="CLX">
  <Row >
	<Data>
	      <xsl:attribute name="value"><xsl:value-of select="$strEnableCap"/></xsl:attribute>
	      <xsl:attribute name="display"><xsl:value-of select="$strEnableCap"/></xsl:attribute>
	</Data>
	<Data align="center">
	<xsl:choose>
		<xsl:when test="powerCapSetting ='1'">
			<xsl:attribute name="value"><xsl:value-of select="$strEnabled"/></xsl:attribute>
		</xsl:when>
		<xsl:when test="powerCapSetting ='0'">
			<xsl:attribute name="value"><xsl:value-of select="$strDisabled"/></xsl:attribute>
		</xsl:when>
		<xsl:otherwise></xsl:otherwise>
	</xsl:choose>
	</Data>
      </Row>
      <xsl:element name="Row">
        <Data name="action">
          <xsl:attribute name="value"><xsl:value-of select="$strBudgetCap"/></xsl:attribute>
        </Data>
        <xsl:element name="Data">
          <xsl:attribute name="align">center</xsl:attribute>
          <xsl:attribute name="value">
            <xsl:choose>
              <xsl:when test="$varUnit = 'btuphr'">
                <xsl:call-template name="convertWattToBTUhr">
                  <xsl:with-param name="value"><xsl:value-of select="powerCap"/></xsl:with-param>
                </xsl:call-template>
                <xsl:text> ( </xsl:text>
                <xsl:call-template name="calculateFromWattToPercentage">
                  <xsl:with-param name="wattValue"><xsl:value-of select="powerCap"/></xsl:with-param>
                  <xsl:with-param name="minPower"><xsl:value-of select="minPower"/></xsl:with-param>
                  <xsl:with-param name="maxPower"><xsl:value-of select="maxPower"/></xsl:with-param>
                </xsl:call-template>
                <xsl:text>% )</xsl:text>
              </xsl:when>
              <xsl:otherwise>
                <xsl:call-template name="formatWattValue">
                  <xsl:with-param name="value"><xsl:value-of select="powerCap"/></xsl:with-param>
                </xsl:call-template>
                <xsl:text> ( </xsl:text>
                <xsl:call-template name="calculateFromWattToPercentage">
                  <xsl:with-param name="wattValue"><xsl:value-of select="powerCap"/></xsl:with-param>
                  <xsl:with-param name="minPower"><xsl:value-of select="minPower"/></xsl:with-param>
                  <xsl:with-param name="maxPower"><xsl:value-of select="maxPower"/></xsl:with-param>
                </xsl:call-template>
                <xsl:text>% )</xsl:text>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:attribute>            
        </xsl:element>
      </xsl:element>
  </xsl:template>
  
    <xsl:template name="PowerInventory">
    <TableData columnspacing="true" name="inventory" >
      <xsl:attribute name="display"><xsl:value-of select="$strPwrInventory"/></xsl:attribute>
	    <SubHeader>
        <xsl:attribute name="display"><xsl:value-of select="$strPwrInventory"/></xsl:attribute>
      </SubHeader>
      <Header>
        <Data>
          <xsl:attribute name="display"><xsl:value-of select="$gstrAttribute"/></xsl:attribute>
          <xsl:attribute name="value"><xsl:value-of select="$gstrAttribute"/></xsl:attribute>
        </Data>
        <Data>
          <xsl:attribute name="display"><xsl:value-of select="$gstrValue"/></xsl:attribute>
          <xsl:attribute name="value"><xsl:value-of select="$gstrValue"/></xsl:attribute>
        </Data>
       </Header>
      <Row>
        <Data>
          <xsl:attribute name="value"><xsl:value-of select="$strIdlePower"/></xsl:attribute>
        </Data>
        <Data>
	        <xsl:attribute name="value">
          <xsl:call-template name="formatWattValue">
            <xsl:with-param name="value"><xsl:value-of select="minPower"/></xsl:with-param>
            <xsl:with-param name="unit"><xsl:value-of select="$varUnit"/></xsl:with-param>            
	        </xsl:call-template>
	        </xsl:attribute>
        </Data>
	    </Row>
	    <Row>
         <Data>
          <xsl:attribute name="value"><xsl:value-of select="$strMaxPotentialPwrConsumption"/></xsl:attribute>
        </Data>
        <Data>
	        <xsl:attribute name="value">
            <xsl:call-template name="formatWattValue">
              <xsl:with-param name="value"><xsl:value-of select="maxPower"/></xsl:with-param>
              <xsl:with-param name="unit"><xsl:value-of select="$varUnit"/></xsl:with-param>            
            </xsl:call-template>
	      </xsl:attribute>
        </Data>
      </Row>
    </TableData>
  </xsl:template>
  


  <xsl:template name="PowerBudget">
    <TableData name="showbudget" columnspacing="true">
		  <xsl:attribute name="display"><xsl:value-of select="$strPowerBudget"/></xsl:attribute>
      <SubHeader>
        <xsl:attribute name="display"><xsl:value-of select="$strPowerBudget"/></xsl:attribute>
      </SubHeader>
      <xsl:if test="(/OMA/OMAUserRights = '7') and (powerCapCaps = '3')">
        <!--<PromptText><xsl:value-of select="$strEditPowerCap"/> ( 0% = <xsl:value-of select="minPower"/> <xsl:value-of select="$gstrWattUnit"/>, 100% = <xsl:value-of select="maxPower"/> <xsl:value-of select="$gstrWattUnit"/> )</PromptText>-->
      </xsl:if>
		  <Header>
			  <Data width="50%">
				  <xsl:attribute name="value"><xsl:value-of select="$gstrAttribute"/></xsl:attribute>
				  <xsl:attribute name="display"><xsl:value-of select="$gstrAttribute"/></xsl:attribute>
			  </Data>
        <Data name="h2" align="center" colspan="3">
        <xsl:attribute name="display"><xsl:value-of select="$gstrValues"/></xsl:attribute>
        <xsl:attribute name="value"><xsl:value-of select="$gstrValues"/></xsl:attribute>
        </Data>
      </Header>
      <xsl:call-template name="CLX"/>
    </TableData>
  </xsl:template>
  


<xsl:template name="prof_web">
 <xsl:if test="(/OMA/OMAUserRights = '7')">
<xsl:choose>
  <xsl:when test="profilesSupported/Custom = 'true'">
  <!--<PromptText><xsl:value-of select="$strPwrProfilesMsg"/><xsl:value-of select="$strPwrProfilesMsgWithCustom"/></PromptText>-->
</xsl:when>
<xsl:otherwise>
  <!--<PromptText><xsl:value-of select="$strPwrProfilesMsg"/></PromptText>-->
</xsl:otherwise>
</xsl:choose>
</xsl:if>
  <TableData name="profiles">
    <xsl:attribute name="display"><xsl:value-of select="$strPwrProfiles"/></xsl:attribute>
    <SubHeader>
      <xsl:attribute name="display"><xsl:value-of select="$strPwrProfiles"/></xsl:attribute>
    </SubHeader> 
      <Header>
			  <Data width="50%">
				  <xsl:attribute name="value"><xsl:value-of select="$gstrAttribute"/></xsl:attribute>
				  <xsl:attribute name="display"><xsl:value-of select="$gstrAttribute"/></xsl:attribute>
			  </Data>
        <Data name="h2" align="center" colspan="3">
        <xsl:attribute name="display"><xsl:value-of select="$gstrValues"/></xsl:attribute>
        <xsl:attribute name="value"><xsl:value-of select="$gstrValues"/></xsl:attribute>
        </Data>
      </Header>    
    <!--Header>
      <Data name="h1">
        <xsl:attribute name="value"><xsl:value-of select="$strSelectPwrProfile"/></xsl:attribute>
      </Data>
    </Header-->
    <xsl:if test="profilesSupported/MaxPerf = 'true'">
      <!--Row>
        <Data name="profiletype"-->
          <xsl:element name="Row">
            <Data name="action">
            <xsl:attribute name="value"><xsl:value-of select="$strProfileMaxPerformance"/></xsl:attribute>
            </Data>
        <xsl:element name="Data">
          <xsl:attribute name="align">center</xsl:attribute>
            <xsl:attribute name="value">
          <xsl:choose>
            <xsl:when test="curProfile/MaxPerf = 'true'"><xsl:value-of select="$strSelected"/></xsl:when>
            <xsl:otherwise><xsl:value-of select="$strNotSelected"/></xsl:otherwise>
          </xsl:choose>
          </xsl:attribute>
                  </xsl:element>
      </xsl:element>
        <!--/Data>
      </Row-->
    </xsl:if>
    <xsl:if test="profilesSupported/DellDBPM = 'true'">
      <!--Row>
        <Data name="profiletype"-->
          <xsl:element name="Row">
            <Data name="action">
          <xsl:attribute name="value"><xsl:value-of select="$strProfileATP"/></xsl:attribute>
          </Data>
        <xsl:element name="Data">
          <xsl:attribute name="align">center</xsl:attribute>
            <xsl:attribute name="value">
            <xsl:choose>
              <xsl:when test="curProfile/DellDBPM = 'true'"><xsl:value-of select="$strSelected"/></xsl:when>
              <xsl:otherwise><xsl:value-of select="$strNotSelected"/></xsl:otherwise>
            </xsl:choose>
           </xsl:attribute>
         </xsl:element>
      </xsl:element>
        <!--/Data>
      </Row-->
    </xsl:if>
    <xsl:if test="profilesSupported/OSDBPM = 'true'">
      <!--Row>
        <Data name="profiletype"-->
          <xsl:element name="Row">
            <Data name="action">
          <xsl:attribute name="value"><xsl:value-of select="$strProfileOSControl"/></xsl:attribute>
          </Data>
        <xsl:element name="Data">
          <xsl:attribute name="align">center</xsl:attribute>
          <xsl:attribute name="value">
          <xsl:choose>
            <xsl:when test="curProfile/OSDBPM = 'true'"><xsl:value-of select="$strSelected"/></xsl:when>
            <xsl:otherwise><xsl:value-of select="$strNotSelected"/></xsl:otherwise>
          </xsl:choose>
          </xsl:attribute>
        </xsl:element>
      </xsl:element>
        <!--/Data>
      </Row-->
    </xsl:if>
    <xsl:if test="profilesSupported/Custom = 'true'">
      <!--Row>
        <Data name="profiletype"-->
          <xsl:element name="Row">
            <Data name="action">
          <xsl:attribute name="value"><xsl:value-of select="$strProfileCustom"/></xsl:attribute>
          </Data>
        <xsl:element name="Data">
          <xsl:attribute name="align">center</xsl:attribute>
          <xsl:attribute name="value">
          <xsl:choose>
            <xsl:when test="curProfile/Custom = 'true'"><xsl:value-of select="$strSelected"/></xsl:when>
            <xsl:otherwise><xsl:value-of select="$strNotSelected"/></xsl:otherwise>
          </xsl:choose>
          </xsl:attribute>
        </xsl:element>
      </xsl:element>
        <!--/Data>
      </Row-->
    </xsl:if>
  </TableData>
   <xsl:if test="//curProfile/Custom = 'true'">
  <xsl:call-template name="CustomOptions"/>
  </xsl:if>
</xsl:template>
  
<xsl:template name="CustomOptions">
<xsl:if test="PowerKnobPstateObject !='null' or PowerKnobMemoryObject!='null' or PowerKnobFanObject!='null'">
  <TableData name="custprofiles" >
    <xsl:attribute name="display"><xsl:value-of select="$strPwrCustomOptions"/></xsl:attribute>
    <SubHeader>
      <xsl:attribute name="display"><xsl:value-of select="$strPwrCustomOptions"/></xsl:attribute>
    </SubHeader>
    <Header>
      <Data name="h1">
        <xsl:attribute name="value"><xsl:value-of select="$gstrAttribute"/></xsl:attribute>
      </Data>
      <Data name="h2" align="center">
        <xsl:attribute name="value"><xsl:value-of select="$gstrValue"/></xsl:attribute>
      </Data>      
    </Header> 
	<xsl:if test="//PowerKnobPstateObject"> 
          <Row>
            <Data name="pk_name" align="left" width="40%">
              <xsl:attribute name="value"><xsl:value-of select="$strProfileCPUPowerMgmt"/></xsl:attribute>
            </Data>
	    <Data name="pk_cpu" id="pk_cpu" align="center">
            <xsl:attribute name="display"><xsl:value-of select="$strProfileCPUPowerMgmt"/></xsl:attribute>
              <xsl:attribute name="value">
                <xsl:choose>
                  <xsl:when test="//PowerKnobPstateObject/currentState/min = 'true'"><xsl:value-of select="$strMinimumPower"/></xsl:when>
                  <xsl:when test="//PowerKnobPstateObject/currentState/max = 'true'"><xsl:value-of select="$strMaximumPerformance"/></xsl:when>
                  <xsl:when test="//PowerKnobPstateObject/currentState/System = 'true'"><xsl:value-of select="$strProfileSystemDBPM"/></xsl:when>
                  <xsl:when test="//PowerKnobPstateObject/currentState/OS = 'true'"><xsl:value-of select="$strProfileOSDBPM"/></xsl:when>
                  <xsl:otherwise><xsl:value-of select="$strNotSelected"/></xsl:otherwise>
                </xsl:choose>
              </xsl:attribute>
	  </Data>
          </Row>
	   </xsl:if>
        
        <!-- Power Knob - Memory Power Management -->
        <xsl:if test="//PowerKnobMemoryObject">
          <Row>
            <Data name="pk_name" align="left">
              <xsl:attribute name="value"><xsl:value-of select="$strProfileMemoryPowerMgmt"/></xsl:attribute>
            </Data>
            <Data name="pk_mem" id="pk_mem" align="center">
            <xsl:attribute name="display"><xsl:value-of select="$strProfileMemoryPowerMgmt"/></xsl:attribute>
              <xsl:attribute name="value">
              <xsl:choose>
                 <xsl:when test="//PowerKnobMemoryObject/currentState/freq_min = 'true'"><xsl:value-of select="$strMinimumPower"/></xsl:when>
		 <xsl:when test="//PowerKnobMemoryObject/currentState/freq_800 = 'true'"><xsl:value-of select="$str800MHz"/></xsl:when>
		 <xsl:when test="//PowerKnobMemoryObject/currentState/freq_1067 = 'true'"><xsl:value-of select="$str1067MHz"/></xsl:when>
		 <xsl:when test="//PowerKnobMemoryObject/currentState/freq_1333 = 'true'"><xsl:value-of select="$str1333MHz"/></xsl:when>
                 <xsl:when test="//PowerKnobMemoryObject/currentState/freq_max = 'true'"><xsl:value-of select="$strMaximumPerformance"/></xsl:when>
                <xsl:otherwise><xsl:value-of select="$strNotSelected"/></xsl:otherwise>
              </xsl:choose>
            </xsl:attribute>
            </Data>
          </Row>
        </xsl:if>
        <!-- Power Knob - Fan Mode -->
         <xsl:if test="//PowerKnobFanObject">
          <Row>
            <Data name="pk_name" align="left">
              <xsl:attribute name="value"><xsl:value-of select="$strProfileFanPowerMgmt"/></xsl:attribute>
            </Data>
            <Data name="pk_fan" id="pk_fan" align="center">
            <xsl:attribute name="display"><xsl:value-of select="$strProfileFanPowerMgmt"/></xsl:attribute>
              <xsl:attribute name="value">
                <xsl:choose>
                  <xsl:when test="//PowerKnobFanObject/currentState/power = 'true'"><xsl:value-of select="$strMinimumPower"/></xsl:when>
                  <xsl:when test="//PowerKnobFanObject/currentState/performance = 'true'"><xsl:value-of select="$strMaximumPerformance"/></xsl:when>
                  <xsl:otherwise><xsl:value-of select="$strNotSelected"/></xsl:otherwise>
                </xsl:choose>
              </xsl:attribute>
            </Data>
          </Row>
	  </xsl:if>
  </TableData>
</xsl:if>
</xsl:template>





<!--================================================== ========================-->
<!--Template: float-to-date-time-->
<!--Description: Convert a floating point value representing a date/time to-->
<!--a date/time string.-->
<!--Parameters:-->
<!--<value> the value to be converted-->
<!--<round-seconds> if true then the seconds are not quoted on the output-->
<!--and, if the seconds are 59 then hour/minute is rounded-->
<!--this is useful because some processors have limited-->
<!--loating point precision to cope with the seconds)-->
<!--================================================== ======================== -->

<xsl:template name="float-to-date-time">
	<xsl:param name="value" select="number(0)"/>
	<xsl:param name="round-seconds" select="false()"/>
	<xsl:variable name="date">
	   <xsl:call-template name="julian-day-to-date">
	      <xsl:with-param name="julian-day" select="floor($value)"/>
	   </xsl:call-template>
	</xsl:variable>
	<xsl:variable name="t1" select="$value - floor($value)"/>
	<xsl:variable name="h" select="floor($t1 div (1 div 24))"/>
	<xsl:variable name="t2" select="$t1 - ($h * (1 div 24))"/>
	<xsl:variable name="m" select="floor($t2 div (1 div 1440))"/>
	<xsl:variable name="t3" select="$t2 - ($m * (1 div 1440))"/>
	<xsl:choose>
	    <xsl:when test="$round-seconds">
		<xsl:variable name="s" select="$t3 div (1 div 86400)"/>
		<xsl:variable name="h2">
		<xsl:choose>
		<xsl:when test="($s &gt;= 59) and ($m = 59)">
			<xsl:value-of select="$h +1"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="$h"/>
		</xsl:otherwise>
		</xsl:choose>
		</xsl:variable>
	<xsl:variable name="m2">
	 <xsl:choose>
	    <xsl:when test="($s &gt;= 59) and ($m = 59)">0
		</xsl:when>
	    <xsl:when test="($s &gt;= 59)">
		<xsl:value-of select="$m +1"/>
	    </xsl:when>
	    <xsl:otherwise>
		<xsl:value-of select="$m"/>
	    </xsl:otherwise>
	 </xsl:choose>
	</xsl:variable>
<!-- pad final time result -->
	<xsl:variable name="hh" select="concat(substring('00',1,2 - string-length(string($h2))),string($h2))"/>
	<xsl:variable name="mm" select="concat(substring('00',1,2 - string-length(string($m2))),string($m2))"/>
<!-- final output resultant -->
	<xsl:value-of select="concat($date,'T',$hh,':',$mm)"/>
	</xsl:when>
	<xsl:otherwise>
	<xsl:variable name="s" select="floor($t3 div (1 div 86400))"/>
<!-- pad final time result -->
	<xsl:variable name="hh" select="concat(substring('00',1,2 - string-length(string($h))),string($h))"/>
	<xsl:variable name="mm" select="concat(substring('00',1,2 - string-length(string($m))),string($m))"/>
	<xsl:variable name="ss" select="concat(substring('00',1,2 - string-length(string($s))),string($s))"/>
<!-- final output resultant -->
	<xsl:value-of select="concat($date,'T',$hh,':',$mm,':',$ss)"/>
</xsl:otherwise>
</xsl:choose>
</xsl:template>


<!--================================================== ========================-->
<!--Template: julian-day-to-date-->
<!--Description: Convert a julian day to date-->
<!--Parameters: -->
<!--<julian-day>-->
<!--================================================== ======================== -->

<xsl:template name="julian-day-to-date">
<xsl:param name="julian-day" select="number(0)"/>
<!-- pre-calcs -->
<xsl:variable name="la" select="$julian-day + 68569"/>
<xsl:variable name="n" select="floor((4 * $la) div 146097)"/>
<xsl:variable name="lb" select="$la - floor((146097 * $n + 3) div 4)"/>
<xsl:variable name="i" select="floor((4000 * ($lb + 1)) div 1461001)"/>
<xsl:variable name="lc" select="$lb - floor((1461 * $i) div 4) + 31"/>
<xsl:variable name="j" select="floor((80 * $lc) div 2447)"/>
<xsl:variable name="day" select="$lc - floor((2447 * $j) div 80)"/>
<xsl:variable name="ld" select="floor($j div 11)"/>
<xsl:variable name="month" select="$j + 2 - (12 * $ld)"/>
<xsl:variable name="year" select="100 * ($n - 49) + $i + $ld"/>
<!-- whole days -->
<xsl:variable name="iday" select="floor($day)"/>
<!-- pad final result -->
<xsl:variable name="sday" select="concat(substring('00',1,2 - string-length(string($iday))),string($iday))"/>
<xsl:variable name="smonth" select="concat(substring('00',1,2 - string-length(string($month))),string($month))"/>
<xsl:variable name="syear" select="concat(substring('00',1,4 - string-length(string($year))),string($year))"/>
<!-- final output -->
<xsl:value-of select="concat($syear,'-',$smonth,'-',$sday)"/>
</xsl:template>



  <xsl:template name="increment">javascript:incr1(1,100)</xsl:template>
  <xsl:template name="decrement">javascript:decr1(1,0)</xsl:template>

  <xsl:template name="smstatus">
    <xsl:param name="status"/>
    <xsl:param name="mssg"/>
    <xsl:choose>
      <xsl:when test="$status = '-1'"><xsl:value-of select="$strCommandUnsuccessful"/></xsl:when>
      <xsl:when test="$status = '0'"><xsl:value-of select="$strCommandSuccessful"/></xsl:when>
      <xsl:when test="$status = '256'"><xsl:value-of select="$strCurrentProbesNotFound"/></xsl:when>
      <xsl:otherwise>SMStatus: <xsl:value-of select="$status"/></xsl:otherwise>
    </xsl:choose>
  </xsl:template>
</xsl:stylesheet>

