<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
    <xsl:variable name="base-lower" select="'0123456789abcdefghijklmnopqrstuvwxyz'"/>
    <xsl:variable name="base-upper" select="'0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ'"/>
	<xsl:output method="xml"/>
	<xsl:strip-space elements="*"/>
	<xsl:template match="/OMA">
		<OMA skin="modern">
			<DataArea>
				<!--<xsl:if test="OMA/ErrorSummaryInfo/Entry">-->
				<xsl:apply-templates select="OMA/ErrorSummaryInfo"/>	
				<!--</xsl:if>-->
				<xsl:if test="count(OMA/System) = 1">
					<xsl:apply-templates select="OMA/System"/>
				</xsl:if>
				<xsl:if test="count(OMA/ChassisSummary) = 1">
					<xsl:apply-templates select="OMA/ChassisSummary/System"/>
				</xsl:if>
				<xsl:if test="count(OMA/ChassisList) = 1">
					<xsl:apply-templates select="OMA/ChassisList"/>
				</xsl:if>
				<xsl:if test="count(OMA/ChassisSummary/ChassisList) = 1">
					<xsl:apply-templates select="OMA/ChassisSummary/ChassisList"/>
				</xsl:if>
				<xsl:apply-templates select="OMA/Network"/>
				<xsl:apply-templates select="OMA/Software"/>
			</DataArea>
		</OMA>
	</xsl:template>
	<xsl:template match="System">
		<TableData name="System" columnspacing="true">
			<PromptText>
				<xsl:value-of select="$strSystem1"/>
			</PromptText>
			<Header>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strHostName"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strSystemLocation"/>
					</xsl:attribute>
				</Data>
			</Header>
			<Row>
				<Data name="HostName">
					<xsl:attribute name="display">
						<xsl:value-of select="$strHostName"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:value-of select="HostName"/>
					</xsl:attribute>
				</Data>
				<Data name="SystemLocation">
					<xsl:attribute name="display">
						<xsl:value-of select="$strSystemLocation"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:value-of select="SystemInfo/SystemLocation"/>
					</xsl:attribute>
				</Data>
			</Row>
		</TableData>
	</xsl:template>
	<xsl:template match="ChassisList">
		<xsl:apply-templates/>
	</xsl:template>
	<xsl:template match="Chassis">
		<PageTitle>
			<xsl:attribute name="name">chassis_
				<xsl:value-of select="//ChassisList/@index"/>
			</xsl:attribute>
			<xsl:attribute name="display">
				<!-- As per defect DF296270 header info not consistant -->
				<!-- Remove choice statement below -->
<!--				<xsl:choose>
					<xsl:when test="@display = 'Main System Chassis'">
-->
						<xsl:value-of select="$strMainSystemChassis"/>
<!--
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="@display"/>
					</xsl:otherwise>
				</xsl:choose>
End of change for DF286270-->
			</xsl:attribute>
		</PageTitle>
		<xsl:apply-templates select="ChassisInfo"/>
		<xsl:apply-templates select="Hardware"/>
		<!--		<xsl:apply-templates select="OMA/Network"/>
		<xsl:apply-templates select="OMA/Software"/>
-->
	</xsl:template>
	<xsl:template match="ChassisInfo">
		<ListData name="ChassisInformation" type="custom">
			<xsl:attribute name="display">
				<xsl:value-of select="$strChassisInformation"/>
			</xsl:attribute>
			<Data name="ChassModel">
				<xsl:attribute name="display">
					<xsl:value-of select="$strChassisModel"/>
				</xsl:attribute>
				<xsl:attribute name="value">
					<xsl:value-of select="ChassisProps1/ChassModel"/>
				</xsl:attribute>
			</Data>
			<Data name="ServiceTag">
				<xsl:attribute name="display">
					<xsl:value-of select="$strChassisServiceTag"/>
				</xsl:attribute>
				<xsl:call-template name="DispChasSrvcTag"/>
			</Data>
            <Data name="ExpServiceCode">
                <xsl:attribute name="display">
                    <xsl:value-of select="$strExpServiceCode"/>
                </xsl:attribute>
                <!--check for shredder-->
                <xsl:choose>
                    <xsl:when test="ChassisProps1/ChassType = '25' ">
                        <xsl:choose>
                            <xsl:when test="(count(//BaseBoardList/BaseBoard[BaseBoardType='13'] ) ) > 0">                                
								<xsl:for-each select="//OMA/BaseBoardList/BaseBoard">
								<xsl:if test="BaseBoardType = '13'">
									<xsl:call-template name="convert-to-base-10">
										<xsl:with-param name="number" select="ServiceTag"/>
									</xsl:call-template>
								</xsl:if>
							</xsl:for-each>                                  
                            </xsl:when>
                        </xsl:choose>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:call-template name="convert-to-base-10">
                            <xsl:with-param name="number" select="ChassisProps2/ServiceTag"/>
                        </xsl:call-template>
                    </xsl:otherwise>
                </xsl:choose>
            </Data>
			<Data name="ChassLock">
				<xsl:attribute name="display">
					<xsl:value-of select="$strChassisLock"/>
				</xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="normalize-space(ChassisProps1/ChassLockPresent)='true'">
							<xsl:value-of select="$strPresent"/>
						</xsl:when>
						<xsl:when test="normalize-space(ChassisProps1/ChassLockPresent)='false'">
							<xsl:value-of select="$strAbsent"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$strNoValue"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
			<Data name="AssetTag">
				<xsl:attribute name="display">
					<xsl:choose>
						<xsl:when test="ChassisProps1/ChassType = '25' ">
							<xsl:value-of select="$strServerModuleAsset"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$strChassisAssetTag"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
				<xsl:call-template name="DispChasAssetTag"/>
			</Data>
			<xsl:choose>
				<xsl:when test="ChassisProps1/ChassType = '25' ">
					<xsl:call-template name="YellowStone"/>
				</xsl:when>
			</xsl:choose>
			<xsl:if test="ChassisProps1/ChassType = '25' ">
				<xsl:apply-templates select="//OMA/BaseBoardList"/>
				<xsl:apply-templates select="//OMA/ChassisSummary/BaseBoardList"/>
			</xsl:if>
		</ListData>
	</xsl:template>
	<xsl:template name="YellowStone">
		<xsl:for-each select="/OMA/BaseBoardList/BaseBoard">
			<xsl:choose>
				<xsl:when test="BaseBoardType = '11'">
					<Data>
						<xsl:attribute name="display">
							<xsl:value-of select="$strPMMAssetTag"/>
						</xsl:attribute>
						<xsl:attribute name="value">
							<xsl:value-of select="AssetTag"/>
						</xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">
							<xsl:value-of select="$strPMMserviceTag"/>
						</xsl:attribute>
						<xsl:attribute name="value">
							<xsl:value-of select="ServiceTag"/>
						</xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">
							<xsl:value-of select="$strPMMLocation"/>
						</xsl:attribute>
						<xsl:attribute name="value">
							<xsl:value-of select="BoardLocation"/>
						</xsl:attribute>
					</Data>
				</xsl:when>
				<xsl:when test="BaseBoardType = '12'">
					<Data>
						<xsl:attribute name="display">
							<xsl:value-of select="$strIOMAssetTag"/>
						</xsl:attribute>
						<xsl:attribute name="value">
							<xsl:value-of select="AssetTag"/>
						</xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">
							<xsl:value-of select="$strIOMserviceTag"/>
						</xsl:attribute>
						<xsl:attribute name="value">
							<xsl:value-of select="ServiceTag"/>
						</xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">
							<xsl:value-of select="$strIOMLocation"/>
						</xsl:attribute>
						<xsl:attribute name="value">
							<xsl:value-of select="BoardLocation"/>
						</xsl:attribute>
					</Data>
				</xsl:when>
			</xsl:choose>
		</xsl:for-each>
		<xsl:for-each select="/OMA/BaseBoardList/BaseBoard[BaseBoardType='2']">
			<xsl:choose>
				<xsl:when test="position() = 1">
					<Data>
						<xsl:attribute name="name">dsmassetag</xsl:attribute>
						<xsl:attribute name="display">
							<xsl:value-of select="$strDSM0AssetTag"/>
						</xsl:attribute>
						<xsl:attribute name="value">
							<xsl:value-of select="AssetTag"/>
						</xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">
							<xsl:value-of select="$strDSM0serviceTag"/>
						</xsl:attribute>
						<xsl:attribute name="value">
							<xsl:value-of select="ServiceTag"/>
						</xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">
							<xsl:value-of select="$strDSM0Location"/>
						</xsl:attribute>
						<xsl:attribute name="value">
							<xsl:value-of select="BoardLocation"/>
						</xsl:attribute>
					</Data>
				</xsl:when>
				<xsl:when test="position() = 2">
					<Data>
						<xsl:attribute name="name">dsmassetag</xsl:attribute>
						<xsl:attribute name="display">
							<xsl:value-of select="$strDSM1AssetTag"/>
						</xsl:attribute>
						<xsl:attribute name="value">
							<xsl:value-of select="AssetTag"/>
						</xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">
							<xsl:value-of select="$strDSM1serviceTag"/>
						</xsl:attribute>
						<xsl:attribute name="value">
							<xsl:value-of select="ServiceTag"/>
						</xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">
							<xsl:value-of select="$strDSM1Location"/>
						</xsl:attribute>
						<xsl:attribute name="value">
							<xsl:value-of select="BoardLocation"/>
						</xsl:attribute>
					</Data>
				</xsl:when>
				<xsl:when test="position() = 3">
					<Data>
						<xsl:attribute name="name">dsmassetag</xsl:attribute>
						<xsl:attribute name="display">
							<xsl:value-of select="$strDSM2AssetTag"/>
						</xsl:attribute>
						<xsl:attribute name="value">
							<xsl:value-of select="AssetTag"/>
						</xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">
							<xsl:value-of select="$strDSM2serviceTag"/>
						</xsl:attribute>
						<xsl:attribute name="value">
							<xsl:value-of select="ServiceTag"/>
						</xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="display">
							<xsl:value-of select="$strDSM2Location"/>
						</xsl:attribute>
						<xsl:attribute name="value">
							<xsl:value-of select="BoardLocation"/>
						</xsl:attribute>
					</Data>
				</xsl:when>
			</xsl:choose>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="DispChasSrvcTag">
		<xsl:attribute name="value">
			<!--check for shredder-->
			<xsl:choose>
				<!--Shredder-->
				<xsl:when test="ChassisProps1/ChassType = '25' ">
						<xsl:for-each select="//OMA/BaseBoardList/BaseBoard">
							<xsl:if test="BaseBoardType = '13'">
								<xsl:value-of select="ServiceTag"/>
							</xsl:if>
						</xsl:for-each>
<!--
					<xsl:if test="//OMA/ChassisSummary/BaseBoardList/@count &gt; 0">
						<xsl:for-each select="//OMA/ChassisSummary/BaseBoardList/BaseBoard">
							<xsl:if test="BaseBoardType = '13'">
								<xsl:value-of select="ServiceTag"/>
							</xsl:if>
						</xsl:for-each>
					</xsl:if>
-->
				</xsl:when>
				<xsl:otherwise>
					<!--not shredder -->
					<xsl:value-of select="ChassisProps2/ServiceTag"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:attribute>
	</xsl:template>
    <xsl:template name="convert-to-base-10">
        <xsl:param name="number"/>
        <xsl:choose>
			<xsl:when test="$number = 'Not Available'">
			<xsl:attribute name="value">Not Available</xsl:attribute>
			</xsl:when>
		<xsl:otherwise>	
			<xsl:variable name="num" select="translate($number,$base-upper, $base-lower)"/>
			<xsl:variable name="valid-in-chars" select="substring($base-lower,1,36)"/>
			<xsl:choose>
				<xsl:when test="not($num) or translate($num,$valid-in-chars,'')">
					<xsl:attribute name="value">Invalid</xsl:attribute>
				</xsl:when>
				<xsl:when test="string-length($num) != 7">
					<xsl:attribute name="value">Invalid</xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="convert-to-base-10-impl">
						<xsl:with-param name="number" select="$num"/>
						<xsl:with-param name="from-chars" select="$valid-in-chars"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:otherwise>
		</xsl:choose>
    </xsl:template>
    <xsl:template name="convert-to-base-10-impl">
        <xsl:param name="number"/>
        <xsl:param name="from-chars"/>
        <xsl:param name="result" select="0"/>
        <xsl:variable name="value" select="string-length(substring-before($from-chars,substring($number,1,1)))"/>
        <xsl:variable name="total" select="$result * 36 + $value"/>
        <xsl:choose>
            <xsl:when test="string-length($number) = 1">
                <xsl:attribute name="value">
                    <xsl:value-of select="format-number($total,'0')"/>
                </xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="convert-to-base-10-impl">
                    <xsl:with-param name="number" select="substring($number,2)"/>
                    <xsl:with-param name="from-chars" select="$from-chars"/>
                    <xsl:with-param name="result" select="$total"/>
                </xsl:call-template>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
	<xsl:template name="DispChasAssetTag">
		<xsl:attribute name="value">
			<xsl:value-of select="ChassisProps2/AssetTag"/>
		</xsl:attribute>
	</xsl:template>
	<xsl:template match="BaseBoardList">
		<xsl:for-each select="BaseBoard">
			<xsl:if test="(BaseBoardType='13')">
				<Data name="BladeServiceTag" type="ustring">
					<xsl:attribute name="display">
						<xsl:value-of select="$strServerModuleService"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:value-of select="//OMA/ChassisList/Chassis/ChassisInfo/ChassisProps2/ServiceTag"/>
					</xsl:attribute>
				</Data>
				<Data name="BladeExpressTag" type="ustring">
					<xsl:attribute name="display">
						<xsl:value-of select="$strServerModuleExpress"/>
					</xsl:attribute>
						<xsl:call-template name="convert-to-base-10">
                                    <xsl:with-param name="number" select="//OMA/ChassisList/Chassis/ChassisInfo/ChassisProps2/ServiceTag"/>
                                </xsl:call-template>
				</Data>
			</xsl:if>
			
<!--
			<xsl:if test="(BaseBoardType!='11') and (BaseBoardType!='2') and (BaseBoardType!='12')and (BaseBoardType!='13')">
				<Data name="BladeServiceTag" type="ustring">
					<xsl:attribute name="display">
						<xsl:value-of select="$strServerModuleService"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:value-of select="ServiceTag"/>
					</xsl:attribute>
				</Data>
			</xsl:if>
-->
			<xsl:if test="(BaseBoardType='13')">
				<Data name="BladeLocation" type="ustring">
					<xsl:attribute name="display">
						<xsl:value-of select="$strServerModuleLocation"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:value-of select="BoardLocation"/>
					</xsl:attribute>
				</Data>
			</xsl:if>
<!--
			<xsl:if test="(BaseBoardType!='3') and (BaseBoardType!='11') and (BaseBoardType!='2') and (BaseBoardType!='12')">
				<Data name="BladeLocation" type="ustring">
					<xsl:attribute name="display">
						<xsl:value-of select="$strServerModuleLocation"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:value-of select="BoardLocation"/>
					</xsl:attribute>
				</Data>
			</xsl:if>
-->
		</xsl:for-each>
	</xsl:template>
	<xsl:template match="Hardware">
		<xsl:apply-templates/>
		<xsl:apply-templates select="FirmwareList"/>
	</xsl:template>
	<xsl:template match="ProcessorList">
		<xsl:apply-templates/>
	</xsl:template>
	<xsl:template match="DevProcessor">
		<TableData name="Processor" columnspacing="true">
			<PromptText>
				<xsl:value-of select="$strProcessor"/>
			</PromptText>
			<Header>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strProcessorManufacturer"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strProcessorFamily"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strProcessorVersion"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strCurrentSpeed"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strMaximumSpeed"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strExternalClockSpeed"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strVoltage"/>
					</xsl:attribute>
				</Data>
			</Header>
			<Row>
				<Data name="ProcessorManufacturer">
					<xsl:attribute name="display">
						<xsl:value-of select="$strProcessorManufacturer"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:value-of select="Manufacturer"/>
					</xsl:attribute>
				</Data>
				<Data name="ProcessorFamily">
					<xsl:attribute name="display">
						<xsl:value-of select="$strProcessorFamily"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="Family='1'">
								<xsl:value-of select="$strOther"/>
							</xsl:when>
							<xsl:when test="Family='2'">
								<xsl:value-of select="$strOther"/>
							</xsl:when>
							<xsl:when test="Family='3'">
								<xsl:value-of select="$str8086"/>
							</xsl:when>
							<xsl:when test="Family='4'">
								<xsl:value-of select="$str286"/>
							</xsl:when>
							<xsl:when test="Family='5'">
								<xsl:value-of select="$str386"/>
							</xsl:when>
							<xsl:when test="Family='6'">
								<xsl:value-of select="$str486"/>
							</xsl:when>
							<xsl:when test="Family='7'">
								<xsl:value-of select="$str8087"/>
							</xsl:when>
							<xsl:when test="Family='8'">
								<xsl:value-of select="$str287"/>
							</xsl:when>
							<xsl:when test="Family='9'">
								<xsl:value-of select="$str387"/>
							</xsl:when>
							<xsl:when test="Family='10'">
								<xsl:value-of select="$str487"/>
							</xsl:when>
							<xsl:when test="Family='11'">
								<xsl:value-of select="$strPentium"/>
							</xsl:when>
							<xsl:when test="Family='12'">
								<xsl:value-of select="$strPentiumPro"/>
							</xsl:when>
							<xsl:when test="Family='13'">
								<xsl:value-of select="$strPentiumII"/>
							</xsl:when>
							<xsl:when test="Family='14'">
								<xsl:value-of select="$strPentiumWithMMX"/>
							</xsl:when>
							<xsl:when test="Family='15'">
								<xsl:value-of select="$strCeleron"/>
							</xsl:when>
							<xsl:when test="Family='16'">
								<xsl:value-of select="$strPentiumIIXeon"/>
							</xsl:when>
							<xsl:when test="Family='17'">
								<xsl:value-of select="$strPentiumIII"/>
							</xsl:when>
							<xsl:when test="Family='130'">
								<xsl:value-of select="$strItanium"/>
							</xsl:when>
							<xsl:when test="Family='176'">
								<xsl:value-of select="$strPentiumIIIXeon"/>
							</xsl:when>
							<xsl:when test="Family='177'">
								<xsl:value-of select="$strPentiumIIIWith"/>
							</xsl:when>
							<xsl:when test="Family='178'">
								<xsl:value-of select="$strPentiumIV"/>
							</xsl:when>
							<xsl:when test="Family='179'">
								<xsl:value-of select="$strXeon"/>
							</xsl:when>
							<xsl:when test="Family='181'">
								<xsl:value-of select="$strXeonMP"/>
							</xsl:when>
							<xsl:when test="Family='184'">
								<xsl:value-of select="$strItanium2"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="$strNoValue1"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
				<Data name="ProcessorVersion">
					<xsl:attribute name="display">
						<xsl:value-of select="$strProcessorVersion"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:value-of select="Version"/>
					</xsl:attribute>
				</Data>
				<Data name="CurrentSpeed">
					<xsl:attribute name="display">
						<xsl:value-of select="$strCurrentSpeed"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:value-of select="CurSpeed"/>
						<xsl:choose>
							<xsl:when test="CurSpeed/@unit='MB'">
								<xsl:value-of select="$strMB"/>
							</xsl:when>
							<xsl:when test="CurSpeed/@unit='KB'">
								<xsl:value-of select="$strKB"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="CurSpeed/@unit"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
				<Data name="MaximumSpeed">
					<xsl:attribute name="display">
						<xsl:value-of select="$strMaximumSpeed"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:value-of select="MaxSpeed"/>
						<xsl:choose>
							<xsl:when test="MaxSpeed/@unit='MB'">
								<xsl:value-of select="$strMB"/>
							</xsl:when>
							<xsl:when test="MaxSpeed/@unit='KB'">
								<xsl:value-of select="$strKB"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="MaxSpeed/@unit"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
				<Data name="ExtClockSpeed">
					<xsl:attribute name="display">
						<xsl:value-of select="$strExternalClockSpeed"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:value-of select="ExtClockSpeed"/>
						<xsl:choose>
							<xsl:when test="ExtClockSpeed/@unit='MB'">
								<xsl:value-of select="$strMB"/>
							</xsl:when>
							<xsl:when test="ExtClockSpeed/@unit='KB'">
								<xsl:value-of select="$strKB"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="ExtClockSpeed/@unit"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
				<Data name="Voltage">
					<xsl:attribute name="display">
						<xsl:value-of select="$strVoltage"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:value-of select="Voltage"/>
						<xsl:choose>
							<xsl:when test="Voltage/@unit='mv'">
								<xsl:value-of select="$strMV"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="Voltage/@unit"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
			</Row>
		</TableData>
	</xsl:template>
	<xsl:template match="MemoryArrayList">
		<TableData name="Memory" columnspacing="true">
			<PromptText>
				<xsl:value-of select="$strMemory"/>
			</PromptText>
			<Header>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strTotalInstalledCapacity"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strMemoryAvailableTo"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strTotalMaximumCapacity"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strMemoryArrayCount"/>
					</xsl:attribute>
				</Data>
			</Header>
			<Row>
				<Data name="InstalledSize">
					<xsl:attribute name="display">
						<xsl:value-of select="$strTotalInstalledCapacity"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:value-of select="../MaxInstalledSizeMBCumulative"/>
						<xsl:choose>
							<xsl:when test="../MaxInstalledSizeMBCumulative/@unit='MB'">
								<xsl:value-of select="$strMB"/>
							</xsl:when>
							<xsl:when test="../MaxInstalledSizeMBCumulative/@unit='KB'">
								<xsl:value-of select="$strKB"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="../MaxInstalledSizeMBCumulative/@unit"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
				<Data name="OSInstalledSize">
					<xsl:attribute name="display">
						<xsl:value-of select="$strMemoryAvailableTo"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:value-of select="../MemoryInfo/TotalPhysMemorySizeMB"/>
						<xsl:choose>
							<xsl:when test="../MemoryInfo/TotalPhysMemorySizeMB/@unit='MB'">
								<xsl:value-of select="$strMB"/>
							</xsl:when>
							<xsl:when test="../MemoryInfo/TotalPhysMemorySizeMB/@unit='KB'">
								<xsl:value-of select="$strKB"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="../MemoryInfo/TotalPhysMemorySizeMB/@unit"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
				<Data name="TotalSize">
					<xsl:attribute name="display">
						<xsl:value-of select="$strTotalMaximumCapacity"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:value-of select="../MaxSizeMBCumulative"/>
						<xsl:choose>
							<xsl:when test="../MaxSizeMBCumulative/@unit='MB'">
								<xsl:value-of select="$strMB"/>
							</xsl:when>
							<xsl:when test="../MaxSizeMBCumulative/@unit='KB'">
								<xsl:value-of select="$strKB"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="../MaxSizeMBCumulative/@unit"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
				<Data name="MemoryArrays">
					<xsl:attribute name="display">
						<xsl:value-of select="$strMemoryArrayCount"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:value-of select="@count"/>
					</xsl:attribute>
				</Data>
			</Row>
		</TableData>
		<xsl:apply-templates/>
	</xsl:template>
	<xsl:template match="MemoryArray">
		<TableData name="MemoryArray" columnspacing="true">
			<PromptText>
				<xsl:value-of select="$strMemoryArray"/>
			</PromptText>
			<Header>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strLocation"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strUse"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strInstalledCapacity"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strMaximumCapacity"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strSlotsAvailable"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strSlotsUsed"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strECCType"/>
					</xsl:attribute>
				</Data>
			</Header>
			<Row>
				<Data name="Location">
					<xsl:attribute name="display">
						<xsl:value-of select="$strLocation"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="Location='1'">
								<xsl:value-of select="$strOther1"/>
							</xsl:when>
							<xsl:when test="Location='3'">
								<xsl:value-of select="$strSystemBoardOr"/>
							</xsl:when>
							<xsl:when test="Location='4'">
								<xsl:value-of select="$strISAAddonCard"/>
							</xsl:when>
							<xsl:when test="Location='5'">
								<xsl:value-of select="$strEISAAddonCard"/>
							</xsl:when>
							<xsl:when test="Location='6'">
								<xsl:value-of select="$strPCIAddonCard"/>
							</xsl:when>
							<xsl:when test="Location='7'">
								<xsl:value-of select="$strMCAAddonCard"/>
							</xsl:when>
							<xsl:when test="Location='8'">
								<xsl:value-of select="$strPCMCIAAddonCard"/>
							</xsl:when>
							<xsl:when test="Location='9'">
								<xsl:value-of select="$strProprietaryAddonCard"/>
							</xsl:when>
							<xsl:when test="Location='16'">
								<xsl:value-of select="$strNuBus"/>
							</xsl:when>
							<xsl:when test="Location='160'">
								<xsl:value-of select="$strPC98C20AddonCard"/>
							</xsl:when>
							<xsl:when test="Location='161'">
								<xsl:value-of select="$strPC98C24AddonCard"/>
							</xsl:when>
							<xsl:when test="Location='162'">
								<xsl:value-of select="$strPC98EAddonCard"/>
							</xsl:when>
							<xsl:when test="Location='163'">
								<xsl:value-of select="$strPC98LocalBusAddon"/>
							</xsl:when>
							<xsl:when test="Location='164'">
								<xsl:value-of select="$strPC98CardSlotAddon"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="$strNoValue2"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
				<Data name="Use">
					<xsl:attribute name="display">
						<xsl:value-of select="$strUse"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="Use='1'">
								<xsl:value-of select="$strOther2"/>
							</xsl:when>
							<xsl:when test="Use='3'">
								<xsl:value-of select="$strSystemMemory"/>
							</xsl:when>
							<xsl:when test="Use='4'">
								<xsl:value-of select="$strVideoMemory"/>
							</xsl:when>
							<xsl:when test="Use='5'">
								<xsl:value-of select="$strFlashMemory"/>
							</xsl:when>
							<xsl:when test="Use='6'">
								<xsl:value-of select="$strNonVolatileRAM"/>
							</xsl:when>
							<xsl:when test="Use='7'">
								<xsl:value-of select="$strCacheMemory"/>
							</xsl:when>
						</xsl:choose>
					</xsl:attribute>
				</Data>
				<Data name="InstalledSize">
					<xsl:attribute name="display">
						<xsl:value-of select="$strInstalledCapacity"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:value-of select="InstalledSizeMBCumulative"/>
						<xsl:choose>
							<xsl:when test="InstalledSizeMBCumulative/@unit='MB'">
								<xsl:value-of select="$strMB"/>
							</xsl:when>
							<xsl:when test="InstalledSizeMBCumulative/@unit='KB'">
								<xsl:value-of select="$strKB"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="InstalledSizeMBCumulative/@unit"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
				<Data name="MaximumCapacity">
					<xsl:attribute name="display">
						<xsl:value-of select="$strMaximumCapacity"/>
					</xsl:attribute>
					<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="extMaxSize!='0'">
							<xsl:value-of select="extMaxSize"/>
							<xsl:text disable-output-escaping="yes">  </xsl:text>
							<xsl:value-of select="$strMB3"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="MaxSizeMB"/>
							<xsl:choose>
								<xsl:when test="MaxSizeMB/@unit='MB'">
									<xsl:value-of select="$strMB"/>
								</xsl:when>
								<xsl:when test="MaxSizeMB/@unit='KB'">
									<xsl:value-of select="$strKB"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="MaxSizeMB/@unit"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:otherwise>
					</xsl:choose>
					</xsl:attribute>
				</Data>
				<Data name="NumSocketsTotal">
					<xsl:attribute name="display">
						<xsl:value-of select="$strSlotsAvailable"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:value-of select="NumSocketsTotal"/>
					</xsl:attribute>
				</Data>
				<Data name="NumSocketsInUse">
					<xsl:attribute name="display">
						<xsl:value-of select="$strSlotsUsed"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:value-of select="NumSocketsInUse"/>
					</xsl:attribute>
				</Data>
				<Data name="ErrCorrType">
					<xsl:attribute name="display">
						<xsl:value-of select="$strECCType"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="ErrCorrType='1'">
								<xsl:value-of select="$strOther3"/>
							</xsl:when>
							<xsl:when test="ErrCorrType='3'">
								<xsl:value-of select="$strNone"/>
							</xsl:when>
							<xsl:when test="ErrCorrType='4'">
								<xsl:value-of select="$strParity"/>
							</xsl:when>
							<xsl:when test="ErrCorrType='5'">
								<xsl:value-of select="$strSingleBitECC"/>
							</xsl:when>
							<xsl:when test="ErrCorrType='6'">
								<xsl:value-of select="$strMultibitECC"/>
							</xsl:when>
							<xsl:when test="ErrCorrType='7'">
								<xsl:value-of select="$strCRC"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="$strNoValue4"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
			</Row>
		</TableData>
	</xsl:template>
	
<!-- The entire SlotList section is being supressed untill the issue with WMI and SLot number is resolved
	<xsl:template match="SlotsList">
		<TableData name="SlotsList" columnspacing="true">
			<PromptText>
				<xsl:value-of select="$strSlot"/>
			</PromptText>
			<Header>
				<Data>
					<xsl:attribute name="value"><xsl:value-of select="$strState"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value"><xsl:value-of select="$strSlot"/></xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strAdapter"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strType"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strDataBusWidth"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strSpeed"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strSlotLength"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strVoltageSupply"/>
					</xsl:attribute>
				</Data>
			</Header>
			<xsl:apply-templates/>
		</TableData>
	</xsl:template>
 end of first comment section -->


<!-- The entire SlotList section is being supressed untill the issue with WMI and SLot number is resolved
	<xsl:template match="Slot">
		<xsl:if test="ExtName != 'Embedded'">
			<Row>
				<Data name="State">
                                 <xsl:attribute name="value">
				<xsl:choose>
					<xsl:when test="SlotDevice/DeviceDesc ='Embedded' " >In use</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="SlotDevice/DeviceDesc"/>
					</xsl:otherwise>
				</xsl:choose>
				</xsl:attribute>
				</Data>
				<Data name="Slot">
				<xsl:choose>
					<xsl:when test="number(@index) > 0">
						<xsl:attribute name="value"><xsl:value-of select ="SMBName"/></xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
					<xsl:attribute name="value"><xsl:value-of select="SlotDevice/DeviceDesc"/></xsl:attribute>
					</xsl:otherwise>
				</xsl:choose>
				</Data>
				<Data name="Adapter">
					<xsl:attribute name="value"><xsl:value-of select="ExtName"/>
					</xsl:attribute>
				</Data>
				<xsl:if test="number(@index) > 0">
					<Data name="Type" editable="false" type="ustring">
						<xsl:attribute name="value">
							<xsl:choose>
								<xsl:when test="Type='1'">
									<xsl:value-of select="$strOther4"/>
								</xsl:when>
								<xsl:when test="Type='3'">
									<xsl:value-of select="$strISA"/>
								</xsl:when>
								<xsl:when test="Type='4'">
									<xsl:value-of select="$strMCA"/>
								</xsl:when>
								<xsl:when test="Type='5'">
									<xsl:value-of select="$strEISA"/>
								</xsl:when>
								<xsl:when test="Type='6'">
									<xsl:value-of select="$strPCI"/>
								</xsl:when>
								<xsl:when test="Type='7'">
									<xsl:value-of select="$strPCMCIA"/>
								</xsl:when>
								<xsl:when test="Type='8'">
									<xsl:value-of select="$strVLVESA"/>
								</xsl:when>
								<xsl:when test="Type='9'">
									<xsl:value-of select="$strProprietary"/>
								</xsl:when>
								<xsl:when test="Type='10'">
									<xsl:value-of select="$strProcessorCard"/>
								</xsl:when>
								<xsl:when test="Type='11'">
									<xsl:value-of select="$strProprietaryMemoryCard"/>
								</xsl:when>
								<xsl:when test="Type='12'">
									<xsl:value-of select="$strIORiserCard"/>
								</xsl:when>
								<xsl:when test="Type='13'">
									<xsl:value-of select="$strNuBus1"/>
								</xsl:when>
								<xsl:when test="Type='14'">
									<xsl:value-of select="$strPCI66MHz"/>
								</xsl:when>
								<xsl:when test="Type='15'">
									<xsl:value-of select="$strAGP"/>
								</xsl:when>
								<xsl:when test="Type='16'">
									<xsl:value-of select="$strAGP2X"/>
								</xsl:when>
								<xsl:when test="Type='17'">
									<xsl:value-of select="$strAGP4X"/>
								</xsl:when>
								<xsl:when test="Type='18'">
									<xsl:value-of select="$strPCIX"/>
								</xsl:when>
								<xsl:when test="Type='160'">
									<xsl:value-of select="$strPC98C20"/>
								</xsl:when>
								<xsl:when test="Type='161'">
									<xsl:value-of select="$strPC98C24"/>
								</xsl:when>
								<xsl:when test="Type='162'">
									<xsl:value-of select="$strPC98E"/>
								</xsl:when>
								<xsl:when test="Type='163'">
									<xsl:value-of select="$strPC98LocalBus"/>
								</xsl:when>
								<xsl:when test="Type='164'">
									<xsl:value-of select="$strPC98Card"/>
								</xsl:when>
								<xsl:when test="Type='165'">
									<xsl:value-of select="$strPCIE"/>
								</xsl:when>
								<xsl:when test="Type='166'">
									<xsl:value-of select="$strPCIEx1"/>
								</xsl:when>
								<xsl:when test="Type='167'">
									<xsl:value-of select="$strPCIEx2"/>
								</xsl:when>
								<xsl:when test="Type='168'">
									<xsl:value-of select="$strPCIEx4"/>
								</xsl:when>
								<xsl:when test="Type='169'">
									<xsl:value-of select="$strPCIEx8"/>
								</xsl:when>
								<xsl:when test="Type='170'">
									<xsl:value-of select="$strPCIEx16"/>
								</xsl:when>
								<xsl:when test="Type='171'">
									<xsl:value-of select="$strPCIEx32"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="$strNoValue5"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:attribute>
					</Data>
					<Data name="DataBusWidth">
						<xsl:attribute name="value">
							<xsl:choose>
								<xsl:when test="HotPlugSystemSlot/DataBusWidth='1'">
									<xsl:value-of select="$strOther5"/>
								</xsl:when>
								<xsl:when test="HotPlugSystemSlot/DataBusWidth='3'">
									<xsl:value-of select="$str8Bits"/>
								</xsl:when>
								<xsl:when test="HotPlugSystemSlot/DataBusWidth='4'">
									<xsl:value-of select="$str16Bits"/>
								</xsl:when>
								<xsl:when test="HotPlugSystemSlot/DataBusWidth='5'">
									<xsl:value-of select="$str32Bits"/>
								</xsl:when>
								<xsl:when test="HotPlugSystemSlot/DataBusWidth='6'">
									<xsl:value-of select="$str64Bits"/>
								</xsl:when>
								<xsl:when test="HotPlugSystemSlot/DataBusWidth='7'">
									<xsl:value-of select="$str128Bits"/>
								</xsl:when>
								<xsl:when test="HotPlugSystemSlot/DataBusWidth='8'">
									<xsl:value-of select="$str1xOr1x"/>
								</xsl:when>
								<xsl:when test="HotPlugSystemSlot/DataBusWidth='9'">
									<xsl:value-of select="$str2xOr2x"/>
								</xsl:when>
								<xsl:when test="HotPlugSystemSlot/DataBusWidth='10'">
									<xsl:value-of select="$str4xOr4x"/>
								</xsl:when>
								<xsl:when test="HotPlugSystemSlot/DataBusWidth='11'">
									<xsl:value-of select="$str8xOr8x"/>
								</xsl:when>
								<xsl:when test="HotPlugSystemSlot/DataBusWidth='12'">
									<xsl:value-of select="$str12xOr12x"/>
								</xsl:when>
								<xsl:when test="HotPlugSystemSlot/DataBusWidth='13'">
									<xsl:value-of select="$str16xOr16x"/>
								</xsl:when>
								<xsl:when test="HotPlugSystemSlot/DataBusWidth='14'">
									<xsl:value-of select="$str32xOr32x"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="$strNotObtainedRefer"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:attribute>
					</Data>
					<Data name="Speed" editable="false" type="ustring">
						<xsl:attribute name="value">
							<xsl:choose>
								<xsl:when test="HotPlugSystemSlot/SlotSpeed='0'">
									<xsl:value-of select="$strNotObtainedRefer"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="HotPlugSystemSlot/SlotSpeed"/>
									<xsl:choose>
										<xsl:when test="HotPlugSystemSlot/SlotSpeed/@unit='MB'">
											<xsl:value-of select="$strMB"/>
										</xsl:when>
										<xsl:when test="HotPlugSystemSlot/SlotSpeed/@unit='KB'">
											<xsl:value-of select="$strKB"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="HotPlugSystemSlot/SlotSpeed/@unit"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:attribute>
					</Data>
					<Data name="SlotLength">
						<xsl:attribute name="value">
							<xsl:choose>
								<xsl:when test="Length='1'">
									<xsl:value-of select="$strOther6"/>
								</xsl:when>
								<xsl:when test="Length='3'">
									<xsl:value-of select="$strShort"/>
								</xsl:when>
								<xsl:when test="Length='4'">
									<xsl:value-of select="$strLong"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="$strNoValue8"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:attribute>
					</Data>
					<Data name="VoltSupply" editable="false" type="ustring">
						<xsl:attribute name="value">
							<xsl:if test="IsVolt33='true'">
								<xsl:value-of select="$str33Volts"/>
								<xsl:if test="IsVolt5='true'">,</xsl:if>
							</xsl:if>
							<xsl:if test="IsVolt5='true'">
								<xsl:value-of select="$str5Volts"/>
							</xsl:if>
						</xsl:attribute>
					</Data>
				</xsl:if>
			</Row>
		</xsl:if>
	</xsl:template>
   End of COmmenting out Slot info from report -->	

	<xsl:template match="SystemBIOS">
		<TableData name="SystemBIOS" columnspacing="true">
			<PromptText>
				<xsl:value-of select="$strBIOSInformation"/>
			</PromptText>
			<Header>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strManufacturer"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strVersion"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strReleaseDate"/>
					</xsl:attribute>
				</Data>
			</Header>
			<Row>
				<Data name="Manufacturer">
					<xsl:attribute name="display">
						<xsl:value-of select="$strManufacturer"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:value-of select="Manufacturer"/>
					</xsl:attribute>
				</Data>
				<Data name="Version">
					<xsl:attribute name="display">
						<xsl:value-of select="$strVersion"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:value-of select="Version"/>
					</xsl:attribute>
				</Data>
				<Data name="ReleaseDate">
					<xsl:attribute name="display">
						<xsl:value-of select="$strReleaseDate"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:value-of select="ReleaseDate"/>
					</xsl:attribute>
				</Data>
			</Row>
		</TableData>
	</xsl:template>
	<xsl:template match="Network">
		<xsl:if test="IPAddrList">
			<xsl:apply-templates select="IPAddrList"/>
		</xsl:if>
		<xsl:if test="NICList">
			<xsl:apply-templates select="NICList"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="NICList">
		<TableData name="NICList" columnspacing="true">
			<PromptText>
				<xsl:value-of select="$strNetworkData"/>
			</PromptText>
			<Header>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strNetworkInterfaceCard"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strIPAddress"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strIPV6Address"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strSubnetMask"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strDefaultGateway"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strMACAddress"/>
					</xsl:attribute>
				</Data>
			</Header>
			<xsl:apply-templates/>
		</TableData>
	</xsl:template>
	<xsl:template match="NICCard">
		<Row>
			<Data>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="Description = ''">
							<xsl:value-of select="$strNoValue10"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="Description"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="name">IPAddr 
            
					<xsl:value-of select="@index"/>
				</xsl:attribute>
				<xsl:attribute name="display">
					<xsl:value-of select="$strIPAddress"/>
				</xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="IPAddress = ''">
							<xsl:value-of select="$strNoValue9"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="IPAddress"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="name">IPAddrv6<xsl:value-of select="@index"/>
				</xsl:attribute>
				<xsl:attribute name="display">
					<xsl:value-of select="$strIPV6Address"/>
				</xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="//IPV6Address or IPV6Address != ''">
							<xsl:value-of select="IPV6Address"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$strNoValue14"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="name">SubnetMask 
               
					<xsl:value-of select="@index"/>
				</xsl:attribute>
				<xsl:attribute name="display">
					<xsl:value-of select="$strSubnetMask"/>
				</xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="SubnetMask = ''">
							<xsl:value-of select="$strNoValue10"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="SubnetMask"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="name">DefaultGateway 
               
					<xsl:value-of select="@index"/>
				</xsl:attribute>
				<xsl:attribute name="display">
					<xsl:value-of select="$strDefaultGateway"/>
				</xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="DefaultGateway = ''">
							<xsl:value-of select="$strNoValue11"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="DefaultGateway"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="name">MacAddr 
               
					<xsl:value-of select="@index"/>
				</xsl:attribute>
				<xsl:attribute name="display">
					<xsl:value-of select="$strMACAddress"/>
				</xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="CurrentMacAddr = ''">
							<xsl:value-of select="$strNoValue12"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="CurrentMacAddr"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
		</Row>
	</xsl:template>
	<xsl:template match="IPAddrList">
		<Data name="IPAddrList">
			<xsl:attribute name="display">
				<xsl:value-of select="$strIPAddressData"/>
			</xsl:attribute>
			<xsl:apply-templates/>
		</Data>
	</xsl:template>
	<xsl:template match="IPAddr">
		<Data name="IPAddr">
			<xsl:attribute name="name">IPAddr 
         
				<xsl:value-of select="@index"/>
			</xsl:attribute>
			<xsl:attribute name="display">
				<xsl:value-of select="$strIPAddress1"/>
				<xsl:value-of select="@index"/>
			</xsl:attribute>
			<xsl:attribute name="value">
				<xsl:value-of select="."/>
			</xsl:attribute>
		</Data>
	</xsl:template>
	<xsl:template match="Software">
		<xsl:apply-templates/>
	</xsl:template>
	<xsl:template match="OSInfo">
		<TableData name="OSInfo" columnspacing="true">
			<PromptText>
				<xsl:value-of select="$strOperatingSystem"/>
			</PromptText>
			<Header>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strName"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strVersion1"/>
					</xsl:attribute>
				</Data>
				<!-- <Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strSystemTime"/>
					</xsl:attribute>
				</Data> -->
				<!-- <Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strSystemBootupTime"/>
					</xsl:attribute>
				</Data> -->
			</Header>
			<Row>
				<Data name="OSName">
					<xsl:attribute name="display">
						<xsl:value-of select="$strName"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:value-of select="OSName"/>
					</xsl:attribute>
				</Data>
				<Data name="OSVersion">
					<xsl:attribute name="display">
						<xsl:value-of select="$strVersion1"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:value-of select="OSVersion"/>
					</xsl:attribute>
				</Data>
				<!-- <Data name="SystemTime">
					<xsl:attribute name="display">
						<xsl:value-of select="$strSystemTime"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:value-of select="//System/SystemInfo/SystemTime"/>
					</xsl:attribute>
				</Data> -->
				<!-- <Data name="SystemBootupTime">
					<xsl:attribute name="display">
						<xsl:value-of select="$strSystemBootupTime"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:value-of select="//System/SystemInfo/SystemBootupTime"/>
					</xsl:attribute>
				</Data> -->
			</Row>
		</TableData>
	</xsl:template>
	<xsl:template match="FirmwareList">
		<xsl:apply-templates/>
	</xsl:template>
	<xsl:template match="Firmware">
		<TableData name="Firmware" columnspacing="true">
			<PromptText>
				<xsl:attribute name="display">Firmware_ 
            
					<xsl:value-of select="@index"/>
				</xsl:attribute>
			</PromptText>
			<Header>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strName1"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strVersion2"/>
					</xsl:attribute>
				</Data>
			</Header>
			<Row>
				<Data name="Name">
					<xsl:attribute name="display">
						<xsl:value-of select="$strName1"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="FWType='2'">
								<xsl:value-of select="FWText"/>
							</xsl:when>
							<xsl:when test="FWType='3'">
								<xsl:value-of select="$strBIOSVersion"/>
							</xsl:when>
							<xsl:when test="FWType='4'">
								<xsl:value-of select="$strESMFirmwareVersion"/>
							</xsl:when>
							<xsl:when test="FWType='5'">
								<xsl:value-of select="$strPowerSupplyParalleling"/>
							</xsl:when>
							<xsl:when test="FWType='6'">
								<xsl:value-of select="$strBackplaneFirmwareVersion"/>
							</xsl:when>
							<xsl:when test="FWType='7'">
								<xsl:value-of select="$strKernelVersion"/>
							</xsl:when>
							<xsl:when test="FWType='8'">
								<xsl:value-of select="$strApplicationVersion"/>
							</xsl:when>
							<xsl:when test="FWType='9'">
								<xsl:value-of select="$strFrontPanelController"/>
							</xsl:when>
							<xsl:when test="FWType='10'">
								<xsl:value-of select="$strBaseboardManagementController"/>
							</xsl:when>
							<xsl:when test="FWType='11'">
								<xsl:value-of select="$strHotPlugPCI"/>
							</xsl:when>
							<xsl:when test="FWType='12'">
								<xsl:value-of select="$strSensorDataRecords"/>
							</xsl:when>
							<xsl:when test="FWType='13'">
								<xsl:value-of select="$strPeripheralBayBackplane"/>
							</xsl:when>
							<xsl:when test="FWType='14'">
								<xsl:value-of select="$strPowerEdge2450Secondary"/>
							</xsl:when>
							<xsl:when test="FWType='15'">
								<xsl:value-of select="$strSecondaryBackPlane"/>
							</xsl:when>
							<xsl:when test="FWType='16'">
								<xsl:value-of select="$strRemoteAccessController"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="$strUnknownFirmwareVersion"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
				<Data name="Version">
					<xsl:attribute name="display">
						<xsl:value-of select="$strVersion2"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:value-of select="FWVersion"/>
					</xsl:attribute>
				</Data>
			</Row>
		</TableData>
	</xsl:template>
	<xsl:template match="ClusterInfo">
		<TableData name="Cluster_Information" columnspacing="true">
			<PromptText>
				<xsl:value-of select="$strClusterInformation"/>
			</PromptText>
			<Header>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strClusterName"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strClusterDescription"/>
					</xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="value">
						<xsl:value-of select="$strClusterType"/>
					</xsl:attribute>
				</Data>
			</Header>
			<Row>
				<Data name="ClusterName">
					<xsl:attribute name="display">
						<xsl:value-of select="$strClusterName"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:value-of select="ClusterName"/>
					</xsl:attribute>
				</Data>
				<Data name="TypeDescription">
					<xsl:attribute name="display">
						<xsl:value-of select="$strClusterDescription"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:value-of select="TypeDescription"/>
					</xsl:attribute>
				</Data>
				<Data name="ClusterType">
					<xsl:attribute name="display">
						<xsl:value-of select="$strClusterType"/>
					</xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="ClusterType='2'">
								<xsl:value-of select="$strMicrosoftClusterServer"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="$strNoValue13"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
			</Row>
		</TableData>
	</xsl:template>
	<xsl:template name="displayunits">
		<xsl:param name="unit"/>
		<xsl:choose>
			<xsl:when test="$unit='MB'">
				<xsl:value-of select="$strMB"/>
			</xsl:when>
			<xsl:when test="$unit='KB'">
				<xsl:value-of select="$strKB"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$unit"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="getFWType">
		<xsl:param name="type"/>
		<xsl:choose>
			<xsl:when test="$type='2'">
				<xsl:value-of select="FWText"/>
			</xsl:when>
			<xsl:when test="$type='3'">
				<xsl:value-of select="$strBIOSVersion"/>
			</xsl:when>
			<xsl:when test="$type='4'">
				<xsl:value-of select="$strESMFirmwareVersion"/>
			</xsl:when>
			<xsl:when test="$type='5'">
				<xsl:value-of select="$strPowerSupplyParalleling"/>
			</xsl:when>
			<xsl:when test="$type='6'">
				<xsl:value-of select="$strBackplaneFirmwareVersion"/>
			</xsl:when>
			<xsl:when test="$type='7'">
				<xsl:value-of select="$strKernelVersion"/>
			</xsl:when>
			<xsl:when test="$type='8'">
				<xsl:value-of select="$strApplicationVersion"/>
			</xsl:when>
			<xsl:when test="$type='9'">
				<xsl:value-of select="$strFrontPanelController"/>
			</xsl:when>
			<xsl:when test="$type='10'">
				<xsl:value-of select="$strBaseboardManagementController"/>
			</xsl:when>
			<xsl:when test="$type='11'">
				<xsl:value-of select="$strHotPlugPCI"/>
			</xsl:when>
			<xsl:when test="$type='12'">
				<xsl:value-of select="$strSensorDataRecords"/>
			</xsl:when>
			<xsl:when test="$type='13'">
				<xsl:value-of select="$strPeripheralBayBackplane"/>
			</xsl:when>
			<xsl:when test="$type='14'">
				<xsl:value-of select="$strPowerEdge2450Secondary"/>
			</xsl:when>
			<xsl:when test="$type='15'">
				<xsl:value-of select="$strSecondaryBackPlane"/>
			</xsl:when>
			<xsl:when test="$type='16'">
				<xsl:value-of select="$strRemoteAccessController"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$strUnknownFirmwareVersion"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="ErrorSummaryInfo">
		<TableData columnspacing="true" sortable="true">
		<SubHeader>
			<xsl:choose>
			<xsl:when test="Entry">
			<xsl:attribute name="display"><xsl:value-of select="$strErrorSummary1"/></xsl:attribute>
			</xsl:when>
			<xsl:otherwise>
			<xsl:attribute name="display"><xsl:value-of select="$NoError"/></xsl:attribute>
			</xsl:otherwise>
			</xsl:choose>
		</SubHeader>
			<Header>
				<Data name="Status" align="center" link="true">
					<xsl:attribute name="value"><xsl:value-of select="$strStatus2"/></xsl:attribute>
					
				</Data>
				<Data name="Name" align="center" link="true">
					<xsl:attribute name="value"><xsl:value-of select="$strName2"/></xsl:attribute>
					
				</Data>
				<Data name="Location" align="center" link="true">
					<xsl:attribute name="value"><xsl:value-of select="$strLocation2"/></xsl:attribute>
					
				</Data>
				<Data name="Details" align="centre" link="true">
					<xsl:attribute name="value"><xsl:value-of select="$strDetails2"/></xsl:attribute>
					
				</Data>
			</Header>
			<xsl:choose>
			<xsl:when test="//Entry">
			
			<xsl:variable name="countESMwarning">
				<xsl:value-of select="count(//Entry[@status='3']/FileName[normalize-space(text()) = 'ESMLog'])"/>
			</xsl:variable>
			<xsl:variable name="countESMcritical">
				<xsl:value-of select="count(//Entry[@status='4']/FileName[normalize-space(text()) = 'ESMLog'])"/>
			</xsl:variable>
			<xsl:if test="Entry/FileName='ESMLog'">
			<Row>
				
					<Data name="Status" align="center" type="status">
						<xsl:choose>
							<xsl:when test = "$countESMcritical &gt; 0">
								<xsl:attribute name="value">
									<xsl:value-of select="4"/>
								</xsl:attribute>
							</xsl:when>
							<xsl:when test = "$countESMcritical = 0 and $countESMwarning &gt; 0">
								<xsl:attribute name="value">
									<xsl:value-of select="3"/>
								</xsl:attribute>
							</xsl:when>						
						</xsl:choose>
					</Data>
					<Data name="Name" align="center">
						<xsl:attribute name="value">
							<xsl:value-of select="$strESMLog"/> (<xsl:value-of select="$countESMcritical"/> Critical and  <xsl:value-of select="$countESMwarning"/> Warning Entries)
						</xsl:attribute>
					</Data>
					<Data name="Location" align="center" type = "link">
						<xsl:attribute name="value">
							<xsl:value-of select="$strESMLog"/>
						</xsl:attribute>
						<xsl:attribute name="link">true</xsl:attribute>
						<xsl:attribute name="href">ESMLog.xml</xsl:attribute>
						<!--<xsl:attribute name="href"><xsl:value-of select="strESMLogFile"/>.xml</xsl:attribute>-->
					</Data>
					<Data name="Details" align="center">
						<xsl:attribute name="value">
							<xsl:value-of select="Details"/>
						</xsl:attribute>
					</Data>
			</Row>
			</xsl:if>
			<xsl:for-each select="Entry">
			<xsl:choose>
				<xsl:when test="FileName!='ESMLog' and FileName!='Memarr'">
				<Row>			
				
					<Data name="Status" type="status" align="center">
						<xsl:attribute name="value">
							<xsl:value-of select="@status"/>
						</xsl:attribute>
					</Data>
					<Data name="Name" align="center">
						<xsl:attribute name="value">
							<xsl:value-of select="Name"/>
						</xsl:attribute>
					</Data>
					<Data name="Location" align="center" type = "link">
							<xsl:choose>
								<xsl:when test = "Location !='None'">
									<xsl:attribute name="value">
										<xsl:value-of select="Location"/>
									</xsl:attribute>
								</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="value">
									<xsl:value-of select="$strNA5"/>
								</xsl:attribute>
							</xsl:otherwise>
							</xsl:choose>
						<xsl:attribute name="link">true</xsl:attribute>
						<xsl:attribute name="href"><xsl:value-of select="FileName"/>.xml</xsl:attribute>
					</Data>
					<Data name="Details" align="center">
						<xsl:attribute name="value">
							<xsl:value-of select="Details"/>
						</xsl:attribute>
					</Data>
				</Row>			
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
			</xsl:when>
			</xsl:choose>
		</TableData>	
	</xsl:template>
	<xsl:template match="*"/>
</xsl:stylesheet>