<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
<xsl:output method="xml" encoding="UTF-8"></xsl:output>
<xsl:param name="filter" select="'date;a'" />


<xsl:template match="/osda">
	<xsl:processing-instruction name="xml-stylesheet">
		<xsl:text>type="text/xsl" </xsl:text>
		<xsl:text>href="DataArea.xsl"</xsl:text>
</xsl:processing-instruction>
     <OMA skin="modern" >
		<DataArea>
			<PageTitle>
				<xsl:attribute name="display"><!--XLATESTART-->Application Log<!--XLATESTOP--></xsl:attribute>
			</PageTitle>
			<SubHeader>
				<xsl:choose>
				<xsl:when test="LogLimited">
					<xsl:attribute name="display"><xsl:value-of select="LogLimited"/></xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="display"><xsl:value-of select="LogType"/>Application Log</xsl:attribute>
				</xsl:otherwise>
				</xsl:choose>
			</SubHeader>
			<xsl:choose>
				<xsl:when test="SMStatus != '0' ">
					<TableData>
						<Row>
							<Data>
								<xsl:attribute name="value"><!--XLATESTART--><xsl:value-of select="LogType"/> Log not found.<!--XLATESTOP--></xsl:attribute>
							</Data>
						</Row>
					</TableData>
				</xsl:when>
				<xsl:otherwise>
					<xsl:choose>
						<xsl:when test="not (LogEntry)">
							<xsl:call-template name="LogEmpty"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="WinLog"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</DataArea>
	  </OMA>
	</xsl:template>
	
	<xsl:template name="LogEmpty">
		<TableData>
			<Row>
				<Data>
					<xsl:attribute name="value"><!--XLATESTART-->Log is empty<!--XLATESTOP--></xsl:attribute>
				</Data>
			</Row>
		</TableData>
	</xsl:template>
	
	<xsl:template name="WinLog">
        <TableData  columnspacing="true" sortable="true">
            <Header>
                <Data name="Status" >
                    <xsl:attribute name="value"><!--XLATESTART-->Status<!--XLATESTOP--></xsl:attribute>
                    <xsl:attribute name="display">
                        <!--XLATESTART-->Status<!--XLATESTOP-->
                    </xsl:attribute>
                    <xsl:attribute name="link">true</xsl:attribute>
                </Data>
                <Data name="Type" >
                    <xsl:attribute name="value"><!--XLATESTART-->Type<!--XLATESTOP--></xsl:attribute>
                    <xsl:attribute name="display">
                        <!--XLATESTART-->Type<!--XLATESTOP-->
                    </xsl:attribute>
                    <xsl:attribute name="link">true</xsl:attribute>
                    <!-- Removed Link to sort file -->
				</Data>
                <Data name="Source" >
                    <xsl:attribute name="value"><!--XLATESTART-->Source<!--XLATESTOP--></xsl:attribute>
                    <xsl:attribute name="display">
                        <!--XLATESTART-->Source<!--XLATESTOP-->
                    </xsl:attribute>
                    <xsl:attribute name="link">true</xsl:attribute>
                    <!-- Removed Link to sort file -->
				</Data>
                <Data name="DateTime">
                    <xsl:attribute name="value"><!--XLATESTART-->DateTime<!--XLATESTOP--></xsl:attribute>
                    <xsl:attribute name="display">
                        <!--XLATESTART-->DateTime<!--XLATESTOP-->
                    </xsl:attribute>
                    <xsl:attribute name="link">true</xsl:attribute>
                    <!-- Removed Link to sort file -->
				</Data>
                <Data name="EventID" >
                    <xsl:attribute name="value"><!--XLATESTART-->Event ID<!--XLATESTOP--></xsl:attribute>
                    <xsl:attribute name="display">
                        <!--XLATESTART-->Event ID<!--XLATESTOP-->
                    </xsl:attribute>
                    <xsl:attribute name="link">true</xsl:attribute>
                </Data>
                <Data name="Message" >
                    <xsl:attribute name="value"><!--XLATESTART-->Message  or Comment<!--XLATESTOP--></xsl:attribute>
                    <xsl:attribute name="display">
                        <!--XLATESTART-->Message  or Comment<!--XLATESTOP-->
                    </xsl:attribute>
                    <xsl:attribute name="link">true</xsl:attribute>
                </Data>
			</Header>
			
			<xsl:apply-templates select="LogEntry">
			</xsl:apply-templates>
		</TableData>
	</xsl:template>

	<xsl:template match="LogEntry">
		<Row>
			<xsl:choose>
				<xsl:when test="EventID">
					<Data type="status" >
						<!--<xsl:attribute name="status"><xsl:value-of select="status"/></xsl:attribute>-->
						<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="EventType='Error'">
							    <!-- this should give us the Red X icon-->
								<xsl:value-of select="4"/>
							</xsl:when>
							<xsl:when test="EventType='Warning'">
							    <!-- this should give us the yellow triangle icon-->
								<xsl:value-of select="3"/>
							</xsl:when>
							
							<xsl:otherwise>
							    <!-- this should give us the Information icon-->
								<xsl:value-of select="11"/>
							</xsl:otherwise>
						</xsl:choose></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="value"><xsl:value-of select="EventType"/></xsl:attribute>
						<!--<xsl:attribute name="width"><xsl:value-of select="100"/></xsl:attribute>-->
					</Data>
					<Data>
						<xsl:attribute name="value"><xsl:value-of select="Source"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="value"><xsl:value-of select="Time"/></xsl:attribute>
						<!--<xsl:attribute name="width"><xsl:value-of select="300"/></xsl:attribute>-->
					</Data>
					<Data>
						<xsl:attribute name="value"><xsl:value-of select="EventID"/></xsl:attribute>
					</Data>
					<Data>
						<xsl:attribute name="value"><xsl:value-of select="Message"/></xsl:attribute>
					</Data>
				</xsl:when>
				<xsl:otherwise>
					<Data>
						<xsl:attribute name="value"><xsl:value-of select="."/></xsl:attribute>
					</Data>
				</xsl:otherwise>
			</xsl:choose>
		</Row>
	</xsl:template>

	<xsl:template match="*"/>

</xsl:stylesheet>
