<!-- This is the XSL to render the Controller Information page.  The associated web plugin is the ControllerInfoWebPlugin. -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
	<!-- Include some common templates created by SS -->
	<xsl:template match="OMA">
		<xsl:variable name="checkAdmin">
			<xsl:choose>
				<xsl:when test="OMAUserRights = '7'">true</xsl:when>
				<xsl:otherwise>false</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<OMA skin = "modern">
		<DataArea>
			<PageTitle>
        <xsl:attribute name="display">
          <xsl:choose>
            <xsl:when test="substring(/*/Channels/DCStorageObject/AttributesMask,26,1)='1'">
              <xsl:value-of select="$strTitleLogicalPart1"/>
            </xsl:when>
            <xsl:otherwise>
				<xsl:if test="//BusProtocol!='9'">
					<xsl:value-of select="$strTitle1Part1" />
				</xsl:if>
				<xsl:if test="//BusProtocol='9'">
					<xsl:value-of select="$strExtenderPart1" />
				</xsl:if>
				<xsl:value-of select="/*/Channels/DCStorageObject/Channel"/>
            </xsl:otherwise>
          </xsl:choose>
          
          <xsl:value-of select="$strTitle1Part2"/>
          <xsl:value-of select="$strTitle1Part3"/>
          <xsl:value-of select="/*/Channels/@ControllerName"/>
          <xsl:value-of select="$strTitle1Part4"/>
        </xsl:attribute>
			</PageTitle>
			<CustomButton>
				<Data link="true" name="Return">
					<xsl:attribute name="display"><xsl:value-of select="$strRetSystemSummary"/></xsl:attribute>
					<xsl:attribute name="href">syssum.xml</xsl:attribute>
				</Data>
			</CustomButton>
			<xsl:apply-templates select="Channels/DCStorageObject">
				<xsl:with-param name="tasks">
					<xsl:value-of select="$checkAdmin"/>
				</xsl:with-param>
			</xsl:apply-templates>
		</DataArea>
		</OMA>
	</xsl:template>
	<xsl:template match="Channels/DCStorageObject">
		<xsl:param name="tasks"/>
		<ComboData ignoreJumpBar="true">
			<ListData>
				<xsl:variable name="showtasks">
					<xsl:value-of select="$tasks"/>
				</xsl:variable>
				<SubHeader>
					<xsl:attribute name="display"><xsl:value-of select="$strSubHeader1"/></xsl:attribute>
					<xsl:attribute name="status"><xsl:value-of select="ObjStatus"/></xsl:attribute>
				</SubHeader>
				<xsl:call-template name="ChannelList">
					<xsl:with-param name="tasks" select="$showtasks"/>
				</xsl:call-template>
			</ListData>
			<xsl:if test="count(../../Enclosures)>0">
				<TableData columnspacing="true">
					<xsl:variable name="showtasks">false</xsl:variable>
					<SubHeader>
						<xsl:attribute name="display"><xsl:value-of select="$strSubHeader4"/></xsl:attribute>
					</SubHeader>
					<Header>
						<xsl:call-template name="EnclosureTableHeader">
							<xsl:with-param name="tasks" select="$showtasks"/>
						</xsl:call-template>
					</Header>
					<xsl:for-each select="../../Enclosures/DCStorageObject">
						<xsl:call-template name="EnclosureTableRows">
							<xsl:with-param name="tasks" select="$showtasks"/>
						</xsl:call-template>
					</xsl:for-each>
				</TableData>
			</xsl:if>
		</ComboData>
	</xsl:template>
	
	<!-- The following template is for PEDiags channel output files -->
	<xsl:template match="DataArea">
	<OMA skin = "modern">
		<DataArea>
			<PageTitle>				
				<xsl:if test="//BusProtocol != '9'">
					<xsl:attribute name="display"><xsl:value-of select="$strTitle1Part1"/><xsl:value-of select="/*/Channel/@channel"/><xsl:value-of select="$strTitle1Part2"/><xsl:value-of select="$strTitle1Part3"/><xsl:value-of select="/*/Channel/@name"/><xsl:value-of select="$strTitle1Part4"/></xsl:attribute>
				</xsl:if>
				<xsl:if test="//BusProtocol = '9'">
					<xsl:attribute name="display"><xsl:value-of select="$strExtenderPart1"/><xsl:value-of select="/*/Channel/@channel"/><xsl:value-of select="$strTitle1Part2"/><xsl:value-of select="$strTitle1Part3"/><xsl:value-of select="/*/Channel/@name"/><xsl:value-of select="$strTitle1Part4"/></xsl:attribute>
				</xsl:if>
			</PageTitle>
			<CustomButton>
				<Data link="true" name="Return">
					<xsl:attribute name="display"><xsl:value-of select="$strRetSystemSummary"/></xsl:attribute>
					<xsl:attribute name="href">syssum.xml</xsl:attribute>
				</Data>
			</CustomButton>
			<xsl:apply-templates select="Channel/DCStorageObject">
			</xsl:apply-templates>
		</DataArea>
		</OMA>
	</xsl:template>
	
	<!--  The following template formats the pediags channel output to desired format ready to display  -->
	<xsl:template match="Channel/DCStorageObject">
	<!--  Display channel info in list format -->
		<ListData type="custom" columnspacing="true">
	
		<Data columnspacing="true" name="Name" editable="false" type="usting">
			<xsl:attribute name="display">
				<xsl:value-of select="$strName" /> 
			</xsl:attribute>
			<xsl:attribute name="value">
				<xsl:value-of select="Name" /> 
			</xsl:attribute>
		</Data>
	
		<Data columnspacing="true" name="Status" editable="false" type="usting">
			<xsl:attribute name="display">
				<xsl:value-of select="$strStatus" /> 
			</xsl:attribute>
			<xsl:attribute name="value">
				<xsl:value-of select="Status" /> 
			</xsl:attribute>
		</Data>
		
		<Data columnspacing="true" name="Firmware" editable="false" type="usting">
			<xsl:attribute name="display">
				<xsl:value-of select="$strFW" /> 
			</xsl:attribute>
			<xsl:attribute name="value">
				<xsl:value-of select="Firmware" /> 
			</xsl:attribute>
		</Data>
		
		<Data columnspacing="true" name="Descriptor" editable="false" type="usting">
			<xsl:attribute name="display">Device Descriptor</xsl:attribute>
			<xsl:attribute name="value">
				<xsl:value-of select="Descriptor" /> 
			</xsl:attribute>
		</Data>
		
		<Data columnspacing="true" name="Description" editable="false" type="usting">
			<xsl:attribute name="display">Description</xsl:attribute>
			<xsl:attribute name="value">
				<xsl:value-of select="Description" /> 
			</xsl:attribute>
		</Data>
		
		<Data columnspacing="true" name="Location" editable="false" type="usting">
			<xsl:attribute name="display">Device Location</xsl:attribute>
			<xsl:attribute name="value">
				<xsl:value-of select="Location" /> 
			</xsl:attribute>
		</Data>
		
		<Data columnspacing="true" name="ParentLocation" editable="false" type="usting">
			<xsl:attribute name="display">Parent Location</xsl:attribute>
			<xsl:attribute name="value">
				<xsl:value-of select="ParentLocation" /> 
			</xsl:attribute>
		</Data>
	
		<Data columnspacing="true" name="Manufacturer" editable="false" type="usting">
			<xsl:attribute name="display">Manufacturer</xsl:attribute>
			<xsl:attribute name="value">
				<xsl:value-of select="Manufacturer" /> 
			</xsl:attribute>
		</Data>
		
		<Data columnspacing="true" name="SerialNumber" editable="false" type="usting">
			<xsl:attribute name="display">
				<xsl:value-of select="$strSerial" /> 
			</xsl:attribute>
			<xsl:attribute name="value">
				<xsl:value-of select="SerialNumber" /> 
			</xsl:attribute>
		</Data>
	
		<Data columnspacing="true" name="ModelNumber" editable="false" type="usting">
			<xsl:attribute name="display">Model Number</xsl:attribute>
			<xsl:attribute name="value">
				<xsl:value-of select="ModelNumber" /> 
			</xsl:attribute>
		</Data>
		
		<Data columnspacing="true" name="AssetTag" editable="false" type="usting">
			<xsl:attribute name="display">
				<xsl:value-of select="$strAssetTag" /> 
			</xsl:attribute>
			<xsl:attribute name="value">
				<xsl:value-of select="AssetTag" /> 
			</xsl:attribute>
		</Data>

<!-- Since channels do not have any characterstics, the following is a dead code -->	
		<xsl:for-each select="Characteristic/Data">
		<Data columnspacing="true" name="Data" editable="false" type="usting">
			<xsl:attribute name="display">
				<xsl:value-of select="@name" />
			</xsl:attribute>
			<xsl:attribute name="value">
				<xsl:value-of select="@value" />
			</xsl:attribute>
		</Data>
		</xsl:for-each>
	
		</ListData>
	
	</xsl:template>

</xsl:stylesheet>
