<!-- This is the XSL to render the Controller Information page.  The associated web plugin is the ControllerInfoWebPlugin. -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
	<!-- Include some common templates created by SS -->
	
	<!-- Define a bunch of global variables-->
	<xsl:variable name="GLOBAL_VAR_CurrentFirmwareVersion"><xsl:value-of select="/OMA/Controllers/DCStorageObject/FirmwareVer"/></xsl:variable>
	<xsl:variable name="GLOBAL_VAR_RequiredFirmwareVersion"><xsl:value-of select="/OMA/Controllers/DCStorageObject/RequiredFirmwareVersion"/></xsl:variable>
	<xsl:variable name="GLOBAL_VAR_CurrentDriverVersion"><xsl:value-of select="/OMA/Controllers/DCStorageObject/CurrentDriverVersion"/></xsl:variable>
	<xsl:variable name="GLOBAL_VAR_RequiredDriverVersion"><xsl:value-of select="/OMA/Controllers/DCStorageObject/RequiredDriverVersion"/></xsl:variable>
	
	<!-- Define Global variable for health status that can be used by other XSL files. Currently this variables are used to display status in Firmware/Driver version info page-->
	<xsl:variable name="HEALTH_STATUS_UNKNOWN_0">0</xsl:variable>
	<xsl:variable name="HEALTH_STATUS_UNKNOWN_1">1</xsl:variable>
	<xsl:variable name="HEALTH_STATUS_OK">2</xsl:variable>
	<xsl:variable name="HEALTH_STATUS_NON_CRITICAL">3</xsl:variable>
	<xsl:variable name="HEALTH_STATUS_CRITICAL">4</xsl:variable>
	<xsl:variable name="HEALTH_STATUS_NON_RECOVERABLE">5</xsl:variable>
	
	<xsl:template match="DataArea">
		<OMA skin="modern">
		<DataArea>
			<PageTitle>
				<xsl:attribute name="display"><xsl:value-of select="$strTitlePart1"/>: <xsl:value-of select="/*/Controller/@name" /></xsl:attribute>
			</PageTitle>
			<CustomButton>
<Data link="true" name="Return">
				<xsl:attribute name="display"><xsl:value-of select="$strRetSystemSummary"/></xsl:attribute>
				<xsl:attribute name="href">syssum.xml</xsl:attribute>
			</Data>
		</CustomButton>
			<xsl:apply-templates select="/*/Controller/DCStorageObject">
			</xsl:apply-templates>
			<!-- Check if any channels are present. If yes channel table needs to be added -->
			<xsl:if test="count(/*/Channel)>0">
				<TableData columnspacing="true">
				<SubHeader>
					<xsl:attribute name="display"><xsl:value-of select="$strSubHeader3"/></xsl:attribute>
				</SubHeader>
				<Header>
					<Data name="Status" editable="false" type="ustring" align="center">
						<xsl:attribute name="display"><xsl:value-of select="$strStatus"/></xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="$strStatus"/></xsl:attribute>
					</Data>
					<Data name="Name" editable="false" type="ustring" align="left">
						<xsl:attribute name="display"><xsl:value-of select="$strName"/></xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="$strName"/></xsl:attribute>
					</Data>
					<Data name="ChanType" editable="false" type="ustring" align="left">
						<xsl:attribute name="display"><xsl:value-of select="$strChanType"/></xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="$strChanType"/></xsl:attribute>
					</Data>
				</Header>
				<xsl:for-each select="/*/Channel/DCStorageObject">
					<xsl:call-template name="SataChannelRows"></xsl:call-template>
				</xsl:for-each>
				</TableData>
			</xsl:if>
		</DataArea>
		</OMA>
	</xsl:template>
	
	<!-- Template to display the controller object -->
	<xsl:template match="Controller/DCStorageObject">
		<ComboData ignoreJumpBar="true">
			<ListData columnspacing="true">
				<SubHeader>
					<xsl:attribute name="display"><xsl:value-of select="$strSubHeader1"/></xsl:attribute>
					<!-- The first column is the status icon. OMSA considers value of 2 as "working fine", whereas in PEDiags it must be 0. So adding check accordingly -->
					<xsl:attribute name="status">
					<xsl:choose>
						<xsl:when test="//ObjStatus=0">2</xsl:when>
						<xsl:otherwise>1</xsl:otherwise>
					</xsl:choose>
					</xsl:attribute>
				</SubHeader>
				<xsl:call-template name="ControllerTable">
				</xsl:call-template>
			</ListData>
		</ComboData>
	</xsl:template>
	
	<!-- Channel rows template -->
	<xsl:template name="SataChannelRows">
			<Row>
				<!-- The first column is the status icon. OMSA considers value of 2 as "working fine", whereas in PEDiags it must be 0. So adding check accordingly -->
				<Data type="status" align="center">
					<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="//ObjStatus=0">2</xsl:when>
						<xsl:otherwise>1</xsl:otherwise>
					</xsl:choose>
					</xsl:attribute>
				</Data>
				<Data name="Test" editable="false" type="ustring" display="Name" align="left">
					<xsl:attribute name="value"><xsl:value-of select="Name"/></xsl:attribute>
				</Data>
				<Data name="Test" editable="false" type="ustring" display="Type" align="left">
					<xsl:attribute name="value">ATA</xsl:attribute>
				</Data>
			</Row>
	</xsl:template>
	
	<!-- CONTROLLER TABLE -->
	<xsl:template name="ControllerTable">
	
		<Data name="Name" editable="false" type="usting">
			<xsl:attribute name="display">
				<xsl:value-of select="$strName" /> 
			</xsl:attribute>
			<xsl:attribute name="value">
				<xsl:value-of select="Name" /> 
			</xsl:attribute>
		</Data>
	
		<Data name="Status" editable="false" type="usting">
			<xsl:attribute name="display">
				<xsl:value-of select="$strStatus" /> 
			</xsl:attribute>
			<xsl:attribute name="value">
				<xsl:value-of select="Status" /> 
			</xsl:attribute>
		</Data>
		
		<Data name="Firmware" editable="false" type="usting">
			<xsl:attribute name="display">
				<xsl:value-of select="$strFW" /> 
			</xsl:attribute>
			<xsl:attribute name="value">
				<xsl:value-of select="Firmware" /> 
			</xsl:attribute>
		</Data>
		
		<Data name="Descriptor" editable="false" type="usting">
			<xsl:attribute name="display">Device Descriptor</xsl:attribute>
			<xsl:attribute name="value">
				<xsl:value-of select="Descriptor" /> 
			</xsl:attribute>
		</Data>
		
		<Data name="Description" editable="false" type="usting">
			<xsl:attribute name="display">Description</xsl:attribute>
			<xsl:attribute name="value">
				<xsl:value-of select="Description" /> 
			</xsl:attribute>
		</Data>
		
		<Data name="Location" editable="false" type="usting">
			<xsl:attribute name="display">Device Location</xsl:attribute>
			<xsl:attribute name="value">
				<xsl:value-of select="Location" /> 
			</xsl:attribute>
		</Data>
		
		<Data name="ParentLocation" editable="false" type="usting">
			<xsl:attribute name="display">Parent Location</xsl:attribute>
			<xsl:attribute name="value">
				<xsl:value-of select="ParentLocation" /> 
			</xsl:attribute>
		</Data>
	
		<Data name="Manufacturer" editable="false" type="usting">
			<xsl:attribute name="display">Manufacturer</xsl:attribute>
			<xsl:attribute name="value">
				<xsl:value-of select="Manufacturer" /> 
			</xsl:attribute>
		</Data>
		
		<Data name="SerialNumber" editable="false" type="usting">
			<xsl:attribute name="display">
				<xsl:value-of select="$strSerial" /> 
			</xsl:attribute>
			<xsl:attribute name="value">
				<xsl:value-of select="SerialNumber" /> 
			</xsl:attribute>
		</Data>
	
		<Data name="ModelNumber" editable="false" type="usting">
			<xsl:attribute name="display">Model Number</xsl:attribute>
			<xsl:attribute name="value">
				<xsl:value-of select="ModelNumber" /> 
			</xsl:attribute>
		</Data>
		
		<Data name="AssetTag" editable="false" type="usting">
			<xsl:attribute name="display">
				<xsl:value-of select="$strAssetTag" /> 
			</xsl:attribute>
			<xsl:attribute name="value">
				<xsl:value-of select="AssetTag" /> 
			</xsl:attribute>
		</Data>
	
		<!-- Typically SATA controller doesnt have any characterstic data. So the following for-each should not enter -->
		<xsl:for-each select="Characteristic/Data">
		<Data columnspacing="true" name="Data" editable="false" type="usting">
			<xsl:attribute name="display">
				<xsl:value-of select="@name" />
			</xsl:attribute>
			<xsl:attribute name="value">
				<xsl:value-of select="@value" />
			</xsl:attribute>
		</Data>
		</xsl:for-each>
	</xsl:template>
	
</xsl:stylesheet>
