<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
	<xsl:output method="xml" encoding="UTF-8"/>
	<xsl:template name="OMA">
		<xsl:processing-instruction name="xml-stylesheet">
			<xsl:text>type="text/xsl" </xsl:text>
			<xsl:text>href="DataArea.xsl"</xsl:text>
		</xsl:processing-instruction>
		<OMA skin="modern">
			<DataArea>
				<PageTitle>
					<xsl:attribute name="display"><!--XLATESTART-->FC HBA Information<!--XLATESTOP--></xsl:attribute>
				</PageTitle>
				<xsl:apply-templates select="HbaInfo"/>
				<xsl:apply-templates select="LunInfo"/>
			</DataArea>
		</OMA>
	</xsl:template>
	<xsl:template match="HbaInfo">
		<xsl:for-each select="Hba">
			<xsl:call-template name="Hba"/>
		</xsl:for-each>
	</xsl:template>
	<xsl:template match="LunInfo">
		<xsl:for-each select="Lun">
			<xsl:call-template name="Lun"/>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="Hba">
		<ListData type="custom">
			<Data>
				<xsl:attribute name="display"><!--XLATESTART-->Name<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="Name"/></xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="display"><!--XLATESTART-->Host WWN<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="HostWWN"/></xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="display"><!--XLATESTART-->Vendor Name<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="VendorName"/></xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="display"><!--XLATESTART-->Model<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="Model"/></xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="display"><!--XLATESTART-->Firmware Version<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="FirmwareVersion"/></xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="display"><!--XLATESTART-->Driver Version<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="DriverVersion"/></xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="display"><!--XLATESTART-->Serial Number<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="SerialNumber"/></xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="display"><!--XLATESTART-->Vendor Code<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="VendorCode"/></xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="display"><!--XLATESTART-->Type<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="Type"/></xsl:attribute>
			</Data>
			<xsl:for-each select="Port">
				<xsl:call-template name="Port"/>
			</xsl:for-each>
		</ListData>
	</xsl:template>
	<xsl:template name="Lun">
		<ListData type="custom">
			<Data>
				<xsl:attribute name="display"><!--XLATESTART-->Device<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="Device"/></xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="display">
					<!--XLATESTART-->Vendor<!--XLATESTOP-->
				</xsl:attribute>
				<xsl:attribute name="value">
				<!--following changes made by chethana, to mask invalid vendor name '('-->
					<xsl:choose>
						<xsl:when test="Vendor='('"><xsl:value-of select="$strUNKNOWN"/></xsl:when>
						<xsl:otherwise><xsl:value-of select="Vendor"/></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="display"><!--XLATESTART-->Product<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="Product"/></xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="display"><!--XLATESTART-->Revision<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="Rev"/></xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="display"><!--XLATESTART-->Serial Number<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="SerialNumber"/></xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="display"><!--XLATESTART-->Capacity<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="Capacity"/></xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="display"><!--XLATESTART-->Bus<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="Bus"/></xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="display"><!--XLATESTART-->Target ID<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="TargetID"/></xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="display"><!--XLATESTART-->LUN<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="Lun"/></xsl:attribute>
			</Data>
		</ListData>
	</xsl:template>
	<xsl:template name="Port">
		<Data>
			<xsl:attribute name="display"><!--XLATESTART--><!--XLATESTOP--></xsl:attribute>
			<xsl:attribute name="value"/>
		</Data>
		<Data>
			<xsl:attribute name="display"><!--XLATESTART-->Port Number<!--XLATESTOP--></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="Number"/></xsl:attribute>
		</Data>
		<Data>
			<xsl:attribute name="display"><!--XLATESTART-->Port WWN<!--XLATESTOP--></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="WWN"/></xsl:attribute>
		</Data>
		<Data>
			<xsl:attribute name="display"><!--XLATESTART-->Port OS Name<!--XLATESTOP--></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="OSName"/></xsl:attribute>
		</Data>
		<Data>
			<xsl:attribute name="display"><!--XLATESTART-->Port Type<!--XLATESTOP--></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="Type"/></xsl:attribute>
		</Data>
		<Data>
			<xsl:attribute name="display"><!--XLATESTART-->Port Speed<!--XLATESTOP--></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="Speed"/></xsl:attribute>
		</Data>
		<Data>
			<xsl:attribute name="display"><!--XLATESTART-->Port Supported Speed<!--XLATESTOP--></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="SupportedSpeed"/></xsl:attribute>
		</Data>
		<Data>
			<xsl:attribute name="display"><!--XLATESTART-->Port State<!--XLATESTOP--></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="State"/></xsl:attribute>
		</Data>
		<Data>
			<xsl:attribute name="display"><!--XLATESTART-->Port FCID<!--XLATESTOP--></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="FCID"/></xsl:attribute>
		</Data>
	</xsl:template>
	<xsl:template match="*">
		<xsl:call-template name="OMA"/>
	</xsl:template>
</xsl:stylesheet>
