<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
	<xsl:output method="xml" encoding="UTF-8"/>
	<xsl:template name="OMA">
		<xsl:processing-instruction name="xml-stylesheet">
			<xsl:text>type="text/xsl" </xsl:text>
			<xsl:text>href="DataArea.xsl"</xsl:text>
		</xsl:processing-instruction>
		<OMA skin="modern">
			<DataArea>
				<PageTitle>
					<xsl:attribute name="display"><!--XLATESTART-->iSCSI Initiator Information<!--XLATESTOP--></xsl:attribute>
				</PageTitle>
				<xsl:apply-templates select="iScsiInfo"/>
			</DataArea>
		</OMA>
	</xsl:template>
	<xsl:template match="iScsiInfo">
			<xsl:call-template name="iSCSI"/> 
      <xsl:if test="count(listtargets/*) > 0">
			    <xsl:call-template name="listtargets"/>
      </xsl:if>
    <xsl:if test="count(sessions/*) > 0 or ../OS = 'linux'">
          <xsl:call-template name="listsessions"/>
      </xsl:if>
      <xsl:if test="count(portals/*) > 0 or ../OS = 'linux'">
			    <xsl:call-template name="listportals"/>
      </xsl:if> 
	</xsl:template>
	<xsl:template name="iSCSI">
		<ListData type="custom">
			<Data>
				<xsl:attribute name="display"><!--XLATESTART-->Initiator Version<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="InitiatorVersion"/></xsl:attribute>
			</Data>
		</ListData>
	</xsl:template>
	<xsl:template name="listtargets">		
		<TableData columnspacing="true">
				<SubHeader>
					<xsl:attribute name="display">Targets List</xsl:attribute>
				</SubHeader>
				<xsl:for-each select="listtargets/*">
				<Row>
						<Data>
							<xsl:attribute name="value"><xsl:value-of select="."/></xsl:attribute>
						</Data>
				</Row>
				</xsl:for-each>
		</TableData>
	</xsl:template>	
	<xsl:template name="listsessions">
	<TableData>
				<SubHeader>
					<xsl:attribute name="display">Sessions List</xsl:attribute>
				</SubHeader>
				<Row>
				<Data>
					<xsl:attribute name="value">
						Total of <xsl:value-of select="sessions/TotalSession"/> sessions
					</xsl:attribute>
				</Data>
				</Row>
			</TableData>	
			<xsl:for-each select="sessions/session">
			<TableData>
				<SubHeader>
					<xsl:attribute name="display">Session <xsl:value-of select="position()"/>
                </xsl:attribute>
				</SubHeader>
				<xsl:for-each select="*">
				<xsl:if test="node()=text()">	
				<Row>							
						<Data>
							<xsl:attribute name="value"><xsl:value-of select="name()"/></xsl:attribute>
						</Data>
						<Data>
							<xsl:attribute name="value"><xsl:value-of select="."/></xsl:attribute>
						</Data>
					</Row>
				</xsl:if>
				</xsl:for-each>	
				</TableData>
				<xsl:for-each select="*">
				<xsl:if test="name() = 'Connections'">
					<TableData>
				<SubHeader>
					<xsl:attribute name="display">Connections</xsl:attribute>
				</SubHeader>
						<xsl:for-each select="*">
						<Row>
							<Data>
							<xsl:attribute name="value"><xsl:value-of select="name()"/></xsl:attribute>
						</Data>
						<Data>
							<xsl:attribute name="value"><xsl:value-of select="."/></xsl:attribute>
						</Data>
							</Row>
						</xsl:for-each>
					</TableData>
				</xsl:if>
				<xsl:if test="name() = 'Devices'">
					<TableData>
				<SubHeader>
					<xsl:attribute name="display">Devices</xsl:attribute>
				</SubHeader>
						<xsl:for-each select="*">
						<Row>
							<Data>
							<xsl:attribute name="value"><xsl:value-of select="name()"/></xsl:attribute>
						</Data>
						<Data>
							<xsl:attribute name="value"><xsl:value-of select="."/></xsl:attribute>
						</Data>
							</Row>
						</xsl:for-each>
					</TableData>
				</xsl:if>
				</xsl:for-each>	
			</xsl:for-each>			
	</xsl:template>	
	<xsl:template name="listportals">
	<TableData>
				<SubHeader>
					<xsl:attribute name="display">Portals List</xsl:attribute>
				</SubHeader>
				<Row>
				<Data>
					<xsl:attribute name="value">
						Total of <xsl:value-of select="portals/TotalPortals"/> portals
					</xsl:attribute>
				</Data>
				</Row>
			</TableData>	
			<xsl:for-each select="portals/portal">
			<TableData>
			<SubHeader>
					<xsl:attribute name="display">Portal <xsl:value-of select="position()"/>
                </xsl:attribute>
				</SubHeader>
				<xsl:for-each select="*">	
				<Row>							
						<Data>
							<xsl:attribute name="value"><xsl:value-of select="name()"/></xsl:attribute>
						</Data>
						<Data>
							<xsl:attribute name="value"><xsl:value-of select="."/></xsl:attribute>
						</Data>
					</Row>
				</xsl:for-each>	
				</TableData>
				
			</xsl:for-each>		
	
	</xsl:template>	
	<xsl:template match="*">
		<xsl:call-template name="OMA"/>
	</xsl:template>
</xsl:stylesheet>