<!-- This is the XSL to render the Controller Information page.  The associated web plugin is the ControllerInfoWebPlugin. -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
	<!-- Include some common templates created by SS -->
	
	<!-- Define a bunch of global variables-->
	<xsl:variable name="GLOBAL_VAR_CurrentFirmwareVersion"><xsl:value-of select="/OMA/Controllers/DCStorageObject/FirmwareVer"/></xsl:variable>
	<xsl:variable name="GLOBAL_VAR_RequiredFirmwareVersion"><xsl:value-of select="/OMA/Controllers/DCStorageObject/RequiredFirmwareVersion"/></xsl:variable>
	<xsl:variable name="GLOBAL_VAR_CurrentDriverVersion"><xsl:value-of select="/OMA/Controllers/DCStorageObject/CurrentDriverVersion"/></xsl:variable>
	<xsl:variable name="GLOBAL_VAR_RequiredDriverVersion"><xsl:value-of select="/OMA/Controllers/DCStorageObject/RequiredDriverVersion"/></xsl:variable>
	
	<!-- Define Global variable for health status that can be used by other XSL files. Currently this variables are used to display status in Firmware/Driver version info page-->
	<xsl:variable name="HEALTH_STATUS_UNKNOWN_0">0</xsl:variable>
	<xsl:variable name="HEALTH_STATUS_UNKNOWN_1">1</xsl:variable>
	<xsl:variable name="HEALTH_STATUS_OK">2</xsl:variable>
	<xsl:variable name="HEALTH_STATUS_NON_CRITICAL">3</xsl:variable>
	<xsl:variable name="HEALTH_STATUS_CRITICAL">4</xsl:variable>
	<xsl:variable name="HEALTH_STATUS_NON_RECOVERABLE">5</xsl:variable>
	
	<xsl:template match="OMA">
		<xsl:variable name="checkAdmin">
			<xsl:choose>
				<xsl:when test="OMAUserRights = '7'">true</xsl:when>
				<xsl:otherwise>false</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="isCluster">
				<xsl:choose>
					<xsl:when test="substring(/OMA/Controllers/DCStorageObject/AttributesMask,32,1)!='0'">1</xsl:when>
				  <xsl:otherwise>0</xsl:otherwise>
			 </xsl:choose>
		</xsl:variable>	
		<OMA skin="modern">
		<DataArea>
			<!-- The call to the scripts template is needed to include the new common javascript function GetLocalUrl( ) for error handling -->
			<!-- This call must reside within the <DataArea> tag -->
			<xsl:choose>
				<xsl:when test= "count(Controllers/DCStorageObject)=0">
					<PageTitle>
						<xsl:attribute name="display"><xsl:value-of select="$strSummaryNotAvailable"/></xsl:attribute>
					</PageTitle>
					<CustomButton>
						<Data link="true" name="Return">
							<xsl:attribute name="display"><xsl:value-of select="$strRetSystemSummary"/></xsl:attribute>
							<xsl:attribute name="href">syssum.xml</xsl:attribute>
						</Data>
					</CustomButton>
				</xsl:when>
				<xsl:otherwise>
					<PageTitle>
						<xsl:attribute name="display"><xsl:value-of select="$strTitlePart1"/><xsl:value-of select="/*/Controllers/@ControllerName"/><xsl:value-of select="$strTitlePart2"/></xsl:attribute>
					</PageTitle>
					<CustomButton>
						<Data link="true" name="Return">
							<xsl:attribute name="display"><xsl:value-of select="$strRetSystemSummary"/></xsl:attribute>
							<xsl:attribute name="href">syssum.xml</xsl:attribute>
						</Data>
					</CustomButton>
					<xsl:apply-templates select="/*/Controllers/DCStorageObject">
					<xsl:with-param name="tasks">
						<xsl:value-of select="$checkAdmin"/>
					</xsl:with-param>
					</xsl:apply-templates>
				</xsl:otherwise>
			</xsl:choose>
		</DataArea>
		</OMA>
	</xsl:template>
	<!-- Template to display the controller object -->
	<xsl:template match="Controllers/DCStorageObject">
		<xsl:param name="tasks"/>
		<xsl:param name="checkAdmin"/>
		<ComboData ignoreJumpBar="true">
			<ListData type="custom" columnspacing="true">
				<xsl:variable name="showtasks">
					<xsl:value-of select="$tasks"/>
				</xsl:variable>
				<SubHeader>
					<xsl:attribute name="display"><xsl:value-of select="$strSubHeader1"/></xsl:attribute>
					<xsl:attribute name="status"><xsl:value-of select="ObjStatus"/></xsl:attribute>
				</SubHeader>
				<xsl:call-template name="ControllerTable">
					<xsl:with-param name="tasks" select="$showtasks"/>
				</xsl:call-template>
			</ListData>
			<xsl:if test="MaxVDAllowed>0">
				<xsl:if test="count(../../VirtualDisks)>0">
					<TableData columnspacing="true">
						<xsl:variable name="showtasks">false</xsl:variable>
						<SubHeader>
							<xsl:attribute name="display"><xsl:value-of select="$strSubHeader2"/></xsl:attribute>
						</SubHeader>
						<DescText>
							<xsl:attribute name="display"><xsl:value-of select="$strPromptText"/></xsl:attribute>
						</DescText>
						<xsl:choose>
							<xsl:when test="count(../../VirtualDisks)>0">
								<Header>
									<xsl:call-template name="VirtualDiskTableHeader">
										<xsl:with-param name="tasks" select="$showtasks"/>
									</xsl:call-template>
								</Header>
								<xsl:for-each select="../../VirtualDisks/DCStorageObject">
									<xsl:call-template name="VirtualDiskTableRows">
										<xsl:with-param name="tasks" select="$showtasks"/>
										<xsl:with-param name="caller">com.dell.sm.webplugins.ControllerInfoWebPlugin<xsl:value-of select="/OMA/ControllerOID"/></xsl:with-param>
									</xsl:call-template>
								</xsl:for-each>
							</xsl:when>
							<xsl:otherwise>
								<xsl:if test="$checkAdmin='true'">
									<!--check to see if user had admin rights-->
									<Row>
										<Data type="ustring" name="execute" link="true">
											<xsl:attribute name="display"/>
											<xsl:attribute name="value"><xsl:value-of select="$strNoVD"/></xsl:attribute>
											<xsl:attribute name="href">javascript:callCreate("<xsl:value-of select="../@ControllerName"/>","<xsl:value-of select="/OMA/ControllerOID"/>")</xsl:attribute>
										</Data>
									</Row>
								</xsl:if>
							</xsl:otherwise>
						</xsl:choose>
					</TableData>
				</xsl:if>
			</xsl:if>
			<xsl:if test="count(../../Batteries)>0">
				<TableData columnspacing="true">
					<xsl:variable name="showtasks">false</xsl:variable>
					<SubHeader>
						<xsl:attribute name="display"><xsl:value-of select="$strSubHeader5"/></xsl:attribute>
					</SubHeader>
					<Header>
						<xsl:call-template name="BatteryTableHeader">
							<xsl:with-param name="tasks" select="$showtasks"/>
						</xsl:call-template>
					</Header>
					<xsl:for-each select="../../Batteries/DCStorageObject">
						<xsl:call-template name="BatteryTableRows">
							<xsl:with-param name="tasks" select="$showtasks"/>
						</xsl:call-template>
					</xsl:for-each>
				</TableData>
			</xsl:if>
			<xsl:if test="count(../../Channels)>0">
				<TableData columnspacing="true">
					<xsl:variable name="showtasks">false</xsl:variable>
					<SubHeader>
						<xsl:attribute name="display"><xsl:value-of select="$strSubHeader3"/></xsl:attribute>
					</SubHeader>
					<Header>
						<xsl:call-template name="ChannelTableHeader">
							<xsl:with-param name="tasks" select="$showtasks"/>
						</xsl:call-template>
					</Header>
					<xsl:for-each select="../../Channels/DCStorageObject">
						<xsl:call-template name="ChannelTableRows">
							<xsl:with-param name="tasks" select="$showtasks"/>
						</xsl:call-template>
					</xsl:for-each>
				</TableData>
			</xsl:if>
			<xsl:if test="count(../../Enclosures)>0">
				<TableData columnspacing="true">
					<xsl:variable name="showtasks">false</xsl:variable>
					<SubHeader>
						<xsl:attribute name="display"><xsl:value-of select="$strSubHeader4"/></xsl:attribute>
					</SubHeader>
					<Header>
						<xsl:call-template name="EnclosureTableHeader">
							<xsl:with-param name="tasks" select="$showtasks"/>
							<xsl:with-param name="expanded" select="false"/>
						</xsl:call-template>
					</Header>
					<xsl:for-each select="../../Enclosures/DCStorageObject">
						<xsl:call-template name="EnclosureTableRows">
							<xsl:with-param name="tasks" select="$showtasks"/>
							<xsl:with-param name="expanded" select="false"/>
						</xsl:call-template>
					</xsl:for-each>
				</TableData>
			</xsl:if>
		</ComboData>
	</xsl:template>
	<!-- CONTROLLER TABLE -->
	<xsl:template name="ControllerTable">
		<xsl:param name="tasks"/>
		<xsl:param name="nonRaid">
			<xsl:call-template name="IsObjectNonRaid">
				<xsl:with-param name="Mask">
					<xsl:value-of select="AttributesMask"/>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:param>
	<xsl:param name="ObjID">
		<xsl:call-template name="ModNexus">
			<xsl:with-param name="nexus">
				<xsl:value-of select="Nexus"/>
			</xsl:with-param>
		</xsl:call-template>
        </xsl:param>
		<!-- The current implementation is to have the UI be dynamic in the data it shows.  Only the columns applicable
              to the objects will be displayed.  The CLI will display all columns of data however to ease script parsing. -->
		<xsl:variable name="dynamicView">
			<xsl:choose>
				<xsl:when test="/OMA/@cli = 'true' ">false</xsl:when>
				<xsl:otherwise>true</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<!--xsl:variable name="isCluster">
			<xsl:if test="substring(AttributesMask,32,1)!='0'">true</xsl:if>
		</xsl:variable-->
    <!--xsl:if test="//BusProtocol != '9'"-->
		<xsl:variable name="isCluster">
				<xsl:choose>
					<xsl:when test="ClusterMode">
						<!--Make sure Cluster Allowed bit is ON -->
						<xsl:if test="substring(ClusterMode,30,1)!='0'">true</xsl:if>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="substring(AttributesMask,32,1)!='0'">true</xsl:if>
					</xsl:otherwise>
				</xsl:choose>
		</xsl:variable>
    <!--/xsl:if-->
		<xsl:variable name="isAlarmPresent">
				<xsl:choose>
					<xsl:when test="AlarmState">
						<xsl:if test="substring(AlarmState,31,1)!='0'">true</xsl:if>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="substring(CurrentMethodMask,30,1)!='0' or substring(CurrentMethodMask,29,1)!='0' or substring(CurrentMethodMask,28,1)!='0'">true</xsl:if>
					</xsl:otherwise>
				</xsl:choose>
		</xsl:variable>
		
		<Data name="ID" editable="false" type="ustring">
			<xsl:attribute name="display"><xsl:value-of select="$strID"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="GlobalNo"/></xsl:attribute>
		</Data>
		<Data name="Name" editable="false" type="ustring">
			<xsl:attribute name="display"><xsl:value-of select="$strName"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="Name"/></xsl:attribute>
		</Data>
		<Data name="State" editable="false" type="ustring">
			<xsl:attribute name="display"><xsl:value-of select="$strState"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:call-template name="GetState"><xsl:with-param name="state"><xsl:value-of select="ObjState"/></xsl:with-param></xsl:call-template></xsl:attribute>
		</Data>
		<xsl:if test="//FirmwareVer or $dynamicView = 'false' ">
			<Data name="FW" editable="false" type="ustring">
				<xsl:attribute name="display"><xsl:value-of select="$strFW"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:choose><xsl:when test="FirmwareVer"><xsl:choose><xsl:when test="FirmwareVer = '(null)' "><xsl:value-of select="$strUnknown"/></xsl:when><xsl:otherwise><xsl:value-of select="FirmwareVer"/></xsl:otherwise></xsl:choose></xsl:when><xsl:otherwise><xsl:value-of select="$strNotApplicable"/></xsl:otherwise></xsl:choose></xsl:attribute>
			</Data>
		</xsl:if>
		<!--
		<xsl:if test="//RequiredFirmwareVersion or $dynamicView = 'false' ">
			<Data name="FW" editable="false" type="ustring">
				<xsl:attribute name="display"><xsl:value-of select="$strReqFW"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:choose><xsl:when test="RequiredFirmwareVersion"><xsl:choose><xsl:when test="RequiredFirmwareVersion= '(null)' "><xsl:value-of select="$strUnknown"/></xsl:when><xsl:otherwise><xsl:value-of select="RequiredFirmwareVersion"/></xsl:otherwise></xsl:choose></xsl:when><xsl:otherwise><xsl:value-of select="$strNotApplicable"/></xsl:otherwise></xsl:choose></xsl:attribute>
			</Data>
		</xsl:if>
		-->
		<xsl:if test="//CurrentDriverVersion or $dynamicView = 'false' ">
			<Data name="FW" editable="false" type="ustring">
				<xsl:attribute name="display"><xsl:value-of select="$strDvr"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:choose><xsl:when test="CurrentDriverVersion"><xsl:choose><xsl:when test="CurrentDriverVersion= '(null)' "><xsl:value-of select="$strUnknown"/></xsl:when><xsl:otherwise><xsl:value-of select="CurrentDriverVersion"/></xsl:otherwise></xsl:choose></xsl:when><xsl:otherwise><xsl:value-of select="$strNotApplicable"/></xsl:otherwise></xsl:choose></xsl:attribute>
			</Data>
		</xsl:if>
		<!--
		<xsl:if test="//RequiredDriverVersion or $dynamicView = 'false' ">
			<Data name="FW" editable="false" type="ustring">
				<xsl:attribute name="display"><xsl:value-of select="$strReqDvr"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:choose><xsl:when test="RequiredDriverVersion"><xsl:choose><xsl:when test="RequiredDriverVersion= '(null)' "><xsl:value-of select="$strUnknown"/></xsl:when><xsl:otherwise><xsl:value-of select="RequiredDriverVersion"/></xsl:otherwise></xsl:choose></xsl:when><xsl:otherwise><xsl:value-of select="$strNotApplicable"/></xsl:otherwise></xsl:choose></xsl:attribute>
			</Data>
		</xsl:if>
		-->
		
		<Data name="NumChannels" editable="false" type="ustring">
			<xsl:choose>
				<xsl:when test="BusProtocol = '9'">
					<xsl:attribute name="display"><xsl:value-of select="$strNumExtenders"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="Channels"/></xsl:attribute>
			    </xsl:when>
			   <xsl:otherwise>
				  <xsl:attribute name="display"><xsl:value-of select="$strNumChannels"/></xsl:attribute>
				  <xsl:attribute name="value"><xsl:value-of select="Channels"/></xsl:attribute>
			   </xsl:otherwise>
          </xsl:choose>	
		</Data>
		<xsl:if test="//RebuildRate or $dynamicView = 'false' ">
			<Data name="RbldRate" editable="false" type="ustring">
				<xsl:attribute name="display"><xsl:value-of select="$strRebuildRate"/></xsl:attribute>
				<!-- set value -->
				<xsl:attribute name="value">
				<xsl:choose>
				   <xsl:when test="count(RebuildRate)>0">
				      <xsl:choose>
				         <xsl:when test="RebuildRate = '(null)' ">
				            <xsl:value-of select="$strUnknown"/>
				         </xsl:when>
				         <xsl:otherwise>
				            <xsl:value-of select="RebuildRate"/>
				         </xsl:otherwise>
				      </xsl:choose>
				   </xsl:when>
				   <xsl:otherwise>
				      <xsl:value-of select="$strNotApplicable"/>
				   </xsl:otherwise>
				</xsl:choose>
				</xsl:attribute>
				<!-- set rebuild rate unit -->
		      <xsl:choose>				
				   <xsl:when test="count(RebuildRate)>0">
				   	<xsl:choose> 
					         <xsl:when test="RebuildRate != '(null)' ">
		         						<xsl:attribute name="unit">%</xsl:attribute>
					         </xsl:when>
						</xsl:choose>
	         </xsl:when>
				</xsl:choose> 				
				</Data>
				
		</xsl:if>

		<xsl:if test="//BGIRate or $dynamicView = 'false' ">
			<Data name="BGIRate" editable="false" type="ustring">
				<xsl:attribute name="display"><xsl:value-of select="$strBGIRate"/></xsl:attribute>
        <xsl:choose>
          <xsl:when test="BGIRate and BGIRate !='Not Available' and BGIRate !='(null)'">
            <xsl:attribute name="value">
              <xsl:value-of select="BGIRate"/>%
            </xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:attribute name="value">
              <xsl:value-of select="$strNotAvailable"/>
            </xsl:attribute>
          </xsl:otherwise>
        </xsl:choose>
			</Data>
		</xsl:if>

		<xsl:if test="//CheckConsistencyRate or $dynamicView = 'false' ">
			<Data name="CheckConsistencyRate" editable="false" type="ustring">
				<xsl:attribute name="display"><xsl:value-of select="$strChkConsistencyRate"/></xsl:attribute>
        <xsl:choose>
          <xsl:when test="CheckConsistencyRate and CheckConsistencyRate !='Not Available' and CheckConsistencyRate !='(null)'">
            <xsl:attribute name="value">
              <xsl:value-of select="CheckConsistencyRate"/>%
            </xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:attribute name="value">
              <xsl:value-of select="$strNotAvailable"/>
            </xsl:attribute>
          </xsl:otherwise>
        </xsl:choose>
      </Data>
		</xsl:if>

		<xsl:if test="//ReconstructRate or $dynamicView = 'false' ">
			<Data name="ReconstructRate" editable="false" type="ustring">
				<xsl:attribute name="display"><xsl:value-of select="$strReconstructRate"/></xsl:attribute>
        <xsl:choose>
          <xsl:when test="ReconstructRate and ReconstructRate !='Not Available' and ReconstructRate !='(null)'">
            <xsl:attribute name="value">
              <xsl:value-of select="ReconstructRate"/>%
            </xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:attribute name="value">
              <xsl:value-of select="$strNotAvailable"/>
            </xsl:attribute>
          </xsl:otherwise>
        </xsl:choose>
			</Data>
		</xsl:if>
           <!-- 6.0 changes to display values on controller information page--> 
           <xsl:if test="//ChangeControllerPropertyMask ">
			<Data name="AbortCc" editable="false" type="ustring">
				<xsl:attribute name="display"><xsl:value-of select="$strAbortCConError"/></xsl:attribute>
				<xsl:attribute name="value">
                        <xsl:choose>
                           <xsl:when test="substring(//ChangeControllerPropertyMask,20,1)='1'"><xsl:value-of select="$strEnabled"/></xsl:when>
                           <xsl:when test="substring(//ChangeControllerPropertyMask,12,1)='1'"><xsl:value-of select="$strDisabled"/></xsl:when>

                        </xsl:choose> 
                        </xsl:attribute>    
                         
                        
			</Data>
		</xsl:if>
            <xsl:if test="//ChangeControllerPropertyMask ">
			<Data name="CopyBack" editable="false" type="ustring">
				<xsl:attribute name="display"><xsl:value-of select="$strCopyback"/></xsl:attribute>
				<xsl:attribute name="value">
                        <xsl:choose>
                           <xsl:when test="substring(//ChangeControllerPropertyMask,17,1)='1'"><xsl:value-of select="$strEnabled"/></xsl:when>
                           <xsl:when test="substring(//ChangeControllerPropertyMask,15,1)='1'"><xsl:value-of select="$strDisabled"/></xsl:when>

                        </xsl:choose> 
                        </xsl:attribute>    
                         
                        
			</Data>
		</xsl:if>
             
            <xsl:if test="//ChangeControllerPropertyMask and //BusProtocol != '9'">
			<Data name="LoadBalancing" editable="false" type="ustring">
				<xsl:attribute name="display"><xsl:value-of select="$strLoadBalancing"/></xsl:attribute>
				<xsl:attribute name="value">
                        <xsl:choose>
                           <xsl:when test="substring(//ChangeControllerPropertyMask,14,1)='1'"><xsl:value-of select="$strAuto"/></xsl:when>
                           <xsl:when test="substring(//ChangeControllerPropertyMask,13,1)='1'"><xsl:value-of select="$strDisabled"/></xsl:when>

                        </xsl:choose> 
                        </xsl:attribute>    
                         
                        
			</Data>
		</xsl:if>

              <xsl:if test="//ChangeControllerPropertyMask ">
			<Data name="SmartErrorDisk" editable="false" type="ustring">
				<xsl:attribute name="display"><xsl:value-of select="$strSmarterErrorDisk"/></xsl:attribute>
				<xsl:attribute name="value">
                        <xsl:choose>
                           <xsl:when test="substring(//ChangeControllerPropertyMask,30,1)='1'"><xsl:value-of select="$strEnabled"/></xsl:when>
                           <xsl:when test="substring(//ChangeControllerPropertyMask,29,1)='1'"><xsl:value-of select="$strDisabled"/></xsl:when>

                        </xsl:choose> 
                        </xsl:attribute>    
                         
                        
			</Data>
		</xsl:if>
                
               <xsl:if test="substring(/OMA/Channels/DCStorageObject[1]/AttributesMask,26,1)='1'">
			<Data name="ClearMultiPath" editable="false" type="ustring">
				<xsl:attribute name="display"><xsl:value-of select="$strClearMultipath"/></xsl:attribute>
				<xsl:attribute name="value">
                        <xsl:choose>
                           <xsl:when test="substring(//ChangeControllerPropertyMask,32,1)='1'"><xsl:value-of select="$strDetected"/></xsl:when>
                           <xsl:when test="substring(//ChangeControllerPropertyMask,31,1)='1'"><xsl:value-of select="$strCleared"/></xsl:when>

                        </xsl:choose> 
                        </xsl:attribute>    
                         
                        
			</Data>
		</xsl:if>
  <!--6.0 changes over -->
 


		<xsl:if test="$isAlarmPresent='true' or dynamicView = 'false' ">
			<Data name="Alarm" editable="false" type="ustring">
				<xsl:attribute name="display"><xsl:value-of select="$strAlarmState"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:call-template name="GetControllerAlarm"><xsl:with-param name="MethodValue"><xsl:value-of select="CurrentMethodMask"/></xsl:with-param></xsl:call-template></xsl:attribute>
			</Data>
		</xsl:if>
		<xsl:if test="$isCluster='true' and //BusProtocol != '9'">
			<Data name="ClusterMode" editable="false" type="ustring">
				<xsl:attribute name="display"><xsl:value-of select="$strClusterMode"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="$strEnabled"/></xsl:attribute>
			</Data>
		</xsl:if>
		<xsl:if test="TargetID or $dynamicView = 'false' ">
			<Data name="ScsiTgId" editable="false" type="ustring">
				<xsl:attribute name="display"><xsl:value-of select="$strScsiTgId"/></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="TargetID"><xsl:value-of select="TargetID"/></xsl:when>
						<xsl:otherwise>	<xsl:value-of select="$strNotApplicable"/></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
		</xsl:if>

		<xsl:if test="//CacheSize or $dynamicView = 'false' ">
			<Data name="CacheSize" editable="false" type="ustring">
				<xsl:attribute name="display"><xsl:value-of select="$strCacheSize"/></xsl:attribute>
				<xsl:choose>
          <xsl:when test="CacheSize and CacheSize !='Not Available' and CacheSize !='(null)'">
            <xsl:attribute name="value">
              <xsl:value-of select="CacheSize"/>MB
            </xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:attribute name="value">
              <xsl:value-of select="$strNotAvailable"/>
            </xsl:attribute>
          </xsl:otherwise>
        </xsl:choose>
			</Data>
		</xsl:if>

		<xsl:if test="//PatrolReadMode or $dynamicView = 'false' ">
			<Data name="PatReadMode" editable="false" type="ustring">
				<xsl:attribute name="display"><xsl:value-of select="$strPatrolReadMode" /></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:call-template name="GetPatrolReadMode">
					<xsl:with-param name="mode"><xsl:value-of select="PatrolReadMode" /></xsl:with-param>
					</xsl:call-template>
				</xsl:attribute>
			</Data>
		</xsl:if>
		<xsl:if test="//PatrolReadState or $dynamicView = 'false'">
			<Data name="PatReadState" editable="false" type="ustring">
				<xsl:attribute name="display"><xsl:value-of select="$strPatrolReadState" /></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:call-template name="GetPatrolReadState">
					<xsl:with-param name="state"><xsl:value-of select="PatrolReadState" /></xsl:with-param>
					</xsl:call-template>
				</xsl:attribute>
			</Data>
		</xsl:if>
		<xsl:if test="//PatrolReadIterations or $dynamicView = 'false'">
			<Data name="PatReadIterations" editable="false" type="ustring">
				<xsl:attribute name="display"><xsl:value-of select="$strPatrolReadIterations" /></xsl:attribute>
        <xsl:choose>
          <xsl:when test="//PatrolReadIterations">
            <xsl:attribute name="value">
              <xsl:value-of select="PatrolReadIterations" />
            </xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:attribute name="value">
              <xsl:value-of select="$strUnknown"/>
            </xsl:attribute>
          </xsl:otherwise>
        </xsl:choose>
      </Data>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>
