<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
	<xsl:template match="OMA">
	<xsl:choose>
		<xsl:when test="CLIMsgID">
			<xsl:call-template name="failure"/>
		</xsl:when>
		<xsl:otherwise>
		<xsl:choose>
			<xsl:when test="SMStatus != '0'">
				<xsl:call-template name="failure"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="success"/>
			</xsl:otherwise>
		</xsl:choose>
		</xsl:otherwise>
	</xsl:choose>
	</xsl:template>
	<xsl:template name="success">
		<xsl:variable name="checkAdmin">
			<xsl:choose>
				<xsl:when test="OMAUserRights = '7'">true</xsl:when>
				<xsl:otherwise>false</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
                <OMA skin="modern">
		<DataArea>
				<xsl:choose>
					<xsl:when test="count(//Enclosures/DCStorageObject) > 1">
					<PageTitle>
						<xsl:attribute name="display"><xsl:value-of select="$strTitle1"/></xsl:attribute>
					</PageTitle>
					<CustomButton>
						<Data link="true" name="Return">
							<xsl:attribute name="display"><xsl:value-of select="$strRetSystemSummary"/></xsl:attribute>
							<xsl:attribute name="href">syssum.xml</xsl:attribute>
						</Data>
					</CustomButton>
					<xsl:apply-templates select="/*/Enclosures/DCStorageObject">
						<xsl:with-param name="tasks">
							<xsl:value-of select="$checkAdmin"/>
						</xsl:with-param>
					</xsl:apply-templates>
					</xsl:when>
					<xsl:when test="count(//Enclosures/DCStorageObject) = 1">
					<PageTitle>
						<xsl:if test="//BusProtocol!='9'">
							<xsl:attribute name="display"><xsl:value-of select="$strTitle2Part1"/><xsl:value-of select="/*/Enclosures/@ControllerName"/><xsl:value-of select="$strTitle2Part2"/></xsl:attribute>
						</xsl:if>
						<xsl:if test="//BusProtocol='9'">
							<xsl:attribute name="display"><xsl:value-of select="$strExtenderPart1"/><xsl:value-of select="/*/Enclosures/@ControllerName"/><xsl:value-of select="$strTitle2Part2"/></xsl:attribute>
						</xsl:if>
					</PageTitle>
					<CustomButton>
						<Data link="true" name="Return">
							<xsl:attribute name="display"><xsl:value-of select="$strRetSystemSummary"/></xsl:attribute>
							<xsl:attribute name="href">syssum.xml</xsl:attribute>
						</Data>
					</CustomButton>
						<xsl:apply-templates select="/*/Enclosures/DCStorageObject">
							<xsl:with-param name="tasks">
								<xsl:value-of select="$checkAdmin"/>
							</xsl:with-param>
						</xsl:apply-templates>
					</xsl:when>
					<xsl:otherwise>
					<PageTitle>
						<xsl:attribute name="display"><xsl:value-of select="$strTitle1"/></xsl:attribute>
					</PageTitle>
					<CustomButton>
						<Data link="true" name="Return">
							<xsl:attribute name="display"><xsl:value-of select="$strRetSystemSummary"/></xsl:attribute>
							<xsl:attribute name="href">syssum.xml</xsl:attribute>
						</Data>
					</CustomButton>
							<xsl:call-template name="Partial"/>
					</xsl:otherwise> 
				</xsl:choose>
		</DataArea>
                </OMA>
	</xsl:template>
	<xsl:template match="Enclosures/DCStorageObject">
		<xsl:param name="tasks"/>
	<!--	<ComboData> -->
			<!-- DISPLAY THE ENCLOSURE INFORMATION IN A LIST FORMAT-->
			<ListData type="custom" columnspacing="true">
				<SubHeader>
					<xsl:attribute name="display"><xsl:value-of select="$strSubHeader"/></xsl:attribute>
					<xsl:attribute name="status"><xsl:value-of select="ObjStatus"/></xsl:attribute>
				</SubHeader>
                                 <Row>
                                	<Data Name="Status" type="status"><xsl:value-of select="ObjStatus"/>
					</Data>
				</Row>
				<xsl:call-template name="EnclosureTable">
					<xsl:with-param name="tasks">
						<xsl:value-of select="$tasks"/>
					</xsl:with-param>
				</xsl:call-template>
			</ListData>
			<!-- DISPLAY THE ARRAY DISK INFORMATION IN A TABLE FORMAT-->
			<xsl:if test="count(../../ArrayDisks)>0">
				<TableData type="custom" columnspacing="true">
					<xsl:attribute name="display"><xsl:value-of select="$strADSubHeader"/></xsl:attribute>
					<xsl:variable name="showtasks">false</xsl:variable>
					<SubHeader>
						<xsl:attribute name="display"><xsl:value-of select="$strADSubHeader"/></xsl:attribute>
					</SubHeader>
					<Header>
						<xsl:call-template name="ArrayDiskTableHeader">
							<xsl:with-param name="tasks" select="$showtasks"/>
							<xsl:with-param name="expanded">true</xsl:with-param>
						</xsl:call-template>
					</Header>
					<xsl:for-each select="../../ArrayDisks/DCStorageObject">
						<xsl:sort select="Channel" data-type="number" order="ascending"/>
						<xsl:sort select="TargetID" data-type="number" order="ascending"/>
						<xsl:call-template name="ArrayDiskTableRows">
							<xsl:with-param name="tasks" select="$showtasks"/>
							<xsl:with-param name="expanded">true</xsl:with-param>
						</xsl:call-template>
					</xsl:for-each>
				</TableData>
			</xsl:if>
			<!-- DISPLAY THE EMM INFORMATION IN A TABLE FORMAT-->
			<xsl:if test="count(../../EMM)>0">
				<TableData type="custom"  columnspacing="true">
					<xsl:attribute name="display"><xsl:value-of select="$strEMMSubHeader"/></xsl:attribute>
					<xsl:variable name="showtasks">false</xsl:variable>
					<SubHeader>
						<xsl:attribute name="display"><xsl:value-of select="$strEMMSubHeader"/></xsl:attribute>
					</SubHeader>
					<Header>
						<xsl:call-template name="EMMTableHeader">
							<xsl:with-param name="tasks" select="$showtasks"/>
						</xsl:call-template>
					</Header>
					<xsl:for-each select="../../EMM/DCStorageObject">
						<xsl:call-template name="EMMTableRows">
							<xsl:with-param name="tasks" select="$showtasks"/>
						</xsl:call-template>
					</xsl:for-each>
				</TableData>
			</xsl:if>
			<!-- DISPLAY THE FAN INFORMATION IN A TABLE FORMAT-->
			<xsl:if test="count(../../Fans)>0">
				<TableData type="custom" columnspacing="true">
					<xsl:attribute name="display"><xsl:value-of select="$strFanSubHeader"/></xsl:attribute>
					<xsl:variable name="showtasks">false</xsl:variable>
					<SubHeader>
						<xsl:attribute name="display"><xsl:value-of select="$strFanSubHeader"/></xsl:attribute>
					</SubHeader>
					<Header>
						<xsl:call-template name="FanTableHeader">
							<xsl:with-param name="tasks" select="$showtasks"/>
						</xsl:call-template>
					</Header>
					<xsl:for-each select="../../Fans/DCStorageObject">
						<xsl:call-template name="FanTableRows">
							<xsl:with-param name="tasks" select="$showtasks"/>
						</xsl:call-template>
					</xsl:for-each>
				</TableData>
			</xsl:if>
			<!-- DISPLAY THE POWER SUPPLY INFORMATION IN A TABLE FORMAT-->
			<xsl:if test="count(../../PowerSupply)>0">
				<TableData type="custom" columnspacing="true">
					<xsl:attribute name="display"><xsl:value-of select="$strPSSubHeader"/></xsl:attribute>
					<xsl:variable name="showtasks">false</xsl:variable>
					<SubHeader>
						<xsl:attribute name="display"><xsl:value-of select="$strPSSubHeader"/></xsl:attribute>
					</SubHeader>
					<Header>
						<xsl:call-template name="PSTableHeader">
							<xsl:with-param name="tasks" select="$showtasks"/>
						</xsl:call-template>
					</Header>
					<xsl:for-each select="../../PowerSupply/DCStorageObject">
						<xsl:call-template name="PSTableRows">
							<xsl:with-param name="tasks" select="$showtasks"/>
						</xsl:call-template>
					</xsl:for-each>
				</TableData>
			</xsl:if>
			<!-- DISPLAY THE TEMPERATURE PROBE INFORMATION IN A TABLE FORMAT-->
			<xsl:if test="count(../../TemperatureProbes)>0">
				<TableData type="custom" columnspacing="true">
					<xsl:attribute name="display"><xsl:value-of select="$strTPSubHeader"/></xsl:attribute>
					<SubHeader>
						<xsl:attribute name="display"><xsl:value-of select="$strTPSubHeader"/></xsl:attribute>
					</SubHeader>
					<xsl:call-template name="TempTableHeader"/>
					<xsl:for-each select="../../TemperatureProbes/DCStorageObject">
						<xsl:call-template name="TempTableRows"/>
					</xsl:for-each>
				</TableData>
			</xsl:if>
<!--		</ComboData> -->
	</xsl:template>
<!-- New code using pieces of Enclosure template -->	

	<xsl:template name="Partial">
		<xsl:param name="tasks"/>
<!--		<ComboData> -->
			<!-- DISPLAY THE ENCLOSURE INFORMATION IN A LIST FORMAT-->
			<ListData type="custom" columnspacing="true">
				<SubHeader>
					<xsl:attribute name="display"><xsl:value-of select="$strSubHeader"/></xsl:attribute>
					<xsl:attribute name="status"><xsl:value-of select="ObjStatus"/></xsl:attribute>
				</SubHeader>
			</ListData>
			<!-- DISPLAY THE ARRAY DISK INFORMATION IN A TABLE FORMAT-->
			<xsl:if test="count(ArrayDisks)>0">
				<TableData type="custom" columnspacing="true">
					<xsl:attribute name="display"><xsl:value-of select="$strADSubHeader"/></xsl:attribute>
					<xsl:variable name="showtasks">false</xsl:variable>
					<SubHeader>
						<xsl:attribute name="display"><xsl:value-of select="$strADSubHeader"/></xsl:attribute>
					</SubHeader>
					<Header>
						<xsl:call-template name="ArrayDiskTableHeader">
							<xsl:with-param name="tasks" select="$showtasks"/>
							<xsl:with-param name="expanded">true</xsl:with-param>
						</xsl:call-template>
					</Header>
					<xsl:for-each select="ArrayDisks/DCStorageObject">
						<xsl:sort select="Channel" data-type="number" order="ascending"/>
						<xsl:sort select="TargetID" data-type="number" order="ascending"/>
						<xsl:call-template name="ArrayDiskTableRows">
							<xsl:with-param name="tasks" select="$showtasks"/>
							<xsl:with-param name="expanded">true</xsl:with-param>
						</xsl:call-template>
					</xsl:for-each>
				</TableData>
			</xsl:if>
			<!-- DISPLAY THE EMM INFORMATION IN A TABLE FORMAT-->
			<xsl:if test="count(EMM)>0">
				<TableData type="custom" columnspacing="true">
					<xsl:attribute name="display"><xsl:value-of select="$strEMMSubHeader"/></xsl:attribute>
					<xsl:variable name="showtasks">false</xsl:variable>
					<SubHeader>
						<xsl:attribute name="display"><xsl:value-of select="$strEMMSubHeader"/></xsl:attribute>
					</SubHeader>
					<Header>
						<xsl:call-template name="EMMTableHeader">
							<xsl:with-param name="tasks" select="$showtasks"/>
						</xsl:call-template>
					</Header>
					<xsl:for-each select="EMM/DCStorageObject">
						<xsl:call-template name="EMMTableRows">
							<xsl:with-param name="tasks" select="$showtasks"/>
						</xsl:call-template>
					</xsl:for-each>
				</TableData>
			</xsl:if>
			<!-- DISPLAY THE FAN INFORMATION IN A TABLE FORMAT-->
			<xsl:if test="count(Fans)>0">
				<TableData type="custom" columnspacing="true">
					<xsl:attribute name="display"><xsl:value-of select="$strFanSubHeader"/></xsl:attribute>
					<xsl:variable name="showtasks">false</xsl:variable>
					<SubHeader>
						<xsl:attribute name="display"><xsl:value-of select="$strFanSubHeader"/></xsl:attribute>
					</SubHeader>
					<Header>
						<xsl:call-template name="FanTableHeader">
							<xsl:with-param name="tasks" select="$showtasks"/>
						</xsl:call-template>
					</Header>
					<xsl:for-each select="Fans/DCStorageObject">
						<xsl:call-template name="FanTableRows">
							<xsl:with-param name="tasks" select="$showtasks"/>
						</xsl:call-template>
					</xsl:for-each>
				</TableData>
			</xsl:if>
			<!-- DISPLAY THE POWER SUPPLY INFORMATION IN A TABLE FORMAT-->
			<xsl:if test="count(PowerSupply)>0">
				<TableData type="custom" columnspacing="true">
					<xsl:attribute name="display"><xsl:value-of select="$strPSSubHeader"/></xsl:attribute>
					<xsl:variable name="showtasks">false</xsl:variable>
					<SubHeader>
						<xsl:attribute name="display"><xsl:value-of select="$strPSSubHeader"/></xsl:attribute>
					</SubHeader>
					<Header>
						<xsl:call-template name="PSTableHeader">
							<xsl:with-param name="tasks" select="$showtasks"/>
						</xsl:call-template>
					</Header>
					<xsl:for-each select="PowerSupply/DCStorageObject">
						<xsl:call-template name="PSTableRows">
							<xsl:with-param name="tasks" select="$showtasks"/>
						</xsl:call-template>
					</xsl:for-each>
				</TableData>
			</xsl:if>
			<!-- DISPLAY THE TEMPERATURE PROBE INFORMATION IN A TABLE FORMAT-->
			<xsl:if test="count(TemperatureProbes)>0">
				<TableData type="custom" columnspacing="true">
					<xsl:attribute name="display"><xsl:value-of select="$strTPSubHeader"/></xsl:attribute>
					<SubHeader>
						<xsl:attribute name="display"><xsl:value-of select="$strTPSubHeader"/></xsl:attribute>
					</SubHeader>
					<xsl:call-template name="TempTableHeader"/>
					<xsl:for-each select="TemperatureProbes/DCStorageObject">
						<xsl:call-template name="TempTableRows"/>
					</xsl:for-each>
				</TableData>
			</xsl:if>
<!--		</ComboData> -->
	</xsl:template>

<!-- End of New Code -->
	<!-- Enclosure TABLE (for Combo Data) -->
	<xsl:template name="EnclosureTable">
		<xsl:param name="tasks"/>
		<xsl:param name="ObjID">
		<xsl:call-template name="ModNexus">
			<xsl:with-param name="nexus">
				<xsl:value-of select="Nexus"/>
			</xsl:with-param>
		</xsl:call-template>
        	</xsl:param>
		<xsl:variable name="dynamicView">
			<xsl:choose>
				<xsl:when test="/OMA/@cli = 'true' ">false</xsl:when>
				<xsl:otherwise>true</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!-- ignore on web is set to true since it's only needed for scripts using the cli -->
		<xsl:choose>
			<xsl:when test="BusProtocol=8 or BusProtocol=9">
				<!--ID for a SAS enclosure, ID is determined by the Channel:EnclosureID-->
				<Data columnspacing="true" name="Id" editable="false" type="usting">
					<xsl:attribute name="display"><xsl:value-of select="$strID"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="Channel"/>:<xsl:value-of select="EnclosureID"/></xsl:attribute>
				</Data>
			</xsl:when>
			<xsl:otherwise>
				<!--ID for a SCSI enclosure is determined by the Channel number to which it is attached-->
				<Data columnspacing="true" name="Id" editable="false" type="usting">
					<xsl:attribute name="display"><xsl:value-of select="$strID"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="Channel"/></xsl:attribute>
				</Data>
			</xsl:otherwise>
		</xsl:choose>
		<Data columnspacing="true" name="Name" editable="false" type="usting">
			<xsl:attribute name="display"><xsl:value-of select="$strName"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:call-template name="GetEnclosureType"><xsl:with-param name="type"><xsl:value-of select="EnclosureType"/></xsl:with-param></xsl:call-template></xsl:attribute>
		</Data>
		<Data columnspacing="true" name="State" editable="false" type="usting">
			<xsl:attribute name="display"><xsl:value-of select="$strState"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:call-template name="GetState"><xsl:with-param name="state"><xsl:value-of select="ObjState"/></xsl:with-param></xsl:call-template></xsl:attribute>
		</Data>
		
		<Data columnspacing="true" name="Channel" editable="false" type="usting">
			<!--<xsl:attribute name="display"><xsl:value-of select="$strChannel"/></xsl:attribute>-->
			<xsl:attribute name="display">
				<xsl:choose>
					<xsl:when test="BusProtocol = '9'">
						<xsl:value-of select="$strPCIeSSDExpander"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$strChannel"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="Channel"/></xsl:attribute>
		</Data>
		
		<xsl:if test="(//Enclosures/DCStorageObject/TargetID or $dynamicView = 'false') and //BusProtocol!='9'">
			<xsl:choose>
				<xsl:when test="TargetID">
					<Data columnspacing="true" name="TargetID" editable="false" type="usting">
						<xsl:attribute name="display"><xsl:value-of select="$strTargetID"/></xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="TargetID"/></xsl:attribute>
					</Data>
				</xsl:when>
				<xsl:otherwise>
					<Data columnspacing="true" name="TargetID" editable="false" type="usting">
						<xsl:attribute name="display"><xsl:value-of select="$strTargetID"/></xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="$strNotApplicable"/></xsl:attribute>
					</Data>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<xsl:if test="(//EnclosureConfig or $dynamicView = 'false') and //BusProtocol!='9'">
			<xsl:choose>
				<xsl:when test="EnclosureConfig">
					<Data columnspacing="true" name="Config" editable="false" type="usting">
						<xsl:attribute name="display"><xsl:value-of select="$strConfig"/></xsl:attribute>
						<xsl:attribute name="value"><xsl:call-template name="GetEnclosureConfig"><xsl:with-param name="config"><xsl:value-of select="EnclosureConfig"/></xsl:with-param></xsl:call-template></xsl:attribute>
					</Data>
				</xsl:when>
				<xsl:otherwise>
					<Data columnspacing="true" name="Config" editable="false" type="usting">
						<xsl:attribute name="display"><xsl:value-of select="$strConfig"/></xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="$strNotApplicable"/></xsl:attribute>
					</Data>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<xsl:if test="//FirmwareVer or $dynamicView = 'false'">
			<xsl:choose>
				<xsl:when test="FirmwareVer">
					<Data columnspacing="true" name="FirmwareVer" editable="false" type="usting">
						<xsl:attribute name="display"><xsl:value-of select="$strFW"/></xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="FirmwareVer"/></xsl:attribute>
					</Data>
				</xsl:when>
				<xsl:otherwise>
					<Data columnspacing="true" name="FirmwareVer" editable="false" type="usting">
						<xsl:attribute name="display"><xsl:value-of select="$strFW"/></xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="$strNotApplicable"/></xsl:attribute>
					</Data>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<xsl:if test="(//ServiceTag or $dynamicView = 'false') and //BusProtocol!='9'">
			<xsl:choose>
				<xsl:when test="ServiceTag">
					<Data columnspacing="true" name="ServiceTag" editable="false" type="usting">
						<xsl:attribute name="display"><xsl:value-of select="$strServiceTag"/></xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="ServiceTag"/></xsl:attribute>
					</Data>
				</xsl:when>
				<xsl:otherwise>
					<Data columnspacing="true" name="ServiceTag" editable="false" type="usting">
						<xsl:attribute name="display"><xsl:value-of select="$strServiceTag"/></xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="$strNotApplicable"/></xsl:attribute>
					</Data>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<xsl:if test="(//AssetTag or $dynamicView = 'false') and //BusProtocol!='9'">
			<xsl:choose>
				<xsl:when test="AssetTag">
					<Data columnspacing="true" name="AssetTag" editable="false" type="usting">
						<xsl:attribute name="display"><xsl:value-of select="$strAssetTag"/></xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="AssetTag"/></xsl:attribute>
					</Data>
				</xsl:when>
				<xsl:otherwise>
					<Data columnspacing="true" name="AssetTag" editable="false" type="usting">
						<xsl:attribute name="display"><xsl:value-of select="$strAssetTag"/></xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="$strNotApplicable"/></xsl:attribute>
					</Data>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<xsl:if test="//AssetName or $dynamicView = 'false'">
			<xsl:choose>
				<xsl:when test="AssetName">
					<Data columnspacing="true" name="AssetName" editable="false" type="usting">
						<xsl:attribute name="display"><xsl:value-of select="$strAssetName"/></xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="AssetName"/></xsl:attribute>
					</Data>
				</xsl:when>
				<xsl:otherwise>
					<Data columnspacing="true" name="AssetName" editable="false" type="usting">
						<xsl:attribute name="display"><xsl:value-of select="$strAssetName"/></xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="$strNotApplicable"/></xsl:attribute>
					</Data>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<xsl:if test="(//BackPlanePartNum or $dynamicView = 'false') and and //BusProtocol!='9'">
			<xsl:choose>
				<xsl:when test="BackPlanePartNum">
					<Data columnspacing="true" name="BackPlanePartNo" editable="false" type="usting">
						<xsl:attribute name="display"><xsl:value-of select="$strBPPartNo"/></xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="BackPlanePartNum"/></xsl:attribute>
					</Data>
				</xsl:when>
				<xsl:otherwise>
					<Data columnspacing="true" name="BackPlanePartNo" editable="false" type="usting">
						<xsl:attribute name="display"><xsl:value-of select="$strBPPartNo"/></xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="$strNotApplicable"/></xsl:attribute>
					</Data>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<xsl:if test="(//SplitBusPartNum or $dynamicView = 'false') and //BusProtocol!='9'">
			<xsl:choose>
				<xsl:when test="SplitBusPartNum">
					<Data columnspacing="true" name="SplitBusPartNo" editable="false" type="usting">
						<xsl:attribute name="display"><xsl:value-of select="$strSBPartNo"/></xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="SplitBusPartNum"/></xsl:attribute>
					</Data>
				</xsl:when>
				<xsl:otherwise>
					<Data columnspacing="true" name="SplitBusPartNo" editable="false" type="usting">
						<xsl:attribute name="display"><xsl:value-of select="$strSBPartNo"/></xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="$strNotApplicable"/></xsl:attribute>
					</Data>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<xsl:if test="(//SCSIRate or $dynamicView = 'false') and //BusProtocol!='9'">
			<xsl:choose>
				<xsl:when test="SCSIRate">
					<Data columnspacing="true" name="SCSIRate" editable="false" type="usting" display="Test">
						<xsl:attribute name="display"><xsl:value-of select="$strSCSIRate"/></xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="SCSIRate"/></xsl:attribute>
					</Data>
				</xsl:when>
				<xsl:otherwise>
					<Data columnspacing="true" name="SCSIRate" editable="false" type="usting">
						<xsl:attribute name="display"><xsl:value-of select="$strSCSIRate"/></xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="$strNotApplicable"/></xsl:attribute>
					</Data>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<xsl:if test="(//SASAddress or $dynamicView = 'false') and //BusProtocol!='9'">
			<xsl:choose>
				<xsl:when test="SASAddress">
					<Data columnspacing="true" name="SASAddress" editable="false" type="usting" display="Test">
						<xsl:attribute name="display"><xsl:value-of select="$strSASAddress"/></xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="SASAddress"/></xsl:attribute>
					</Data>
				</xsl:when>
				<xsl:otherwise>
					<Data columnspacing="true" name="SASAddress" editable="false" type="usting">
						<xsl:attribute name="display"><xsl:value-of select="$strSASAddress"/></xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="$strNotApplicable"/></xsl:attribute>
					</Data>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<xsl:if test="(//EnclosureAlarm or $dynamicView = 'false') and //BusProtocol!='9'">
			<xsl:choose>
				<xsl:when test="EnclosureAlarm">
					<Data columnspacing="true" name="EnclAlarm" editable="false" type="usting">
						<xsl:attribute name="display"><xsl:value-of select="$strEnclAlarm"/></xsl:attribute>
						<xsl:attribute name="value"><xsl:call-template name="GetEnclosureAlarm"><xsl:with-param name="state"><xsl:value-of select="EnclosureAlarm"/></xsl:with-param></xsl:call-template></xsl:attribute>
					</Data>
				</xsl:when>
				<xsl:otherwise>
					<Data columnspacing="true" name="EnclAlarm" editable="false" type="usting">
						<xsl:attribute name="display"><xsl:value-of select="$strEnclAlarm"/></xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="$strNotApplicable"/></xsl:attribute>
					</Data>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
	</xsl:template>
	
<xsl:template match="DataArea">
	<xsl:variable name="tape"><xsl:value-of select="//Controller/DCStorageObject/Name" /></xsl:variable>

	<!--  Set the document title here  -->
	<OMA skin="modern">
		<DataArea>

			<!--  There has to be at least one <Name> tag  -->
			<xsl:choose>
				<xsl:when test="count(//Controller/DCStorageObject) > 0">
					<PageTitle>
						<xsl:attribute name="display">
							<xsl:choose>
							<xsl:when test=" contains($tape,'PV') ">
							Tape Device on Controller 
							</xsl:when>
							<xsl:when test=" contains($tape,'TL') ">
							Tape Device on Controller 
							</xsl:when>
							<xsl:otherwise>
								<xsl:if test="//BusProtocol!='9'">
									<xsl:value-of select="$strTitle2Part1" />
								</xsl:if>
								<xsl:if test="//BusProtocol='9'">
									<xsl:value-of select="$strExtenderPart1" />
								</xsl:if>
							</xsl:otherwise>
							</xsl:choose>
							<xsl:value-of select="/*/Controller/@name" /> 
							<xsl:value-of select="$strTitle2Part2" /> 
						</xsl:attribute>
					</PageTitle>
					<xsl:apply-templates select="/*/Controller/DCStorageObject">
					</xsl:apply-templates>
				</xsl:when>
				<xsl:otherwise>
					<PageTitle>
						
							<xsl:attribute name="display">
								<xsl:value-of select="$strTitle3" /> 
							</xsl:attribute>
						
					</PageTitle>
				</xsl:otherwise>
			</xsl:choose>

		</DataArea>
	</OMA>
</xsl:template>

<!--  The following template formats the pediags output to desired format ready to display  -->
<xsl:template match="Controller/DCStorageObject">
<!--  Display tape device info in list format -->
	<ListData type="custom" columnspacing="true">
	
	<Data columnspacing="true" name="Name" editable="false" type="usting">
		<xsl:attribute name="display">
			<xsl:value-of select="$strName" /> 
		</xsl:attribute>
		<xsl:attribute name="value">
			<xsl:value-of select="Name" /> 
		</xsl:attribute>
	</Data>

	<Data columnspacing="true" name="Status" editable="false" type="usting">
		<xsl:attribute name="display">
			<xsl:value-of select="$strStatus" /> 
		</xsl:attribute>
		<xsl:attribute name="value">
			<xsl:value-of select="Status" /> 
		</xsl:attribute>
	</Data>
	
	<Data columnspacing="true" name="Firmware" editable="false" type="usting">
		<xsl:attribute name="display">
			<xsl:value-of select="$strFW" /> 
		</xsl:attribute>
		<xsl:attribute name="value">
			<xsl:value-of select="Firmware" /> 
		</xsl:attribute>
	</Data>
	
	<Data columnspacing="true" name="Descriptor" editable="false" type="usting">
		<xsl:attribute name="display">Device Descriptor</xsl:attribute>
		<xsl:attribute name="value">
			<xsl:value-of select="Descriptor" /> 
		</xsl:attribute>
	</Data>
	
	<Data columnspacing="true" name="Description" editable="false" type="usting">
		<xsl:attribute name="display">Description</xsl:attribute>
		<xsl:attribute name="value">
			<xsl:value-of select="Description" /> 
		</xsl:attribute>
	</Data>
	
	<Data columnspacing="true" name="Location" editable="false" type="usting">
		<xsl:attribute name="display">Device Location</xsl:attribute>
		<xsl:attribute name="value">
			<xsl:value-of select="Location" /> 
		</xsl:attribute>
	</Data>
	
	<Data columnspacing="true" name="ParentLocation" editable="false" type="usting">
		<xsl:attribute name="display">Parent Location</xsl:attribute>
		<xsl:attribute name="value">
			<xsl:value-of select="ParentLocation" /> 
		</xsl:attribute>
	</Data>

	<Data columnspacing="true" name="Manufacturer" editable="false" type="usting">
		<xsl:attribute name="display">Manufacturer</xsl:attribute>
		<xsl:attribute name="value">
			<xsl:value-of select="Manufacturer" /> 
		</xsl:attribute>
	</Data>
	
	<Data columnspacing="true" name="SerialNumber" editable="false" type="usting">
		<xsl:attribute name="display">
			<xsl:value-of select="$strSerial" /> 
		</xsl:attribute>
		<xsl:attribute name="value">
			<xsl:value-of select="SerialNumber" /> 
		</xsl:attribute>
	</Data>

	<Data columnspacing="true" name="ModelNumber" editable="false" type="usting">
		<xsl:attribute name="display">Model Number</xsl:attribute>
		<xsl:attribute name="value">
			<xsl:value-of select="ModelNumber" /> 
		</xsl:attribute>
	</Data>
	
	<Data columnspacing="true" name="AssetTag" editable="false" type="usting">
		<xsl:attribute name="display">
			<xsl:value-of select="$strAssetTag" /> 
		</xsl:attribute>
		<xsl:attribute name="value">
			<xsl:value-of select="AssetTag" /> 
		</xsl:attribute>
	</Data>

	<xsl:for-each select="Characteristic/Data">
	<Data columnspacing="true" name="Data" editable="false" type="usting">
		<xsl:attribute name="display">
			<xsl:value-of select="@name" />
		</xsl:attribute>
		<xsl:attribute name="value">
			<xsl:value-of select="@value" />
		</xsl:attribute>
	</Data>
	</xsl:for-each>

	</ListData>

</xsl:template>
<xsl:template name="failure">
<OMA skin="modern">
	<DataArea><PageTitle><xsl:attribute name="display"><xsl:value-of select="$strErrorNoEncl"/></xsl:attribute></PageTitle></DataArea>
</OMA>
</xsl:template>
</xsl:stylesheet>
