<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
	<!--<xsl:import href="Utils.xsl"/>-->
	<xsl:variable name="DisplayIsSecureVDColumn">
			<xsl:call-template name="IsCoulmnApplicable">
				<xsl:with-param name="BitPosition">32</xsl:with-param>
                        <xsl:with-param name="ObjectRef" select="//VirtualDisks/DCStorageObject"/>
			</xsl:call-template>
      </xsl:variable>
      <xsl:variable name="GLOBAL_VAR_VD_LOCALE"><xsl:value-of select="/OMA/Locale"/></xsl:variable>
		
	<!-- VIRTUAL DISK TABLE HEADER -->
	<xsl:template name="VirtualDiskTableHeader">
		<xsl:param name="tasks"/>
        <xsl:param name="ManageIsSSC"/>
         <xsl:param name="ControllerPageSSC"/>
        <xsl:variable name="ManageSSC">
		    <xsl:choose>
			    <xsl:when test="/OMA/@cli = 'true'">
			        <xsl:value-of select="$ManageIsSSC"/>
			    </xsl:when>
                            <xsl:when test="$ControllerPageSSC = '1'">
			        <xsl:value-of select="$ControllerPageSSC"/>
			    </xsl:when>
			    <xsl:otherwise>
			        <xsl:value-of select="//ManageSSC"/>
			    </xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!-- ignore on web is set to true since it's only needed for scripts using the cli -->
		<Data name="Id" editable="false" type="ustring" ignoreonweb="true">
			<xsl:attribute name="display"><xsl:value-of select="$strID"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$strID"/></xsl:attribute>
		</Data>
		<Data name="Status" editable="false" type="ustring">
			<xsl:attribute name="display"><xsl:value-of select="$strStatus"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$strStatus"/></xsl:attribute>
		</Data>
		<Data name="Name" editable="false" type="ustring">
			<xsl:attribute name="display"><xsl:value-of select="$strName"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$strName"/></xsl:attribute>
		</Data>
		 <Data name="State" editable="false" type="ustring">
			<xsl:attribute name="display"><xsl:value-of select="$strState"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$strState"/></xsl:attribute>
		</Data>
		      <xsl:if test="//Partitions &gt; 0 and $ManageSSC != '1' ">
                        <Data name="Partitions" editable="false" type="ustring">
                                <xsl:attribute name="display"><xsl:value-of select="$strPartition"/></xsl:attribute>
                                <xsl:attribute name="value"><xsl:value-of select="$strPartition"/></xsl:attribute>
                        </Data>
		</xsl:if>
		<xsl:if test="(//VirtualDisks/DCStorageObject/ProtectionPolicyViolated and $ManageSSC != '1')">
			<!-- See if any VDisk has violated hotspare policy.  If so, show the header for the table -->
			<Data name="protectionpolicy" editable="false" type="ustring">
				<xsl:attribute name="display"><xsl:value-of select="$strHSPPolicyViolated"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="$strHSPPolicyViolated"/></xsl:attribute>
			</Data>
		</xsl:if>
		
		<xsl:if test="(//VirtualDisks/DCStorageObject/VDBadBlocksDetected and $ManageSSC != '1')">
			<!-- See if any VDisk has detected bad blocks.  If so, show the header for the table -->
			<Data name="protectionpolicy" editable="false" type="ustring">
				<xsl:attribute name="display"><xsl:value-of select="$strVDBadBlocks"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="$strVDBadBlocks"/></xsl:attribute>
			</Data>
		</xsl:if>
          <xsl:if test="$ManageSSC != '1'">		
		    <xsl:if test="contains($DisplayIsSecureVDColumn,'1') or /OMA/@cli = 'true'">
             
			<Data name="IsVDSecured" editable="false" type="ustring">
				<xsl:attribute name="display"><xsl:value-of select="$strSecured"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="$strSecured"/></xsl:attribute>
			</Data>
		   </xsl:if>
		</xsl:if>
		<xsl:if test="((//VirtualDisks/DCStorageObject/Progress and $ManageSSC != '1' )) and //BusProtocol!='9'">
			<!-- See if any VDisk has a progress.  If so, show the header for the table -->
			<Data name="Progress" editable="false" type="ustring">
				<xsl:attribute name="display"><xsl:value-of select="$strProgress"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="$strProgress"/></xsl:attribute>
			</Data>
		</xsl:if>
        <xsl:if test="$ManageSSC !='1'">
  		    <Data name="Layout" editable="false" type="ustring">
			      <xsl:attribute name="display"><xsl:value-of select="$strLayout"/></xsl:attribute>
			      <xsl:attribute name="value"><xsl:value-of select="$strLayout"/></xsl:attribute>
		    </Data>
        </xsl:if>
		<Data name="Size" editable="false" type="ustring">
			<xsl:attribute name="display"><xsl:value-of select="$strSize"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$strSize"/></xsl:attribute>
		</Data>
		<xsl:if test="(//VdPIEnabled or /OMA/@cli = 'true') and //BusProtocol!='9'"> 
			<Data name="VdPIEnabled" editable="false" type="ustring">
			<xsl:attribute name="display"><xsl:value-of select="$strT10ProtectionStatus"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$strT10ProtectionStatus"/></xsl:attribute>
			</Data>
		 </xsl:if> 
        <xsl:if test="//PartOfCachePool  or /OMA/@cli = 'true'">
        <Data name="FluidCacheEnabled" editable="false" type="ustring">
			<xsl:attribute name="display"><xsl:value-of select="$strFluidCacheEnabled"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$strFluidCacheEnabled"/></xsl:attribute>
	  </Data>
        </xsl:if> 
        <xsl:if test="$ManageSSC !='1'">
		<Data name="DeviceName" editable="false" type="ustring">
			<xsl:attribute name="display"><xsl:value-of select="$strDeviceName"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$strDeviceName"/></xsl:attribute>
		</Data>
        </xsl:if>
		<Data name="Type" editable="false" type="ustring">
			<xsl:attribute name="display"><xsl:value-of select="$strType"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$strType"/></xsl:attribute>
		</Data>
            <xsl:if test="$ManageSSC !='1'">
                <Data name="Type" editable="false" type="ustring">
			<xsl:attribute name="display"><xsl:value-of select="$strMediaType"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$strMediaType"/></xsl:attribute>
		</Data>
		<Data name="Read Cache" editable="false" type="ustring">
			<xsl:attribute name="display"><xsl:value-of select="$strReadCache"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$strReadCache"/></xsl:attribute>
		</Data>
		<Data name="Write Cache" editable="false" type="ustring">
			<xsl:attribute name="display"><xsl:value-of select="$strWriteCache"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$strWriteCache"/></xsl:attribute>
		</Data>
		<xsl:if test="//CachePolicy or /OMA/@cli = 'true'">
			<Data name="Cache Policy" editable="false" type="ustring">
				<xsl:attribute name="display"><xsl:value-of select="$strCachePolicy"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="$strCachePolicy"/></xsl:attribute>
			</Data>
		</xsl:if>
		<Data name="StripeSize" editable="false" type="ustring">
			<xsl:attribute name="display"><xsl:value-of select="$strStripeSize"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$strStripeSize"/></xsl:attribute>
		</Data>
              </xsl:if>
		<xsl:if test="//DiskCachePolicy or /OMA/@cli = 'true'">
             <Data name="DiskCachePolicy" editable="false" type="ustring">
			<xsl:attribute name="display"><xsl:value-of select="$strDiskCachePolicy"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$strDiskCachePolicy"/></xsl:attribute>
		 </Data>
		</xsl:if>
		<xsl:if test="(//IsVDOCEPossible and $ManageSSC != '1')">
         <Data name="ResizePossible" editable="false" type="ustring">
			<xsl:attribute name="display"><xsl:value-of select="$strVDResizePossible"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$strVDResizePossible"/></xsl:attribute>
		 </Data>
		</xsl:if>
		<xsl:if test="(//IsVDOCEPossible = '1'  and $ManageSSC != '1')">
         <Data name="ResizeLength" editable="false" type="ustring">
			<xsl:attribute name="display"><xsl:value-of select="$strResizeLength"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$strResizeLength"/></xsl:attribute>
		 </Data>
		</xsl:if>
        

    </xsl:template>
	<!-- VIRTUAL DISK TABLE ROWS -->
	<xsl:template name="VirtualDiskTableRows">
		<xsl:param name="ObjID">
			<xsl:call-template name="ModNexus">
				<xsl:with-param name="nexus">
					<xsl:value-of select="Nexus"/>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:param>
		<xsl:param name="tasks"/>
		<xsl:param name="ManageIsSSC"/>
        <xsl:param name="ControllerPageSSC"/>
		<xsl:param name="caller"/>
		<xsl:param name="VDLink">true</xsl:param>
		<xsl:call-template name="scripts"/>
		<xsl:variable name="vdiskname">
			<xsl:value-of select="Name"/>
		</xsl:variable>
		<xsl:variable name="vdiskid">
			<xsl:value-of select="$ObjID"/>
		</xsl:variable>

		<xsl:variable name="blink">
			<xsl:if test="substring(CurrentMethodMask,24,1)!='0'">true</xsl:if>
		</xsl:variable>
		
		<xsl:variable name="isCluster">
			<xsl:choose>
				<xsl:when test="substring(/OMA/VirtualDisks/@AttributesMask,32,1)!='0'">1</xsl:when>
			  <xsl:otherwise>0</xsl:otherwise>
		 </xsl:choose>
		</xsl:variable>
		
		<xsl:variable name="vdevname">
			<xsl:value-of select="DeviceName"/>
		</xsl:variable>
		<xsl:variable name="numbootpart">
			<xsl:choose>
				<xsl:when test="NumBootPart">
					<xsl:value-of select="NumBootPart"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="0"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<xsl:variable name="ManageSSC">
		    <xsl:choose>
			    <xsl:when test="/OMA/@cli = 'true'">
			        <xsl:value-of select="$ManageIsSSC"/>
			    </xsl:when>
                            <xsl:when test="$ControllerPageSSC = '1'">
                                <xsl:value-of select="$ControllerPageSSC"/>
                            </xsl:when>
			    <xsl:otherwise>
			        <xsl:value-of select="//ManageSSC"/>
			    </xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<xsl:if test="count(ParentVDID)= 0">
			<!-- Only display main virtual disks, not child VDisks -->
			<Row height="30px">
				<!-- ignore on web is set to true since it's only needed for scripts using the cli -->
				<Data name="Test" editable="false" type="ustring" display="Test" ignoreonweb="true">
					<xsl:attribute name="value"><xsl:value-of select="LogicalDriveNum"/></xsl:attribute>
				</Data>
				<Data type="status" align="center">
					<xsl:attribute name="value"><xsl:value-of select="ObjStatus"/></xsl:attribute>
				</Data>
				<Data link="true" editable="false" type="link" display="Test">
					<xsl:attribute name="name"><xsl:value-of select="$strName"/><xsl:value-of select="position()"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="Name"/></xsl:attribute>

				<!--	<xsl:attribute name="href">vdisk_<xsl:value-of select="(position()-1)"/><xsl:value-of select="$caller"/>.xml</xsl:attribute> -->
					<!-- The old way above would create a number scheme of vdisk#/cntrl# -->
					<!-- The NEW way below creates Cntroller#/Vdisk#  -->
					<!-- <xsl:attribute name="href">vdisk_<xsl:value-of select="$caller"/><xsl:value-of select="(position()-1)"/>.xml</xsl:attribute> -->
					<xsl:attribute name="href">vdisk_<xsl:value-of select="$caller"/><xsl:value-of select="$tasks"/>.xml</xsl:attribute>
				</Data>
				<Data editable="false" type="ustring" display="Test">
					<xsl:attribute name="name"><xsl:value-of select="$strState"/><xsl:value-of select="position()"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:call-template name="GetState"><xsl:with-param name="state"><xsl:value-of select="ObjState"/></xsl:with-param></xsl:call-template></xsl:attribute>
				</Data>
				
				<xsl:if test="//Partitions &gt; 0 and $ManageSSC != '1' ">
                                        <Data editable="false" type="ustring">
								<xsl:choose>
								<xsl:when test="Partitions &gt; 0"> 
                                                   <xsl:choose> 
                                                          <xsl:when test="/OMA/@cli = 'true'"> 
                                                           <xsl:attribute name="name"><xsl:value-of select="$strPartition"/><xsl:value-of select="position()"/></xsl:attribute>
	                                                    <xsl:attribute name="value"><xsl:value-of select="$strAvailable"/></xsl:attribute>
      	                                                
                                                       </xsl:when>

                                                       <xsl:otherwise>
					
                                                	    <xsl:attribute name="name"><xsl:value-of select="$strPartition"/><xsl:value-of select="position()"/></xsl:attribute>
	                                                    <xsl:attribute name="value"><xsl:value-of select="$strPartition"/></xsl:attribute>
      	                                              <xsl:attribute name="link">true</xsl:attribute>
            	                                        <xsl:attribute name="href">./DataArea?plugin=com.dell.sm.webplugins.VirtualDiskPartitionsPlugin&amp;ControllerOID=<xsl:value-of select="/OMA/ControllerOID"/>&amp;ControllerName=<xsl:value-of select="/OMA/ControllerName"/>&amp;VirtualDiskOID=<xsl:value-of select="$ObjID"/>&amp;VirtualDiskName=<xsl:value-of select="Name"/>&amp;RaidLayout=<xsl:value-of select="Layout"/>&amp;BackTo=<xsl:value-of select="$caller"/>&amp;IsVirtualDiskSecured=<xsl:value-of select="$IsVirtualDiskSecured"/>&amp;VDBadBlocksDetected=<xsl:value-of select="VDBadBlocksDetected"/>&amp;ManageSSC=<xsl:value-of select="//ManageSSC"/>&amp;help=vdspart</xsl:attribute>        
                                                       </xsl:otherwise>

                                                      
                                                   </xsl:choose>
								</xsl:when>
								<xsl:otherwise>
									<xsl:attribute name="name"><xsl:value-of select="$strPartition"/><xsl:value-of select="position()"/></xsl:attribute>
	                                                <xsl:attribute name="value"><xsl:value-of select="$strNotAvailable"/></xsl:attribute>							
								</xsl:otherwise>
								</xsl:choose>
      	                                          
                                        </Data>
                </xsl:if>
				
				<xsl:if test="(//VirtualDisks/DCStorageObject/ProtectionPolicyViolated and $ManageSSC != '1')">
					<xsl:choose>
						<xsl:when test="ProtectionPolicyViolated">
							<Data type="ustring" align="center">
								<xsl:attribute name="value"><xsl:call-template name="GetHSPolicyViolationStatus"><xsl:with-param name="ViolationCode"><xsl:value-of select="ProtectionPolicyViolated"/></xsl:with-param></xsl:call-template></xsl:attribute>
							</Data>
						</xsl:when>
						<xsl:when test="Layout = '2'">
							<Data type="ustring" align="center">
								<xsl:attribute name="value"><xsl:value-of select="$strNotApplicable"/></xsl:attribute>
							</Data>									
						</xsl:when>
						<xsl:when test="/OMA/@cli = 'true'">
						   <xsl:choose>
						     <xsl:when test="VendorID != '4'">
							     <Data type="ustring" align="center">
								    <xsl:attribute name="value"><xsl:value-of select="$strNotApplicable"/></xsl:attribute>
							     </Data>  
						     </xsl:when>
							 <xsl:otherwise>
							      <Data type="ustring" align="center">
								    <xsl:attribute name="value"><xsl:value-of select="$strNotAssigned"/></xsl:attribute>
							      </Data>
							 </xsl:otherwise>
                           </xsl:choose>						   
						</xsl:when>
						<xsl:otherwise>
							<Data type="ustring" align="center">
								<xsl:attribute name="value"><xsl:value-of select="$strNotAssigned"/></xsl:attribute>
							</Data>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:if>
				
				<xsl:if test="(//VirtualDisks/DCStorageObject/VDBadBlocksDetected and $ManageSSC != '1')">
					<xsl:choose>
						<xsl:when test="VDBadBlocksDetected">
							<Data type="ustring" align="center">
								<xsl:attribute name="value"><xsl:call-template name="IsVDBadBlocksDetected"><xsl:with-param name="badBlock"><xsl:value-of select="VDBadBlocksDetected"/></xsl:with-param></xsl:call-template></xsl:attribute>
							</Data>
						</xsl:when>
						<xsl:when test="/OMA/@cli = 'true' or substring(MasterMethodMask, 6, 1)= '1'">
							<xsl:choose>
								<xsl:when test="substring(MasterMethodMask, 6, 1)= '1'">
									<Data type="ustring" align="center">
										<xsl:attribute name="value"><xsl:value-of select="$strNo"/></xsl:attribute>
									</Data>
								</xsl:when>
								<xsl:otherwise>
									<Data type="ustring" align="center">
										<xsl:attribute name="value"><xsl:value-of select="$strNotApplicable"/></xsl:attribute>
									</Data>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:when>
					</xsl:choose>
				</xsl:if>
				
				<!-- isEmpty var used for tasks menu option -->
				<xsl:variable name="isEmpty">
					<xsl:call-template name="IsCurrentMethodMaskEmpty">
						<xsl:with-param name="Mask">
							<xsl:value-of select="CurrentMethodMask"/>
						</xsl:with-param>
					</xsl:call-template>
				</xsl:variable>
				
				<xsl:if test="$ManageSSC != '1'">
                <xsl:if test="contains($DisplayIsSecureVDColumn,'1') or /OMA/@cli='true'">
	    			  <Data type="ustring" align="center">
                                    <xsl:attribute name="value">
                                    <xsl:choose>
                                        <xsl:when test="(substring(//VirtualDisks/@AttributesMask,9,1)='1' or substring(//Controllers/DCStorageObject/AttributesMask,9,1)='1')">
                                                <xsl:call-template name="IsVirtualDiskSecured"><xsl:with-param name="Mask"><xsl:value-of select="AttributesMask"/></xsl:with-param></xsl:call-template>
                                        </xsl:when>
                                        <xsl:otherwise>
                                                <xsl:value-of select="$strNotApplicable"/>  
                                        </xsl:otherwise>
                                   </xsl:choose>
                                   </xsl:attribute>
				        </Data>
				</xsl:if>
				</xsl:if>
				
				<xsl:if test="((//VirtualDisks/DCStorageObject/Progress and $ManageSSC != '1' )) and //BusProtocol!='9'">
					<xsl:choose>
						<xsl:when test="Progress and Progress != 'Not Available'">
							<Data type="ustring" align="center">
								<xsl:attribute name="value"><xsl:value-of select="Progress"/><xsl:value-of select="$strPercComp"/></xsl:attribute>
							</Data>
						</xsl:when>
						<xsl:when test="Progress and Progress = 'Not Available'">
							<Data type="ustring" align="center">
								<xsl:attribute name="value"><xsl:value-of select="Progress"/></xsl:attribute>
							</Data>
						</xsl:when>
						<xsl:when test="/OMA/@cli = 'true'">
							<Data type="ustring" align="center">
								<xsl:attribute name="value"><xsl:value-of select="$strNotApplicable"/></xsl:attribute>
							</Data>
						</xsl:when>
						<xsl:otherwise>
							<Data type="ustring" align="center">
								<xsl:attribute name="value"/>
							</Data>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:if>
				
				<xsl:if test="$ManageSSC != '1'">
				<Data editable="false" type="ustring" display="Test">
					<xsl:attribute name="name"><xsl:value-of select="$strLayout"/><xsl:value-of select="position()"/></xsl:attribute>
					<xsl:choose>
					<xsl:when test="IsSSC = '1'">
					<xsl:attribute name="value"><xsl:value-of select="$strEnhCach"/></xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
					  <xsl:attribute name="value"><xsl:call-template name="GetRaidLayout"><xsl:with-param name="RaidType"><xsl:value-of select="Layout"/></xsl:with-param></xsl:call-template></xsl:attribute>
					</xsl:otherwise>
					</xsl:choose>
				</Data>
                </xsl:if>
				
				<xsl:choose>
					<xsl:when test="/OMA/@cli='true'">
						<!--CLI version of the capacty data (displays bytes as well as GB)-->
						<Data name="Test" editable="false" type="ustring" display="Test">
							<xsl:attribute name="value"><xsl:call-template name="DecimalSep"><xsl:with-param name="Size"><xsl:value-of select="Length"/></xsl:with-param></xsl:call-template> GB (<xsl:value-of select="Length"/> bytes)</xsl:attribute>
						</Data>
					</xsl:when>
					<xsl:otherwise>
						<!-- Web Version of the length data (ONLY displays GB) -->
						<Data editable="false" type="ustring" display="Test" ignoreoncli="true">
							<xsl:attribute name="name"><xsl:value-of select="$strSize"/><xsl:value-of select="position()"/></xsl:attribute>
							<xsl:attribute name="value"><xsl:call-template name="DecimalSep"><xsl:with-param name="Size"><xsl:value-of select="Length"/></xsl:with-param></xsl:call-template> <xsl:value-of select="$strGB"/></xsl:attribute>
						</Data>
					</xsl:otherwise>
				</xsl:choose>
				
				
				<xsl:if test="(//VdPIEnabled or /OMA/@cli = 'true') and //BusProtocol!='9'"> 
					<Data editable="false" type="ustring" display="Test">
						<xsl:attribute name="name"><xsl:value-of select="$strT10ProtectionStatus"/><xsl:value-of select="position()"/></xsl:attribute>
					
						<xsl:attribute name="value">
							<xsl:choose>
								<xsl:when test="//VdPIEnabled and //VdPIEnabled!='Not Available'">	
									<xsl:choose>
										<xsl:when test="VdPIEnabled = '1'"><xsl:value-of select="$strEnabled"/></xsl:when>
										<xsl:otherwise><xsl:value-of select="$strDisabled"/></xsl:otherwise>
									</xsl:choose>
								</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="$strNotAvailable"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
				</xsl:if>
                     
                     <xsl:if test="//PartOfCachePool or /OMA/@cli = 'true'"> <!-- RNA -->
                                   <Data editable="false" type="ustring" align="center">
                                         <xsl:attribute name="name"><xsl:value-of select="$strFluidCacheEnabled"/><xsl:value-of select="position()"/></xsl:attribute>
  							<xsl:attribute name="value"><xsl:choose><xsl:when test="PartOfCachePool"><xsl:call-template name="GetFluidCacheDeviceState"><xsl:with-param name="state"><xsl:value-of select="PartOfCachePool"/></xsl:with-param></xsl:call-template></xsl:when><xsl:otherwise><xsl:value-of select="$strNotApplicable"/></xsl:otherwise></xsl:choose></xsl:attribute>
		
            	                  </Data>
                                   
			</xsl:if>
			
			
			<xsl:if test="$ManageSSC != '1'">
				<xsl:choose>
				<xsl:when test="not(IsSSC) or IsSSC != '1'">
				  <Data editable="false" type="ustring" display="Test">
					  <xsl:attribute name="name"><xsl:value-of select="$strDeviceName"/><xsl:value-of select="position()"/></xsl:attribute>
					  <xsl:attribute name="value"><xsl:value-of select="DeviceName"/></xsl:attribute>
				  </Data>
				</xsl:when>
				<xsl:otherwise>
				    <Data editable="false" type="ustring" display="Test">
					   <xsl:attribute name="value"><xsl:value-of select="$strNotApplicable"/></xsl:attribute>
				    </Data>
				</xsl:otherwise>
				</xsl:choose>
                </xsl:if>
				
				<Data editable="false" type="ustring" display="Test">
					<xsl:attribute name="name"><xsl:value-of select="$strType"/><xsl:value-of select="position()"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:call-template name="GetBusProtocol"><xsl:with-param name="Bus"><xsl:value-of select="BusProtocol"/></xsl:with-param></xsl:call-template></xsl:attribute>
				</Data>
				
				<xsl:if test="$ManageSSC != '1'">         
                                <Data editable="false" type="ustring" display="Test">
					<xsl:attribute name="name"><xsl:value-of select="$strMediaType"/><xsl:value-of select="position()"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:call-template name="GetMediaType"><xsl:with-param name="MediaType"><xsl:value-of select="MediaType"/></xsl:with-param></xsl:call-template></xsl:attribute>
				</Data>
				<Data editable="false" type="ustring" display="Test">
					<xsl:attribute name="name"><xsl:value-of select="$strReadCache"/><xsl:value-of select="position()"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:call-template name="GetReadPolicy"><xsl:with-param name="readpolicy"><xsl:value-of select="ReadPolicy"/></xsl:with-param></xsl:call-template></xsl:attribute>
				</Data>
				<Data editable="false" type="ustring" display="Test">
					<xsl:attribute name="name"><xsl:value-of select="$strWriteCache"/><xsl:value-of select="position()"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:call-template name="GetWritePolicy"><xsl:with-param name="writepolicy"><xsl:value-of select="WritePolicy"/></xsl:with-param></xsl:call-template></xsl:attribute>
				</Data>
				<xsl:if test="//CachePolicy or /OMA/@cli = 'true'">
					<Data editable="false" type="ustring" display="Test">
						<xsl:attribute name="name"><xsl:value-of select="$strCachePolicy"/><xsl:value-of select="position()"/></xsl:attribute>
						<xsl:attribute name="value"><xsl:call-template name="GetCachePolicy"><xsl:with-param name="cachepolicy"><xsl:value-of select="CachePolicy"/></xsl:with-param></xsl:call-template></xsl:attribute>
					</Data>
				</xsl:if>
				<Data editable="false" type="ustring" display="Test">
					<xsl:attribute name="name"><xsl:value-of select="$strStripeSize"/><xsl:value-of select="position()"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:call-template name="GetStripeSize"><xsl:with-param name="stripesize"><xsl:value-of select="StripeSize"/></xsl:with-param></xsl:call-template></xsl:attribute>
				</Data>
                       </xsl:if>
					   
			 <xsl:if test="//DiskCachePolicy or /OMA/@cli = 'true'">
				<Data editable="false" type="ustring" display="Test">
					<xsl:attribute name="name"><xsl:value-of select="$strDiskCachePolicy"/><xsl:value-of select="position()"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:call-template name="GetDiskCachePolicy"><xsl:with-param name="DiskCachePolicy"><xsl:value-of select="DiskCachePolicy"/></xsl:with-param></xsl:call-template></xsl:attribute>
				</Data>
                        </xsl:if>

			<xsl:if test="(//IsVDOCEPossible and $ManageSSC != '1')">
				     <Data name="ResizePossible" editable="false" type="ustring">
			              <xsl:attribute name="name"><xsl:value-of select="$strVDResizePossible"/><xsl:value-of select="position()"/></xsl:attribute>
			               <xsl:attribute name="value"><xsl:call-template name="IsVDResizePossible"><xsl:with-param name="resizepossible"><xsl:value-of select="//IsVDOCEPossible"/></xsl:with-param></xsl:call-template></xsl:attribute>
		              </Data>
		        </xsl:if>
			
			<xsl:if test="(//IsVDOCEPossible = '1'  and $ManageSSC != '1')">
                    <Data name="ResizeLength" editable="false" type="ustring">
			            <xsl:attribute name="name"><xsl:value-of select="$strResizeLength"/><xsl:value-of select="position()"/></xsl:attribute>
			            <xsl:attribute name="value"><xsl:call-template name="DecimalSep"><xsl:with-param name="Size"><xsl:value-of select="//GetCapsResp/DCStorageObject/Length"/></xsl:with-param></xsl:call-template> GB (<xsl:value-of select="//GetCapsResp/DCStorageObject/Length"/> bytes)</xsl:attribute>
		            </Data>
		        </xsl:if>
            </Row>
		</xsl:if>
		<!-- End if (VDLevel = 0) -->
	</xsl:template>
</xsl:stylesheet>

